/* notificationbar.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from notificationbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <clutter/clutter.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
typedef struct _BoxesNotificationbarPrivate BoxesNotificationbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block44Data Block44Data;
typedef struct _Block45Data Block45Data;

#define BOXES_TYPE_APP_PAGE (boxes_app_page_get_type ())
typedef struct _Block46Data Block46Data;

struct _BoxesNotificationbar {
	GObject parent_instance;
	BoxesNotificationbarPrivate * priv;
};

struct _BoxesNotificationbarClass {
	GObjectClass parent_class;
};

struct _BoxesNotificationbarPrivate {
	GtkClutterActor* gtk_actor;
	GtkGrid* top_grid;
	GList* active_notifications;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef void (*BoxesNotificationbarOKFunc) (void* user_data);
typedef void (*BoxesNotificationbarCancelFunc) (void* user_data);
typedef void (*BoxesNotificationbarAuthenticateFunc) (const gchar* username, const gchar* password, void* user_data);
struct _Block44Data {
	int _ref_count_;
	BoxesNotificationbar * self;
	gchar* broker_name;
	BoxesNotificationbarAuthenticateFunc auth_func;
	gpointer auth_func_target;
	GDestroyNotify auth_func_target_destroy_notify;
	BoxesNotificationbarCancelFunc cancel_func;
	gpointer cancel_func_target;
	GDestroyNotify cancel_func_target_destroy_notify;
};

struct _Block45Data {
	int _ref_count_;
	BoxesNotificationbar * self;
	GdNotification* notification;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkButton* auth_button;
	BoxesNotificationbarAuthenticateFunc auth_func;
	gpointer auth_func_target;
	GDestroyNotify auth_func_target_destroy_notify;
};

typedef enum  {
	BOXES_APP_PAGE_MAIN,
	BOXES_APP_PAGE_DISPLAY
} BoxesAppPage;

struct _Block46Data {
	int _ref_count_;
	BoxesNotificationbar * self;
	GdNotification* notification;
	gboolean ok_pressed;
	BoxesNotificationbarOKFunc ok_func;
	gpointer ok_func_target;
	GDestroyNotify ok_func_target_destroy_notify;
	BoxesNotificationbarCancelFunc cancel_func;
	gpointer cancel_func_target;
	GDestroyNotify cancel_func_target_destroy_notify;
};


static gpointer boxes_notificationbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
#define BOXES_NOTIFICATIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarPrivate))
enum  {
	BOXES_NOTIFICATIONBAR_DUMMY_PROPERTY,
	BOXES_NOTIFICATIONBAR_ACTOR
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
BoxesNotificationbar* boxes_notificationbar_new (void);
BoxesNotificationbar* boxes_notificationbar_construct (GType object_type);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void __lambda65_ (BoxesNotificationbar* self);
static void boxes_notificationbar_add_notification (BoxesNotificationbar* self, GtkWidget* w);
static void ___lambda65__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationbarOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationbarCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static GdNotification* boxes_notificationbar_display (BoxesNotificationbar* self, const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationbarOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gint timeout);
GdNotification* boxes_notificationbar_display_for_authentication (BoxesNotificationbar* self, const gchar* broker_name, BoxesNotificationbarAuthenticateFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify);
static Block44Data* block44_data_ref (Block44Data* _data44_);
static void block44_data_unref (void * _userdata_);
static void __lambda68_ (Block44Data* _data44_);
static GdNotification* boxes_notificationbar_display_for_auth_next (BoxesNotificationbar* self, const gchar* auth_string, BoxesNotificationbarAuthenticateFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify);
static void ___lambda68__boxes_notificationbar_ok_func (gpointer self);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
static void __lambda69_ (Block45Data* _data45_);
static void ___lambda69__gd_notification_dismissed (GdNotification* _sender, gpointer self);
static gboolean __lambda70_ (BoxesNotificationbar* self);
void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value);
static gboolean ___lambda70__gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static gboolean __lambda71_ (BoxesNotificationbar* self);
static gboolean ___lambda71__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void __lambda72_ (Block45Data* _data45_);
static void ___lambda72__gtk_widget_map (GtkWidget* _sender, gpointer self);
static gboolean __lambda73_ (BoxesNotificationbar* self);
static gboolean ___lambda73__gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static gboolean __lambda74_ (BoxesNotificationbar* self);
static gboolean ___lambda74__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void __lambda75_ (Block45Data* _data45_);
static void ___lambda75__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda76_ (Block45Data* _data45_);
static void ___lambda76__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void __lambda77_ (Block45Data* _data45_);
static void ___lambda77__gtk_entry_activate (GtkEntry* _sender, gpointer self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
void boxes_notificationbar_cancel (BoxesNotificationbar* self);
GType boxes_app_page_get_type (void) G_GNUC_CONST;
void boxes_display_page_add_notification (BoxesDisplayPage* self, GtkWidget* w);
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
static void __lambda66_ (Block46Data* _data46_);
static void ___lambda66__gd_notification_dismissed (GdNotification* _sender, gpointer self);
static void ___lambda67_ (Block46Data* _data46_);
static void ____lambda67__gtk_button_clicked (GtkButton* _sender, gpointer self);
ClutterActor* boxes_notificationbar_get_actor (BoxesNotificationbar* self);
static void boxes_notificationbar_finalize (GObject* obj);
static void _vala_boxes_notificationbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static void _g_object_unref0_ (gpointer var) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 388 "notificationbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_list_free (self);
#line 397 "notificationbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 404 "notificationbar.c"
}


static void __lambda65_ (BoxesNotificationbar* self) {
	GList* _tmp0_ = NULL;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = self->priv->active_notifications;
#line 412 "notificationbar.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		w_collection = _tmp0_;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 420 "notificationbar.c"
			GtkWidget* _tmp1_ = NULL;
			GtkWidget* w = NULL;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
			_tmp1_ = _g_object_ref0 ((GtkWidget*) w_it->data);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
			w = _tmp1_;
#line 427 "notificationbar.c"
			{
				GtkContainer* parent = NULL;
				GtkWidget* _tmp2_ = NULL;
				GtkWidget* _tmp3_ = NULL;
				GtkContainer* _tmp4_ = NULL;
				GtkContainer* _tmp5_ = NULL;
				GtkWidget* _tmp8_ = NULL;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_tmp2_ = w;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_tmp3_ = gtk_widget_get_parent (_tmp2_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GTK_TYPE_CONTAINER) ? ((GtkContainer*) _tmp3_) : NULL);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				parent = _tmp4_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_tmp5_ = parent;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				if (_tmp5_ != NULL) {
#line 447 "notificationbar.c"
					GtkContainer* _tmp6_ = NULL;
					GtkWidget* _tmp7_ = NULL;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
					_tmp6_ = parent;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
					_tmp7_ = w;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
					gtk_container_remove (_tmp6_, _tmp7_);
#line 456 "notificationbar.c"
				}
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_tmp8_ = w;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				boxes_notificationbar_add_notification (self, _tmp8_);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_g_object_unref0 (parent);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
				_g_object_unref0 (w);
#line 466 "notificationbar.c"
			}
		}
	}
}


static void ___lambda65__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda65_ (self);
#line 476 "notificationbar.c"
}


BoxesNotificationbar* boxes_notificationbar_construct (GType object_type) {
	BoxesNotificationbar * self = NULL;
	GtkGrid* _tmp0_ = NULL;
	GtkGrid* _tmp1_ = NULL;
	GtkGrid* _tmp2_ = NULL;
	GtkClutterActor* _tmp3_ = NULL;
	GtkClutterActor* _tmp4_ = NULL;
	GtkClutterActor* _tmp5_ = NULL;
	GtkClutterActor* _tmp6_ = NULL;
	GtkClutterActor* _tmp7_ = NULL;
	GtkClutterActor* _tmp8_ = NULL;
	GdkRGBA transparent = {0};
	GdkRGBA _tmp9_ = {0};
	GtkClutterActor* _tmp10_ = NULL;
	GtkWidget* _tmp11_ = NULL;
	GdkRGBA _tmp12_ = {0};
	BoxesApp* _tmp13_ = NULL;
	GtkNotebook* _tmp14_ = NULL;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = (BoxesNotificationbar*) g_object_new (object_type, NULL);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__g_list_free__g_object_unref0_0 (self->priv->active_notifications);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = NULL;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp0_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (self->priv->top_grid);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->top_grid = _tmp0_;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = self->priv->top_grid;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_show ((GtkWidget*) _tmp1_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = self->priv->top_grid;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp2_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp3_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->gtk_actor = _tmp3_;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = self->priv->gtk_actor;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp4_, "notificationbar");
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = self->priv->gtk_actor;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp5_, CLUTTER_ACTOR_ALIGN_CENTER);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = self->priv->gtk_actor;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp6_, CLUTTER_ACTOR_ALIGN_START);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = self->priv->gtk_actor;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp7_, TRUE);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = self->priv->gtk_actor;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp8_, TRUE);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_.red = (gdouble) 0;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_.green = (gdouble) 0;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_.blue = (gdouble) 0;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_.alpha = (gdouble) 0;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	transparent = _tmp9_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = self->priv->gtk_actor;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp11_ = gtk_clutter_actor_get_widget (_tmp10_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp12_ = transparent;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_override_background_color (_tmp11_, 0, &_tmp12_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp13_ = boxes_app_app;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp14_ = _tmp13_->notebook;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GObject*) _tmp14_, "notify::page", (GCallback) ___lambda65__g_object_notify, self, 0);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return self;
#line 572 "notificationbar.c"
}


BoxesNotificationbar* boxes_notificationbar_new (void) {
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return boxes_notificationbar_construct (BOXES_TYPE_NOTIFICATIONBAR);
#line 579 "notificationbar.c"
}


GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationbarOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationbarCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout) {
	GdNotification* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesNotificationbarOKFunc _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	GDestroyNotify _tmp2__target_destroy_notify = NULL;
	BoxesNotificationbarCancelFunc _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	GDestroyNotify _tmp3__target_destroy_notify = NULL;
	gint _tmp4_ = 0;
	GdNotification* _tmp5_ = NULL;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (action_label != NULL, NULL);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = message;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = action_label;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = action_func;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = action_func_target;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2__target_destroy_notify = action_func_target_destroy_notify;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	action_func_target_destroy_notify = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = ignore_func;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3__target = ignore_func_target;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3__target_destroy_notify = ignore_func_target_destroy_notify;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	ignore_func_target_destroy_notify = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = timeout;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = boxes_notificationbar_display (self, _tmp0_, GTK_MESSAGE_INFO, _tmp1_, _tmp2_, _tmp2__target, _tmp2__target_destroy_notify, _tmp3_, _tmp3__target, _tmp3__target_destroy_notify, _tmp4_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = _tmp5_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(action_func_target_destroy_notify == NULL) ? NULL : (action_func_target_destroy_notify (action_func_target), NULL);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	action_func = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	action_func_target = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	action_func_target_destroy_notify = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(ignore_func_target_destroy_notify == NULL) ? NULL : (ignore_func_target_destroy_notify (ignore_func_target), NULL);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	ignore_func = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	ignore_func_target = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	ignore_func_target_destroy_notify = NULL;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 645 "notificationbar.c"
}


static Block44Data* block44_data_ref (Block44Data* _data44_) {
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data44_->_ref_count_);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return _data44_;
#line 654 "notificationbar.c"
}


static void block44_data_unref (void * _userdata_) {
	Block44Data* _data44_;
	_data44_ = (Block44Data*) _userdata_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data44_->_ref_count_)) {
#line 663 "notificationbar.c"
		BoxesNotificationbar * self;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		self = _data44_->self;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_free0 (_data44_->broker_name);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		(_data44_->auth_func_target_destroy_notify == NULL) ? NULL : (_data44_->auth_func_target_destroy_notify (_data44_->auth_func_target), NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->auth_func = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->auth_func_target = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->auth_func_target_destroy_notify = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		(_data44_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data44_->cancel_func_target_destroy_notify (_data44_->cancel_func_target), NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->cancel_func = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->cancel_func_target = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data44_->cancel_func_target_destroy_notify = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block44Data, _data44_);
#line 689 "notificationbar.c"
	}
}


static void __lambda68_ (Block44Data* _data44_) {
	BoxesNotificationbar * self;
	const gchar* _tmp0_ = NULL;
	BoxesNotificationbarAuthenticateFunc _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	GDestroyNotify _tmp1__target_destroy_notify = NULL;
	BoxesNotificationbarCancelFunc _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	GDestroyNotify _tmp2__target_destroy_notify = NULL;
	GdNotification* _tmp3_ = NULL;
	GdNotification* _tmp4_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data44_->self;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = _data44_->broker_name;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _data44_->auth_func;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1__target = _data44_->auth_func_target;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1__target_destroy_notify = _data44_->auth_func_target_destroy_notify;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func_target_destroy_notify = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = _data44_->cancel_func;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = _data44_->cancel_func_target;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2__target_destroy_notify = _data44_->cancel_func_target_destroy_notify;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target_destroy_notify = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = boxes_notificationbar_display_for_auth_next (self, _tmp0_, _tmp1_, _tmp1__target, _tmp1__target_destroy_notify, _tmp2_, _tmp2__target, _tmp2__target_destroy_notify);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _tmp3_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (_tmp4_);
#line 731 "notificationbar.c"
}


static void ___lambda68__boxes_notificationbar_ok_func (gpointer self) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda68_ (self);
#line 738 "notificationbar.c"
}


GdNotification* boxes_notificationbar_display_for_authentication (BoxesNotificationbar* self, const gchar* broker_name, BoxesNotificationbarAuthenticateFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify) {
	GdNotification* result = NULL;
	Block44Data* _data44_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	BoxesNotificationbarAuthenticateFunc _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	BoxesNotificationbarCancelFunc _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	BoxesNotificationbarOKFunc next_auth_step = NULL;
	void* next_auth_step_target = NULL;
	GDestroyNotify next_auth_step_target_destroy_notify = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	BoxesNotificationbarOKFunc _tmp9_ = NULL;
	void* _tmp9__target = NULL;
	GDestroyNotify _tmp9__target_destroy_notify = NULL;
	BoxesNotificationbarCancelFunc _tmp10_ = NULL;
	void* _tmp10__target = NULL;
	GDestroyNotify _tmp10__target_destroy_notify = NULL;
	GdNotification* _tmp11_ = NULL;
	GdNotification* _tmp12_ = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (broker_name != NULL, NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_ = g_slice_new0 (Block44Data);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->_ref_count_ = 1;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->self = g_object_ref (self);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = broker_name;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_data44_->broker_name);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->broker_name = _tmp1_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = auth_func;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = auth_func_target;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(_data44_->auth_func_target_destroy_notify == NULL) ? NULL : (_data44_->auth_func_target_destroy_notify (_data44_->auth_func_target), NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func_target = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func_target_destroy_notify = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func = _tmp2_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func_target = _tmp2__target;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->auth_func_target_destroy_notify = auth_func_target_destroy_notify;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = cancel_func;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3__target = cancel_func_target;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(_data44_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data44_->cancel_func_target_destroy_notify (_data44_->cancel_func_target), NULL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target_destroy_notify = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func = _tmp3_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target = _tmp3__target;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target_destroy_notify = cancel_func_target_destroy_notify;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step = ___lambda68__boxes_notificationbar_ok_func;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target = block44_data_ref (_data44_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = block44_data_unref;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _ ("Not connected to %s");
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = _data44_->broker_name;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = g_strdup_printf (_tmp4_, _tmp5_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = _tmp6_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = _ ("Sign In");
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_ = next_auth_step;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9__target = next_auth_step_target;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9__target_destroy_notify = next_auth_step_target_destroy_notify;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = _data44_->cancel_func;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10__target = _data44_->cancel_func_target;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10__target_destroy_notify = _data44_->cancel_func_target_destroy_notify;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_->cancel_func_target_destroy_notify = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp11_ = boxes_notificationbar_display_for_action (self, _tmp7_, _tmp8_, _tmp9_, _tmp9__target, _tmp9__target_destroy_notify, _tmp10_, _tmp10__target, _tmp10__target_destroy_notify, -1);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp12_ = _tmp11_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp7_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = _tmp12_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(next_auth_step_target_destroy_notify == NULL) ? NULL : (next_auth_step_target_destroy_notify (next_auth_step_target), NULL);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	block44_data_unref (_data44_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data44_ = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 875 "notificationbar.c"
}


static Block45Data* block45_data_ref (Block45Data* _data45_) {
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data45_->_ref_count_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return _data45_;
#line 884 "notificationbar.c"
}


static void block45_data_unref (void * _userdata_) {
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
#line 893 "notificationbar.c"
		BoxesNotificationbar * self;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		self = _data45_->self;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data45_->auth_button);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data45_->password_entry);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data45_->username_entry);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data45_->notification);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		(_data45_->auth_func_target_destroy_notify == NULL) ? NULL : (_data45_->auth_func_target_destroy_notify (_data45_->auth_func_target), NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data45_->auth_func = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data45_->auth_func_target = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data45_->auth_func_target_destroy_notify = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block45Data, _data45_);
#line 917 "notificationbar.c"
	}
}


static void __lambda69_ (Block45Data* _data45_) {
	BoxesNotificationbar * self;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data45_->self;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_remove (self->priv->active_notifications, (GtkWidget*) _data45_->notification);
#line 928 "notificationbar.c"
}


static void ___lambda69__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda69_ (self);
#line 935 "notificationbar.c"
}


static gboolean __lambda70_ (BoxesNotificationbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = boxes_app_app;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, FALSE);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = FALSE;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 953 "notificationbar.c"
}


static gboolean ___lambda70__gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda70_ (self);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 962 "notificationbar.c"
}


static gboolean __lambda71_ (BoxesNotificationbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = boxes_app_app;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, TRUE);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = FALSE;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 980 "notificationbar.c"
}


static gboolean ___lambda71__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda71_ (self);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 989 "notificationbar.c"
}


static void __lambda72_ (Block45Data* _data45_) {
	BoxesNotificationbar * self;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data45_->self;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_grab_focus ((GtkWidget*) _data45_->username_entry);
#line 999 "notificationbar.c"
}


static void ___lambda72__gtk_widget_map (GtkWidget* _sender, gpointer self) {
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda72_ (self);
#line 1006 "notificationbar.c"
}


static gboolean __lambda73_ (BoxesNotificationbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = boxes_app_app;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, FALSE);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = FALSE;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1024 "notificationbar.c"
}


static gboolean ___lambda73__gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda73_ (self);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1033 "notificationbar.c"
}


static gboolean __lambda74_ (BoxesNotificationbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = boxes_app_app;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, TRUE);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = FALSE;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1051 "notificationbar.c"
}


static gboolean ___lambda74__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda74_ (self);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1060 "notificationbar.c"
}


static void __lambda75_ (Block45Data* _data45_) {
	BoxesNotificationbar * self;
	BoxesNotificationbarAuthenticateFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data45_->self;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = _data45_->auth_func;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0__target = _data45_->auth_func_target;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (_tmp0_ != NULL) {
#line 1076 "notificationbar.c"
		BoxesNotificationbarAuthenticateFunc _tmp1_ = NULL;
		void* _tmp1__target = NULL;
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1_ = _data45_->auth_func;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1__target = _data45_->auth_func_target;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp2_ = gtk_entry_get_text (_data45_->username_entry);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp3_ = gtk_entry_get_text (_data45_->password_entry);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1_ (_tmp2_, _tmp3_, _tmp1__target);
#line 1091 "notificationbar.c"
	}
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gd_notification_dismiss (_data45_->notification);
#line 1095 "notificationbar.c"
}


static void ___lambda75__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda75_ (self);
#line 1102 "notificationbar.c"
}


static void __lambda76_ (Block45Data* _data45_) {
	BoxesNotificationbar * self;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data45_->self;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_grab_focus ((GtkWidget*) _data45_->password_entry);
#line 1112 "notificationbar.c"
}


static void ___lambda76__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda76_ (self);
#line 1119 "notificationbar.c"
}


static void __lambda77_ (Block45Data* _data45_) {
	BoxesNotificationbar * self;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data45_->self;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_emit_by_name (_data45_->auth_button, "activate");
#line 1129 "notificationbar.c"
}


static void ___lambda77__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda77_ (self);
#line 1136 "notificationbar.c"
}


static GdNotification* boxes_notificationbar_display_for_auth_next (BoxesNotificationbar* self, const gchar* auth_string, BoxesNotificationbarAuthenticateFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify) {
	GdNotification* result = NULL;
	Block45Data* _data45_;
	BoxesNotificationbarAuthenticateFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GdNotification* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkLabel* title_label = NULL;
	GtkLabel* _tmp3_ = NULL;
	gchar* title_str = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GtkLabel* username_label = NULL;
	const gchar* _tmp12_ = NULL;
	GtkLabel* _tmp13_ = NULL;
	GtkEntry* _tmp14_ = NULL;
	GtkLabel* password_label = NULL;
	const gchar* _tmp15_ = NULL;
	GtkLabel* _tmp16_ = NULL;
	GtkEntry* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	GtkButton* _tmp19_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp20_ = NULL;
	GdNotification* _tmp21_ = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (auth_string != NULL, NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_ = g_slice_new0 (Block45Data);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->_ref_count_ = 1;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->self = g_object_ref (self);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = auth_func;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0__target = auth_func_target;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(_data45_->auth_func_target_destroy_notify == NULL) ? NULL : (_data45_->auth_func_target_destroy_notify (_data45_->auth_func_target), NULL);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func_target = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func_target_destroy_notify = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func = _tmp0_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func_target = _tmp0__target;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_func_target_destroy_notify = auth_func_target_destroy_notify;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = (GdNotification*) gd_notification_new ();
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp1_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->notification = _tmp1_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _data45_->notification, GTK_ALIGN_START);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_set (_data45_->notification, "timeout", -1, NULL);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_set (_data45_->notification, "show-close-button", FALSE, NULL);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = _g_object_ref0 ((GtkWidget*) _data45_->notification);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_prepend (self->priv->active_notifications, _tmp2_);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_data45_->notification, "dismissed", (GCallback) ___lambda69__gd_notification_dismissed, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = (GtkLabel*) gtk_label_new (NULL);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp3_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	title_label = _tmp3_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _ ("Sign In to %s");
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = auth_string;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = g_strdup_printf (_tmp4_, _tmp5_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = _tmp6_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = g_strconcat ("<span font-weight=\"bold\">", _tmp7_, NULL);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_ = _tmp8_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = g_strconcat (_tmp9_, "</span>", NULL);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp11_ = _tmp10_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp9_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp7_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	title_str = _tmp11_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_label_set_markup (title_label, title_str);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_halign ((GtkWidget*) title_label, GTK_ALIGN_START);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) title_label, 18);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp12_ = _ ("_Username");
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp13_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp12_);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp13_);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	username_label = _tmp13_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp14_ = (GtkEntry*) gtk_entry_new ();
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp14_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->username_entry = _tmp14_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GtkWidget*) _data45_->username_entry, "focus-in-event", (GCallback) ___lambda70__gtk_widget_focus_in_event, self, 0);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GtkWidget*) _data45_->username_entry, "focus-out-event", (GCallback) ___lambda71__gtk_widget_focus_out_event, self, 0);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data ((GtkWidget*) _data45_->username_entry, "map", (GCallback) ___lambda72__gtk_widget_map, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_label_set_mnemonic_widget (username_label, (GtkWidget*) _data45_->username_entry);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_margin_left ((GtkWidget*) username_label, 12);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp15_ = _ ("_Password");
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp16_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp15_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp16_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	password_label = _tmp16_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp17_ = (GtkEntry*) gtk_entry_new ();
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp17_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->password_entry = _tmp17_;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_entry_set_visibility (_data45_->password_entry, FALSE);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GtkWidget*) _data45_->password_entry, "focus-in-event", (GCallback) ___lambda73__gtk_widget_focus_in_event, self, 0);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GtkWidget*) _data45_->password_entry, "focus-out-event", (GCallback) ___lambda74__gtk_widget_focus_out_event, self, 0);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_label_set_mnemonic_widget (password_label, (GtkWidget*) _data45_->password_entry);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_margin_left ((GtkWidget*) password_label, 12);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp18_ = _ ("Sign In");
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp19_ = (GtkButton*) gtk_button_new_from_stock (_tmp18_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp19_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_->auth_button = _tmp19_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_halign ((GtkWidget*) _data45_->auth_button, GTK_ALIGN_END);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_data45_->auth_button, "clicked", (GCallback) ___lambda75__gtk_button_clicked, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_data45_->username_entry, "activate", (GCallback) ___lambda76__gtk_entry_activate, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_data45_->password_entry, "activate", (GCallback) ___lambda77__gtk_entry_activate, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp20_ = (GtkGrid*) gtk_grid_new ();
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp20_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	grid = _tmp20_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_set_column_spacing (grid, 12);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_set_row_spacing (grid, 6);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_container_set_border_width ((GtkContainer*) grid, (guint) 6);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) title_label, 0, 0, 2, 1);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) username_label, 0, 1, 1, 1);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data45_->username_entry, 1, 1, 1, 1);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) password_label, 0, 2, 1, 1);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data45_->password_entry, 1, 2, 1, 1);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data45_->auth_button, 1, 3, 1, 1);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_container_add ((GtkContainer*) _data45_->notification, (GtkWidget*) grid);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_add_notification (self, (GtkWidget*) _data45_->notification);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_show_all ((GtkWidget*) _data45_->notification);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp21_ = _g_object_ref0 (_data45_->notification);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = _tmp21_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (grid);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (password_label);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (username_label);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_free0 (title_str);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (title_label);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	block45_data_unref (_data45_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data45_ = NULL;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(cancel_func_target_destroy_notify == NULL) ? NULL : (cancel_func_target_destroy_notify (cancel_func_target), NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	cancel_func = NULL;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	cancel_func_target = NULL;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	cancel_func_target_destroy_notify = NULL;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1373 "notificationbar.c"
}


GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout) {
	GdNotification* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	GdNotification* _tmp2_ = NULL;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = message;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = timeout;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = boxes_notificationbar_display (self, _tmp0_, GTK_MESSAGE_ERROR, NULL, NULL, NULL, NULL, NULL, NULL, NULL, _tmp1_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = _tmp2_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1396 "notificationbar.c"
}


void boxes_notificationbar_cancel (BoxesNotificationbar* self) {
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (self != NULL);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	while (TRUE) {
#line 1405 "notificationbar.c"
		GList* _tmp0_ = NULL;
		GList* _tmp1_ = NULL;
		gconstpointer _tmp2_ = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp0_ = self->priv->active_notifications;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		if (!(_tmp0_ != NULL)) {
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
			break;
#line 1415 "notificationbar.c"
		}
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1_ = self->priv->active_notifications;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp2_ = _tmp1_->data;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp2_);
#line 1423 "notificationbar.c"
	}
}


static void boxes_notificationbar_add_notification (BoxesNotificationbar* self, GtkWidget* w) {
	BoxesApp* _tmp0_ = NULL;
	GtkNotebook* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (self != NULL);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (w != NULL);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = boxes_app_app;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _tmp0_->notebook;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_get (_tmp1_, "page", &_tmp2_, NULL);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = _tmp2_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (_tmp3_ == ((gint) BOXES_APP_PAGE_MAIN)) {
#line 1447 "notificationbar.c"
		GtkGrid* _tmp4_ = NULL;
		GtkWidget* _tmp5_ = NULL;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp4_ = self->priv->top_grid;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp5_ = w;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		gtk_grid_attach (_tmp4_, _tmp5_, 0, 0, 1, 1);
#line 1456 "notificationbar.c"
	} else {
		BoxesApp* _tmp6_ = NULL;
		BoxesDisplayPage* _tmp7_ = NULL;
		GtkWidget* _tmp8_ = NULL;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp6_ = boxes_app_app;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp7_ = _tmp6_->display_page;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp8_ = w;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		boxes_display_page_add_notification (_tmp7_, _tmp8_);
#line 1469 "notificationbar.c"
	}
}


static Block46Data* block46_data_ref (Block46Data* _data46_) {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data46_->_ref_count_);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return _data46_;
#line 1479 "notificationbar.c"
}


static void block46_data_unref (void * _userdata_) {
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
#line 1488 "notificationbar.c"
		BoxesNotificationbar * self;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		self = _data46_->self;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data46_->notification);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		(_data46_->ok_func_target_destroy_notify == NULL) ? NULL : (_data46_->ok_func_target_destroy_notify (_data46_->ok_func_target), NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->ok_func = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->ok_func_target = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->ok_func_target_destroy_notify = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		(_data46_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data46_->cancel_func_target_destroy_notify (_data46_->cancel_func_target), NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->cancel_func = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->cancel_func_target = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_data46_->cancel_func_target_destroy_notify = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block46Data, _data46_);
#line 1514 "notificationbar.c"
	}
}


static void __lambda66_ (Block46Data* _data46_) {
	BoxesNotificationbar * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GdNotification* _tmp5_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data46_->self;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = _data46_->ok_pressed;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (!_tmp1_) {
#line 1531 "notificationbar.c"
		BoxesNotificationbarCancelFunc _tmp2_ = NULL;
		void* _tmp2__target = NULL;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp2_ = _data46_->cancel_func;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp2__target = _data46_->cancel_func_target;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 1540 "notificationbar.c"
	} else {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp0_ = FALSE;
#line 1544 "notificationbar.c"
	}
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = _tmp0_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (_tmp3_) {
#line 1550 "notificationbar.c"
		BoxesNotificationbarCancelFunc _tmp4_ = NULL;
		void* _tmp4__target = NULL;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp4_ = _data46_->cancel_func;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp4__target = _data46_->cancel_func_target;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp4_ (_tmp4__target);
#line 1559 "notificationbar.c"
	}
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = _data46_->notification;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_remove (self->priv->active_notifications, (GtkWidget*) _tmp5_);
#line 1565 "notificationbar.c"
}


static void ___lambda66__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__lambda66_ (self);
#line 1572 "notificationbar.c"
}


static void ___lambda67_ (Block46Data* _data46_) {
	BoxesNotificationbar * self;
	BoxesNotificationbarOKFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GdNotification* _tmp2_ = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = _data46_->self;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_pressed = TRUE;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = _data46_->ok_func;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0__target = _data46_->ok_func_target;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (_tmp0_ != NULL) {
#line 1591 "notificationbar.c"
		BoxesNotificationbarOKFunc _tmp1_ = NULL;
		void* _tmp1__target = NULL;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1_ = _data46_->ok_func;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1__target = _data46_->ok_func_target;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp1_ (_tmp1__target);
#line 1600 "notificationbar.c"
	}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = _data46_->notification;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gd_notification_dismiss (_tmp2_);
#line 1606 "notificationbar.c"
}


static void ____lambda67__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	___lambda67_ (self);
#line 1613 "notificationbar.c"
}


static GdNotification* boxes_notificationbar_display (BoxesNotificationbar* self, const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationbarOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationbarCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gint timeout) {
	GdNotification* result = NULL;
	Block46Data* _data46_;
	BoxesNotificationbarOKFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	BoxesNotificationbarCancelFunc _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	GdNotification* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GdNotification* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GdNotification* _tmp6_ = NULL;
	GtkWidget* _tmp7_ = NULL;
	GdNotification* _tmp8_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	GtkGrid* _tmp13_ = NULL;
	GtkGrid* _tmp14_ = NULL;
	GdNotification* _tmp15_ = NULL;
	GtkGrid* _tmp16_ = NULL;
	GtkLabel* message_label = NULL;
	const gchar* _tmp17_ = NULL;
	GtkLabel* _tmp18_ = NULL;
	GtkGrid* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	GdNotification* _tmp28_ = NULL;
	GdNotification* _tmp29_ = NULL;
	GdNotification* _tmp30_ = NULL;
	GdNotification* _tmp31_ = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_ = g_slice_new0 (Block46Data);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->_ref_count_ = 1;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->self = g_object_ref (self);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = ok_func;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0__target = ok_func_target;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(_data46_->ok_func_target_destroy_notify == NULL) ? NULL : (_data46_->ok_func_target_destroy_notify (_data46_->ok_func_target), NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func_target = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func_target_destroy_notify = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func = _tmp0_;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func_target = _tmp0__target;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_func_target_destroy_notify = ok_func_target_destroy_notify;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = cancel_func;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp1__target = cancel_func_target;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	(_data46_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data46_->cancel_func_target_destroy_notify (_data46_->cancel_func_target), NULL);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func_target = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func_target_destroy_notify = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func = _tmp1_;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func_target = _tmp1__target;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->cancel_func_target_destroy_notify = cancel_func_target_destroy_notify;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = (GdNotification*) gd_notification_new ();
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp2_);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->notification = _tmp2_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = _data46_->notification;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp3_, GTK_ALIGN_START);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _data46_->notification;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = timeout;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_set (_tmp4_, "timeout", _tmp5_, NULL);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = _data46_->notification;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = _g_object_ref0 ((GtkWidget*) _tmp6_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_prepend (self->priv->active_notifications, _tmp7_);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_->ok_pressed = FALSE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = _data46_->notification;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_tmp8_, "dismissed", (GCallback) ___lambda66__gd_notification_dismissed, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp9_ = (GtkGrid*) gtk_grid_new ();
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp9_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	grid = _tmp9_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = grid;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp10_, GTK_ORIENTATION_HORIZONTAL);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp11_ = grid;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_margin_left ((GtkWidget*) _tmp11_, 12);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp12_ = grid;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp12_, 12);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp13_ = grid;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_grid_set_column_spacing (_tmp13_, 12);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp14_ = grid;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp14_, GTK_ALIGN_CENTER);
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp15_ = _data46_->notification;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp16_ = grid;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_container_add ((GtkContainer*) _tmp15_, (GtkWidget*) _tmp16_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp17_ = message;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp18_ = (GtkLabel*) gtk_label_new (_tmp17_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp18_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	message_label = _tmp18_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp19_ = grid;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp20_ = message_label;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_container_add ((GtkContainer*) _tmp19_, (GtkWidget*) _tmp20_);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp21_ = ok_label;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	if (_tmp21_ != NULL) {
#line 1774 "notificationbar.c"
		GtkButton* ok_button = NULL;
		const gchar* _tmp22_ = NULL;
		GtkButton* _tmp23_ = NULL;
		GtkButton* _tmp24_ = NULL;
		GtkGrid* _tmp25_ = NULL;
		GtkButton* _tmp26_ = NULL;
		GtkButton* _tmp27_ = NULL;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp22_ = ok_label;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp23_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp22_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_object_ref_sink (_tmp23_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		ok_button = _tmp23_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp24_ = ok_button;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		gtk_widget_set_halign ((GtkWidget*) _tmp24_, GTK_ALIGN_END);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp25_ = grid;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp26_ = ok_button;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		gtk_container_add ((GtkContainer*) _tmp25_, (GtkWidget*) _tmp26_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_tmp27_ = ok_button;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_signal_connect_data (_tmp27_, "clicked", (GCallback) ____lambda67__gtk_button_clicked, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (ok_button);
#line 1806 "notificationbar.c"
	}
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp28_ = _data46_->notification;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_add_notification (self, (GtkWidget*) _tmp28_);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp29_ = _data46_->notification;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp29_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp30_ = _data46_->notification;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp31_ = _g_object_ref0 (_tmp30_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = _tmp31_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (message_label);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (grid);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	block46_data_unref (_data46_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_data46_ = NULL;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1832 "notificationbar.c"
}


ClutterActor* boxes_notificationbar_get_actor (BoxesNotificationbar* self) {
	ClutterActor* result;
	GtkClutterActor* _tmp0_ = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	result = (ClutterActor*) _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	return result;
#line 1847 "notificationbar.c"
}


static void boxes_notificationbar_class_init (BoxesNotificationbarClass * klass) {
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_parent_class = g_type_class_peek_parent (klass);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesNotificationbarPrivate));
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_notificationbar_get_property;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_notificationbar_finalize;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_NOTIFICATIONBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1862 "notificationbar.c"
}


static void boxes_notificationbar_instance_init (BoxesNotificationbar * self) {
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self->priv = BOXES_NOTIFICATIONBAR_GET_PRIVATE (self);
#line 1869 "notificationbar.c"
}


static void boxes_notificationbar_finalize (GObject* obj) {
	BoxesNotificationbar * self;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (self->priv->top_grid);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	__g_list_free__g_object_unref0_0 (self->priv->active_notifications);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (boxes_notificationbar_parent_class)->finalize (obj);
#line 1885 "notificationbar.c"
}


GType boxes_notificationbar_get_type (void) {
	static volatile gsize boxes_notificationbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_notificationbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesNotificationbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_notificationbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesNotificationbar), 0, (GInstanceInitFunc) boxes_notificationbar_instance_init, NULL };
		GType boxes_notificationbar_type_id;
		boxes_notificationbar_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesNotificationbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_notificationbar_type_id__volatile, boxes_notificationbar_type_id);
	}
	return boxes_notificationbar_type_id__volatile;
}


static void _vala_boxes_notificationbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesNotificationbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
	switch (property_id) {
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		case BOXES_NOTIFICATIONBAR_ACTOR:
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		g_value_set_object (value, boxes_notificationbar_get_actor (self));
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		break;
#line 1912 "notificationbar.c"
		default:
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/notificationbar.vala"
		break;
#line 1918 "notificationbar.c"
	}
}



