/* main.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from main.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdio.h>
#include <config.h>
#include <stdlib.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <string.h>
#include <libcommon.h>
#include <libvirt-gobject/libvirt-gobject.h>

#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block43Data Block43Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _RunChecksData RunChecksData;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _Block43Data {
	int _ref_count_;
	GMainLoop* loop;
};

struct _RunChecksData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* selinux_context_diagnosis;
	gchar* _tmp0_;
	gchar* storage_pool_diagnosis;
	gchar* _tmp1_;
	gboolean cpu;
	gboolean _tmp2_;
	gboolean kvm;
	gboolean _tmp3_;
	gboolean libvirt_kvm;
	gboolean _tmp4_;
	gboolean selinux_context_default;
	gchar* _tmp5_;
	gboolean _tmp6_;
	gboolean storage_pool;
	gchar* _tmp7_;
	gboolean _tmp8_;
	FILE* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	FILE* _tmp16_;
	const gchar* _tmp17_;
	gboolean _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	FILE* _tmp23_;
	const gchar* _tmp24_;
	gboolean _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	FILE* _tmp30_;
	const gchar* _tmp31_;
	gboolean _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	const gchar* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
	FILE* _tmp40_;
	const gchar* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	FILE* _tmp46_;
	const gchar* _tmp47_;
	gboolean _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	const gchar* _tmp53_;
	gint _tmp54_;
	gint _tmp55_;
	FILE* _tmp56_;
	const gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	gchar* _tmp61_;
	FILE* _tmp62_;
	FILE* _tmp63_;
	const gchar* _tmp64_;
	FILE* _tmp65_;
	const gchar* _tmp66_;
	const gchar* _tmp67_;
};


extern gboolean version;
gboolean version = FALSE;
extern gboolean checks;
gboolean checks = FALSE;

void parse_local_args (gchar*** args, int* args_length1);
static Block43Data* block43_data_ref (Block43Data* _data43_);
static void block43_data_unref (void * _userdata_);
void run_checks (GAsyncReadyCallback _callback_, gpointer _user_data_);
void run_checks_finish (GAsyncResult* _res_);
static void ___lambda230_ (Block43Data* _data43_, GObject* obj, GAsyncResult* res);
static void ____lambda230__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void run_checks_data_free (gpointer _data);
static gboolean run_checks_co (RunChecksData* _data_);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static void run_checks_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis);
gint _vala_main (gchar** args, int args_length1);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
BoxesApp* boxes_app_new (void);
BoxesApp* boxes_app_construct (GType object_type);
gint boxes_app_run (BoxesApp* self, gchar** args, int args_length1);
void boxes_app_shutdown (BoxesApp* self);
void boxes_app_suspend_machines (BoxesApp* self);

const GOptionEntry local_options[3] = {{"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &version, "Display version number", NULL}, {"checks", (gchar) 0, 0, G_OPTION_ARG_NONE, &checks, "Check virtualization capabilities", NULL}, {NULL}};

static Block43Data* block43_data_ref (Block43Data* _data43_) {
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_atomic_int_inc (&_data43_->_ref_count_);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return _data43_;
#line 175 "main.c"
}


static void block43_data_unref (void * _userdata_) {
	Block43Data* _data43_;
	_data43_ = (Block43Data*) _userdata_;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (g_atomic_int_dec_and_test (&_data43_->_ref_count_)) {
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_main_loop_unref0 (_data43_->loop);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_slice_free (Block43Data, _data43_);
#line 188 "main.c"
	}
}


static void ___lambda230_ (Block43Data* _data43_, GObject* obj, GAsyncResult* res) {
	GAsyncResult* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_return_if_fail (res != NULL);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp0_ = res;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	run_checks_finish (_tmp0_);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp1_ = _data43_->loop;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_main_loop_quit (_tmp1_);
#line 206 "main.c"
}


static void ____lambda230__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	___lambda230_ (self, source_object, res);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	block43_data_unref (self);
#line 215 "main.c"
}


void parse_local_args (gchar*** args, int* args_length1) {
	GOptionContext* opt_context = NULL;
	GOptionContext* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp0_ = g_option_context_new (NULL);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	opt_context = _tmp0_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_option_context_set_ignore_unknown_options (opt_context, TRUE);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_option_context_add_main_entries (opt_context, local_options, NULL);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_option_context_set_help_enabled (opt_context, FALSE);
#line 235 "main.c"
	{
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_option_context_parse (opt_context, args_length1, args, &_inner_error_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		if (_inner_error_ != NULL) {
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 243 "main.c"
				goto __catch54_g_option_error;
			}
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
			_g_option_context_free0 (opt_context);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
			g_clear_error (&_inner_error_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
			return;
#line 254 "main.c"
		}
	}
	goto __finally54;
	__catch54_g_option_error:
	{
		GError* _error_ = NULL;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_error_ = _inner_error_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_inner_error_ = NULL;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_error_free0 (_error_);
#line 267 "main.c"
	}
	__finally54:
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_inner_error_ != NULL) {
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_option_context_free0 (opt_context);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_clear_error (&_inner_error_);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		return;
#line 280 "main.c"
	}
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp1_ = version;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_tmp1_) {
#line 286 "main.c"
		FILE* _tmp2_ = NULL;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_tmp2_ = stdout;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		fprintf (_tmp2_, "%s\n", VERSION);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		exit (0);
#line 294 "main.c"
	}
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp3_ = checks;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_tmp3_) {
#line 300 "main.c"
		Block43Data* _data43_;
		GMainLoop* _tmp4_ = NULL;
		GMainLoop* _tmp5_ = NULL;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data43_ = g_slice_new0 (Block43Data);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data43_->_ref_count_ = 1;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_tmp4_ = g_main_loop_new (NULL, FALSE);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data43_->loop = _tmp4_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		run_checks (____lambda230__gasync_ready_callback, block43_data_ref (_data43_));
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_tmp5_ = _data43_->loop;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_main_loop_run (_tmp5_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		exit (0);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		block43_data_unref (_data43_);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data43_ = NULL;
#line 324 "main.c"
	}
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_option_context_free0 (opt_context);
#line 328 "main.c"
}


static void run_checks_data_free (gpointer _data) {
	RunChecksData* _data_;
	_data_ = _data;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (RunChecksData, _data_);
#line 337 "main.c"
}


void run_checks (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	RunChecksData* _data_;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (RunChecksData);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, run_checks);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, run_checks_data_free);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	run_checks_co (_data_);
#line 351 "main.c"
}


void run_checks_finish (GAsyncResult* _res_) {
	RunChecksData* _data_;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 359 "main.c"
}


static void run_checks_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	RunChecksData* _data_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_ = _user_data_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_source_object_ = source_object;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_res_ = _res_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	run_checks_co (_data_);
#line 373 "main.c"
}


static gboolean run_checks_co (RunChecksData* _data_) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	switch (_data_->_state_) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 0:
#line 382 "main.c"
		goto _state_0;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 1:
#line 386 "main.c"
		goto _state_1;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 2:
#line 390 "main.c"
		goto _state_2;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 3:
#line 394 "main.c"
		goto _state_3;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 4:
#line 398 "main.c"
		goto _state_4;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		case 5:
#line 402 "main.c"
		goto _state_5;
		default:
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_assert_not_reached ();
#line 407 "main.c"
	}
	_state_0:
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp0_ = NULL;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->selinux_context_diagnosis = _data_->_tmp0_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp1_ = NULL;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp1_ = g_strdup ("");
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->storage_pool_diagnosis = _data_->_tmp1_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_state_ = 1;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_check_cpu_vt_capability (run_checks_ready, _data_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 428 "main.c"
	_state_1:
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp2_ = FALSE;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp2_ = boxes_check_cpu_vt_capability_finish (_data_->_res_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->cpu = _data_->_tmp2_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_state_ = 2;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_check_module_kvm_loaded (run_checks_ready, _data_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 442 "main.c"
	_state_2:
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp3_ = FALSE;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp3_ = boxes_check_module_kvm_loaded_finish (_data_->_res_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->kvm = _data_->_tmp3_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_state_ = 3;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_check_libvirt_kvm (run_checks_ready, _data_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 456 "main.c"
	_state_3:
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp4_ = FALSE;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp4_ = boxes_check_libvirt_kvm_finish (_data_->_res_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->libvirt_kvm = _data_->_tmp4_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp5_ = NULL;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_state_ = 4;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_check_selinux_context_default (run_checks_ready, _data_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 472 "main.c"
	_state_4:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp6_ = FALSE;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp6_ = boxes_check_selinux_context_default_finish (_data_->_res_, &_data_->_tmp5_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->selinux_context_diagnosis);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->selinux_context_diagnosis = _data_->_tmp5_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->selinux_context_default = _data_->_tmp6_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp7_ = NULL;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_state_ = 5;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_check_storage_pool (run_checks_ready, _data_);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 492 "main.c"
	_state_5:
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp8_ = FALSE;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp8_ = boxes_check_storage_pool_finish (_data_->_res_, &_data_->_tmp7_);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->storage_pool_diagnosis);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->storage_pool_diagnosis = _data_->_tmp7_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->storage_pool = _data_->_tmp8_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp9_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp9_ = stdout;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp10_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp10_ = _ ("• The CPU is capable of virtualization: %s\n");
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp11_ = FALSE;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp11_ = _data_->cpu;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp12_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp12_ = boxes_yes_no (_data_->_tmp11_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp13_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp14_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp14_ = g_strdup_printf (_data_->_tmp10_, _data_->_tmp13_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp15_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp9_, "%s", _data_->_tmp15_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp15_);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp13_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp16_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp16_ = stdout;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp17_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp17_ = _ ("• The KVM module is loaded: %s\n");
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp18_ = FALSE;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp18_ = _data_->kvm;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp19_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp19_ = boxes_yes_no (_data_->_tmp18_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp20_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp21_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp21_ = g_strdup_printf (_data_->_tmp17_, _data_->_tmp20_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp22_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp16_, "%s", _data_->_tmp22_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp22_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp20_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp23_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp23_ = stdout;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp24_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp24_ = _ ("• Libvirt KVM guest available: %s\n");
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp25_ = FALSE;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp25_ = _data_->libvirt_kvm;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp26_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp26_ = boxes_yes_no (_data_->_tmp25_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp27_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp27_ = _data_->_tmp26_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp28_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp28_ = g_strdup_printf (_data_->_tmp24_, _data_->_tmp27_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp29_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp23_, "%s", _data_->_tmp29_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp29_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp27_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp30_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp30_ = stdout;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp31_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp31_ = _ ("• Boxes storage pool available: %s\n");
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp32_ = FALSE;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp32_ = _data_->storage_pool;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp33_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp33_ = boxes_yes_no (_data_->_tmp32_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp34_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp35_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp35_ = g_strdup_printf (_data_->_tmp31_, _data_->_tmp34_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp36_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp36_ = _data_->_tmp35_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp30_, "%s", _data_->_tmp36_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp36_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp34_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp37_ = NULL;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp37_ = _data_->storage_pool_diagnosis;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp38_ = 0;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp38_ = strlen (_data_->_tmp37_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp39_ = 0;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_data_->_tmp39_ != 0) {
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp40_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp40_ = stdout;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp41_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp41_ = _data_->storage_pool_diagnosis;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp42_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp42_ = boxes_indent ("    ", _data_->_tmp41_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp43_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp43_ = _data_->_tmp42_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp44_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp44_ = g_strconcat (_data_->_tmp43_, "\n", NULL);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp45_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		fprintf (_data_->_tmp40_, "%s", _data_->_tmp45_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp45_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp43_);
#line 684 "main.c"
	}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp46_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp46_ = stdout;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp47_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp47_ = _ ("• The SELinux context is default: %s\n");
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp48_ = FALSE;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp48_ = _data_->selinux_context_default;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp49_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp49_ = boxes_yes_no (_data_->_tmp48_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp50_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp50_ = _data_->_tmp49_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp51_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp51_ = g_strdup_printf (_data_->_tmp47_, _data_->_tmp50_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp52_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp52_ = _data_->_tmp51_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp46_, "%s", _data_->_tmp52_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp52_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp50_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp53_ = NULL;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp53_ = _data_->selinux_context_diagnosis;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp54_ = 0;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp54_ = strlen (_data_->_tmp53_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp55_ = 0;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp55_ = _data_->_tmp54_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_data_->_tmp55_ != 0) {
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp56_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp56_ = stdout;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp57_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp57_ = _data_->selinux_context_diagnosis;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp58_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp58_ = boxes_indent ("    ", _data_->_tmp57_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp59_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp59_ = _data_->_tmp58_;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp60_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp60_ = g_strconcat (_data_->_tmp59_, "\n", NULL);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp61_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_data_->_tmp61_ = _data_->_tmp60_;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		fprintf (_data_->_tmp56_, "%s", _data_->_tmp61_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp61_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp59_);
#line 764 "main.c"
	}
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp62_ = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp62_ = stdout;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp62_, "\n");
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp63_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp63_ = stdout;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp64_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp64_ = _ ("Report bugs to <%s>.\n");
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp63_, _data_->_tmp64_, PACKAGE_BUGREPORT);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp65_ = NULL;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp65_ = stdout;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp66_ = NULL;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp66_ = _ ("%s home page: <%s>.\n");
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp67_ = NULL;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_data_->_tmp67_ = g_get_application_name ();
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp65_, _data_->_tmp66_, _data_->_tmp67_, PACKAGE_URL);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->storage_pool_diagnosis);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_free0 (_data_->selinux_context_diagnosis);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_data_->_state_ == 0) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 804 "main.c"
	} else {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 808 "main.c"
	}
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_object_unref (_data_->_async_result);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return FALSE;
#line 814 "main.c"
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	const gchar* _tmp0_ = NULL;
	BoxesApp* app = NULL;
	BoxesApp* _tmp2_ = NULL;
	gint exit_status = 0;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gint _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	textdomain (GETTEXT_PACKAGE);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp0_ = _ ("Boxes");
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_set_application_name (_tmp0_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	parse_local_args (&args, &args_length1);
#line 840 "main.c"
	{
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		gvir_init_object_check (&args_length1, &args, &_inner_error_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		if (_inner_error_ != NULL) {
#line 846 "main.c"
			goto __catch55_g_error;
		}
	}
	goto __finally55;
	__catch55_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp1_ = NULL;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		err = _inner_error_;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_inner_error_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_tmp1_ = err->message;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_error ("main.vala:79: %s", _tmp1_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		_g_error_free0 (err);
#line 865 "main.c"
	}
	__finally55:
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	if (_inner_error_ != NULL) {
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		g_clear_error (&_inner_error_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
		return 0;
#line 876 "main.c"
	}
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp2_ = boxes_app_new ();
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	app = _tmp2_;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp3_ = args;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp3__length1 = args_length1;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_tmp4_ = boxes_app_run (app, _tmp3_, _tmp3__length1);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	exit_status = _tmp4_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_app_shutdown (app);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	boxes_app_suspend_machines (app);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	result = exit_status;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	_g_object_unref0 (app);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return result;
#line 900 "main.c"
}


int main (int argc, char ** argv) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	g_type_init ();
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/main.vala"
	return _vala_main (argv, argc);
#line 909 "main.c"
}



