/* unattended-installer.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from unattended-installer.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <osinfo/osinfo.h>
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_FILE (boxes_unattended_file_get_type ())
#define BOXES_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFile))
#define BOXES_IS_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_FILE))
#define BOXES_UNATTENDED_FILE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFileIface))

typedef struct _BoxesUnattendedFile BoxesUnattendedFile;
typedef struct _BoxesUnattendedFileIface BoxesUnattendedFileIface;

#define BOXES_TYPE_UNATTENDED_AVATAR_FILE (boxes_unattended_avatar_file_get_type ())
#define BOXES_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile))
#define BOXES_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))
#define BOXES_IS_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_IS_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_UNATTENDED_AVATAR_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))

typedef struct _BoxesUnattendedAvatarFile BoxesUnattendedAvatarFile;
typedef struct _BoxesUnattendedAvatarFileClass BoxesUnattendedAvatarFileClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_UNATTENDED_SCRIPT_FILE (boxes_unattended_script_file_get_type ())
#define BOXES_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile))
#define BOXES_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_UNATTENDED_SCRIPT_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))

typedef struct _BoxesUnattendedScriptFile BoxesUnattendedScriptFile;
typedef struct _BoxesUnattendedScriptFileClass BoxesUnattendedScriptFileClass;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_ISO_EXTRACTOR (boxes_iso_extractor_get_type ())
#define BOXES_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractor))
#define BOXES_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))
#define BOXES_IS_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_IS_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_ISO_EXTRACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))

typedef struct _BoxesISOExtractor BoxesISOExtractor;
typedef struct _BoxesISOExtractorClass BoxesISOExtractorClass;
typedef struct _BoxesUnattendedInstallerPrepareForInstallationData BoxesUnattendedInstallerPrepareForInstallationData;
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _BoxesUnattendedInstallerPrepareData BoxesUnattendedInstallerPrepareData;
typedef struct _Block60Data Block60Data;
typedef struct _BoxesUnattendedInstallerCreateDiskImageData BoxesUnattendedInstallerCreateDiskImageData;
typedef struct _BoxesUnattendedInstallerFetchUserAvatarData BoxesUnattendedInstallerFetchUserAvatarData;
typedef struct _BoxesUnattendedInstallerExtractBootFilesData BoxesUnattendedInstallerExtractBootFilesData;
typedef struct _BoxesUnattendedInstallerSetupDriversData BoxesUnattendedInstallerSetupDriversData;
typedef struct _BoxesUnattendedInstallerSetupDriversFromListData BoxesUnattendedInstallerSetupDriversFromListData;

#define BOXES_TYPE_DOWNLOADER (boxes_downloader_get_type ())
#define BOXES_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloader))
#define BOXES_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))
#define BOXES_IS_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOADER))
#define BOXES_IS_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOADER))
#define BOXES_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))

typedef struct _BoxesDownloader BoxesDownloader;
typedef struct _BoxesDownloaderClass BoxesDownloaderClass;

#define BOXES_TYPE_UNATTENDED_RAW_FILE (boxes_unattended_raw_file_get_type ())
#define BOXES_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile))
#define BOXES_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))
#define BOXES_IS_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_IS_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_UNATTENDED_RAW_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))

typedef struct _BoxesUnattendedRawFile BoxesUnattendedRawFile;
typedef struct _BoxesUnattendedRawFileClass BoxesUnattendedRawFileClass;
typedef struct _BoxesUnattendedInstallerSetupDriverData BoxesUnattendedInstallerSetupDriverData;
typedef struct _Block61Data Block61Data;

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _BoxesUnattendedFileIface {
	GTypeInterface parent_iface;
	void (*get_source_file) (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GFile* (*get_source_file_finish) (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
	const gchar* (*get_src_path) (BoxesUnattendedFile* self);
	void (*set_src_path) (BoxesUnattendedFile* self, const gchar* value);
	const gchar* (*get_dest_name) (BoxesUnattendedFile* self);
	void (*set_dest_name) (BoxesUnattendedFile* self, const gchar* value);
	BoxesUnattendedInstaller* (*get_installer) (BoxesUnattendedFile* self);
	void (*set_installer) (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value);
};

struct _BoxesUnattendedInstallerPrivate {
	gchar* product_key_format;
	GList* unattended_files;
	GList* secondary_unattended_files;
	BoxesUnattendedAvatarFile* avatar_file;
	GtkGrid* setup_grid;
	gint setup_grid_n_rows;
	GtkLabel* setup_label;
	GtkBox* setup_hbox;
	GtkSwitch* express_toggle;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkEntry* key_entry;
	gchar* timezone;
	gchar* lang;
	gchar* hostname;
	gchar* kbd;
	gboolean driver_signing;
	OsinfoDeviceList* additional_devices;
	gulong key_inserted_id;
};

struct _BoxesUnattendedInstallerPrepareForInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	gchar* vm_name;
	GCancellable* cancellable;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	const gchar* _tmp3_;
	GCancellable* _tmp4_;
	GList* _tmp5_;
	GList* unattended_file_collection;
	GList* unattended_file_it;
	BoxesUnattendedFile* _tmp6_;
	BoxesUnattendedFile* unattended_file;
	BoxesUnattendedFile* _tmp7_;
	GCancellable* _tmp8_;
	GFile* _tmp9_;
	gchar* secondary_disk_path;
	GFile* _tmp10_;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar** argv;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	gchar** _tmp20_;
	gint argv_length1;
	gint _argv_size_;
	GList* _tmp21_;
	GList* _vala1_unattended_file_collection;
	GList* _vala1_unattended_file_it;
	BoxesUnattendedFile* _tmp22_;
	BoxesUnattendedFile* _vala1_unattended_file;
	gchar* dest_path;
	BoxesUnattendedFile* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* src_path;
	BoxesUnattendedFile* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	gchar** _tmp31_;
	gint _tmp31__length1;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	gchar** _tmp37_;
	gint _tmp37__length1;
	GCancellable* _tmp38_;
	const gchar* _tmp39_;
	gboolean _tmp40_;
	OsinfoMedia* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gboolean _tmp45_;
	OsinfoMedia* _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	gboolean _tmp50_;
	BoxesISOExtractor* extractor;
	const gchar* _tmp51_;
	BoxesISOExtractor* _tmp52_;
	BoxesISOExtractor* _tmp53_;
	GCancellable* _tmp54_;
	BoxesISOExtractor* _tmp55_;
	GCancellable* _tmp56_;
	GError* _error_;
	GtkSwitch* _tmp57_;
	GError* _tmp58_;
	GError* _tmp59_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerPrepareData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	BoxesActivityProgress* _tmp0_;
	GCancellable* _tmp1_;
};

struct _Block60Data {
	int _ref_count_;
	BoxesUnattendedInstaller * self;
	GtkNotebook* notebook;
};

struct _BoxesUnattendedInstallerCreateDiskImageData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	GCancellable* cancellable;
	gchar* template_path;
	gchar* _tmp0_;
	GFile* template_file;
	GFile* _tmp1_;
	GFile* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GFile* _tmp5_;
	GCancellable* _tmp6_;
	GFile* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerFetchUserAvatarData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	GtkImage* avatar;
	BoxesFdoAccounts* _tmp0_;
	gchar* username;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* avatar_path;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* path;
	BoxesFdoAccounts* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesFdoAccountsUser* user;
	const gchar* _tmp8_;
	BoxesFdoAccountsUser* _tmp9_;
	BoxesFdoAccountsUser* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GError* _error_;
	const gchar* _tmp13_;
	GError* _tmp14_;
	const gchar* _tmp15_;
	GdkPixbuf* pixbuf;
	const gchar* _tmp16_;
	GdkPixbuf* _tmp17_;
	GtkImage* _tmp18_;
	GdkPixbuf* _tmp19_;
	OsinfoAvatarFormat* avatar_format;
	OsinfoInstallScriptList* _tmp20_;
	GList* _tmp21_;
	GList* s_collection;
	GList* s_it;
	OsinfoEntity* s;
	OsinfoInstallScript* script;
	OsinfoEntity* _tmp22_;
	OsinfoInstallScript* _tmp23_;
	OsinfoInstallScript* _tmp24_;
	OsinfoAvatarFormat* _tmp25_;
	OsinfoAvatarFormat* _tmp26_;
	OsinfoAvatarFormat* _tmp27_;
	OsinfoAvatarFormat* _tmp28_;
	BoxesUnattendedAvatarFile* _tmp29_;
	const gchar* _tmp30_;
	OsinfoAvatarFormat* _tmp31_;
	BoxesUnattendedAvatarFile* _tmp32_;
	BoxesUnattendedAvatarFile* _tmp33_;
	GError* _vala1__error_;
	const gchar* _tmp34_;
	GError* _tmp35_;
	const gchar* _tmp36_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerExtractBootFilesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesISOExtractor* extractor;
	GCancellable* cancellable;
	gchar* src_path;
	BoxesISOExtractor* _tmp0_;
	OsinfoMedia* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GFile* src_file;
	const gchar* _tmp7_;
	GFile* _tmp8_;
	GFile* _tmp9_;
	GFile* _tmp10_;
	GCancellable* _tmp11_;
	gchar* _tmp12_;
	BoxesISOExtractor* _tmp13_;
	OsinfoMedia* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	GFile* _tmp21_;
	GFile* _tmp22_;
	GFile* _tmp23_;
	GCancellable* _tmp24_;
	GError * _inner_error_;
};

typedef void (*BoxesUnattendedInstallerAddUnattendedFileFunc) (BoxesUnattendedFile* file, void* user_data);
struct _BoxesUnattendedInstallerSetupDriversData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	BoxesActivityProgress* _tmp0_;
	const gchar* _tmp1_;
	GList* scripts;
	GList* _tmp2_;
	GList* drivers;
	GList* _tmp3_;
	GList* _tmp4_;
	gboolean _tmp5_;
	GList* _tmp6_;
	guint _tmp7_;
	GList* _tmp8_;
	guint _tmp9_;
	gboolean _tmp10_;
	BoxesActivityProgress* drivers_progress;
	BoxesActivityProgress* _tmp11_;
	BoxesActivityProgress* _tmp12_;
	GList* _tmp13_;
	BoxesActivityProgress* _tmp14_;
	GCancellable* _tmp15_;
	BoxesActivityProgress* _tmp16_;
	GList* _tmp17_;
	GList* _tmp18_;
	GList* _tmp19_;
	gboolean _tmp20_;
	GList* _tmp21_;
	guint _tmp22_;
	GList* _tmp23_;
	guint _tmp24_;
	gboolean _tmp25_;
	BoxesActivityProgress* _vala1_drivers_progress;
	BoxesActivityProgress* _tmp26_;
	BoxesActivityProgress* _tmp27_;
	GList* _tmp28_;
	BoxesActivityProgress* _tmp29_;
	GCancellable* _tmp30_;
	BoxesActivityProgress* _tmp31_;
};

struct _BoxesUnattendedInstallerSetupDriversFromListData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	GList* drivers;
	BoxesActivityProgress* progress;
	BoxesUnattendedInstallerAddUnattendedFileFunc add_func;
	gpointer add_func_target;
	GCancellable* cancellable;
	gdouble driver_progress_scale;
	GList* _tmp0_;
	guint _tmp1_;
	GList* _tmp2_;
	GList* driver_collection;
	GList* driver_it;
	OsinfoDeviceDriver* _tmp3_;
	OsinfoDeviceDriver* driver;
	BoxesActivityProgress* driver_progress;
	BoxesActivityProgress* _tmp4_;
	gdouble _tmp5_;
	BoxesActivityProgress* _tmp6_;
	OsinfoDeviceDriver* _tmp7_;
	BoxesActivityProgress* _tmp8_;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp9_;
	void* _tmp9__target;
	GCancellable* _tmp10_;
	OsinfoDeviceList* _tmp11_;
	OsinfoDeviceDriver* _tmp12_;
	OsinfoDeviceList* _tmp13_;
	GError* e;
	OsinfoDeviceDriver* _tmp14_;
	const gchar* _tmp15_;
	GError* _tmp16_;
	const gchar* _tmp17_;
	BoxesActivityProgress* _tmp18_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerSetupDriverData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	OsinfoDeviceDriver* driver;
	BoxesActivityProgress* progress;
	BoxesUnattendedInstallerAddUnattendedFileFunc add_func;
	gpointer add_func_target;
	GCancellable* cancellable;
	BoxesDownloader* downloader;
	BoxesDownloader* _tmp0_;
	GList* driver_files;
	gchar* location;
	OsinfoDeviceDriver* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* location_checksum;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	GList* files;
	OsinfoDeviceDriver* _tmp6_;
	GList* _tmp7_;
	gdouble file_progress_scale;
	GList* _tmp8_;
	guint _tmp9_;
	GList* _tmp10_;
	GList* filename_collection;
	GList* filename_it;
	const gchar* filename;
	gchar* file_uri;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GFile* file;
	const gchar* _tmp17_;
	GFile* _tmp18_;
	gchar* cached_path;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GFile* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	BoxesActivityProgress* file_progress;
	BoxesActivityProgress* _tmp29_;
	gdouble _tmp30_;
	BoxesActivityProgress* _tmp31_;
	GFile* _tmp32_;
	BoxesDownloader* _tmp33_;
	GFile* _tmp34_;
	const gchar* _tmp35_;
	BoxesActivityProgress* _tmp36_;
	GFile* _tmp37_;
	BoxesActivityProgress* _tmp38_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	BoxesUnattendedRawFile* _tmp41_;
	GList* _tmp42_;
	GList* driver_file_collection;
	GList* driver_file_it;
	BoxesUnattendedFile* _tmp43_;
	BoxesUnattendedFile* driver_file;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp44_;
	void* _tmp44__target;
	BoxesUnattendedFile* _tmp45_;
	GError * _inner_error_;
};

typedef gboolean (*BoxesUnattendedInstallerDriverInstallableFunc) (OsinfoDeviceDriver* driver, void* user_data);
typedef OsinfoDeviceDriverSigningReq (*BoxesUnattendedInstallerScriptDriverSigningReqFunc) (OsinfoInstallScript* script, void* user_data);
struct _Block61Data {
	int _ref_count_;
	BoxesUnattendedInstaller * self;
	gboolean signing_required;
	gboolean driver_signing_mutable;
	BoxesUnattendedInstallerDriverInstallableFunc installable_func;
	gpointer installable_func_target;
};

typedef gboolean (*BoxesUnattendedInstallerDriverTestFunction) (OsinfoDeviceDriver* driver, void* user_data);
typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

typedef gboolean (*BoxesUnattendedInstallerScriptTestFunction) (OsinfoInstallScript* script, void* user_data);

static gpointer boxes_unattended_installer_parent_class = NULL;
static BoxesFdoAccounts* boxes_unattended_installer_accounts;
static BoxesFdoAccounts* boxes_unattended_installer_accounts = NULL;

GType boxes_installer_media_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_file_get_type (void) G_GNUC_CONST;
GType boxes_unattended_avatar_file_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_INSTALLER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerPrivate))
enum  {
	BOXES_UNATTENDED_INSTALLER_DUMMY_PROPERTY,
	BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION,
	BOXES_UNATTENDED_INSTALLER_READY_FOR_EXPRESS,
	BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE,
	BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES,
	BOXES_UNATTENDED_INSTALLER_EXPRESS_INSTALL,
	BOXES_UNATTENDED_INSTALLER_USERNAME,
	BOXES_UNATTENDED_INSTALLER_PASSWORD,
	BOXES_UNATTENDED_INSTALLER_HIDDEN_PASSWORD
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static gchar* boxes_unattended_installer_escape_mkisofs_path (const gchar* path);
BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesInstallerMedia* boxes_installer_media_new (void);
BoxesInstallerMedia* boxes_installer_media_construct (GType object_type);
static void boxes_unattended_installer_add_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file);
BoxesUnattendedScriptFile* boxes_unattended_script_file_new (BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name);
BoxesUnattendedScriptFile* boxes_unattended_script_file_construct (GType object_type, BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name);
GType boxes_unattended_script_file_get_type (void) G_GNUC_CONST;
gchar* boxes_get_timezone (void);
static gchar* boxes_unattended_installer_get_preferred_language (BoxesUnattendedInstaller* self);
static gchar* boxes_unattended_installer_get_product_key_format (BoxesUnattendedInstaller* self);
static void boxes_unattended_installer_setup_ui (BoxesUnattendedInstaller* self);
static void boxes_unattended_installer_real_prepare_to_continue_installation (BoxesInstallerMedia* base, const gchar* vm_name);
gchar* boxes_unattended_installer_get_user_unattended (BoxesUnattendedInstaller* self, const gchar* suffix);
static void boxes_unattended_installer_real_prepare_for_installation_data_free (gpointer _data);
static void boxes_unattended_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_real_prepare_for_installation_co (BoxesUnattendedInstallerPrepareForInstallationData* _data_);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
static void boxes_unattended_installer_create_disk_image (BoxesUnattendedInstaller* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_create_disk_image_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_unattended_file_copy (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_unattended_file_copy_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
const gchar* boxes_unattended_file_get_dest_name (BoxesUnattendedFile* self);
const gchar* boxes_unattended_file_get_src_path (BoxesUnattendedFile* self);
static void _vala_array_add8 (gchar*** array, int* length, int* size, gchar* value);
GType boxes_iso_extractor_get_type (void) G_GNUC_CONST;
BoxesISOExtractor* boxes_iso_extractor_new (const gchar* iso_path);
BoxesISOExtractor* boxes_iso_extractor_construct (GType object_type, const gchar* iso_path);
void boxes_iso_extractor_mount_media (BoxesISOExtractor* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_iso_extractor_mount_media_finish (BoxesISOExtractor* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_extract_boot_files (BoxesUnattendedInstaller* self, BoxesISOExtractor* extractor, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_extract_boot_files_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
static void boxes_unattended_installer_real_setup_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain);
void boxes_installer_media_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static GVirConfigDomainDisk* boxes_unattended_installer_get_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format);
static GVirConfigDomainDisk* boxes_unattended_installer_get_secondary_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format);
void boxes_unattended_installer_configure_install_script (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
gchar* boxes_unattended_installer_get_password (BoxesUnattendedInstaller* self);
const gchar* boxes_unattended_installer_get_username (BoxesUnattendedInstaller* self);
gboolean boxes_installer_media_get_supports_virtio_disk (BoxesInstallerMedia* self);
static gchar* boxes_unattended_installer_device_name_to_path (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format, const gchar* name);
static void boxes_unattended_installer_real_setup_post_install_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain);
static void boxes_unattended_installer_remove_disk_from_domain_config (BoxesUnattendedInstaller* self, GVirConfigDomain* domain, const gchar* disk_path);
void boxes_installer_media_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static void boxes_unattended_installer_real_populate_setup_vbox (BoxesInstallerMedia* base, GtkBox* setup_vbox);
static GList* boxes_unattended_installer_real_get_vm_properties (BoxesInstallerMedia* base);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
gboolean boxes_unattended_installer_get_express_install (BoxesUnattendedInstaller* self);
gchar* boxes_unattended_installer_get_hidden_password (BoxesUnattendedInstaller* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static void boxes_unattended_installer_real_set_direct_boot_params (BoxesInstallerMedia* base, GVirConfigDomainOs* domain_os);
static void boxes_unattended_installer_real_clean_up (BoxesInstallerMedia* base);
static void boxes_unattended_installer_real_clean_up_preparation_cache (BoxesInstallerMedia* base);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
static void boxes_unattended_installer_real_prepare_data_free (gpointer _data);
static void boxes_unattended_installer_real_prepare (BoxesInstallerMedia* base, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_real_prepare_co (BoxesUnattendedInstallerPrepareData* _data_);
static void boxes_unattended_installer_setup_drivers (BoxesUnattendedInstaller* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_setup_drivers_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static void boxes_unattended_installer_prepare_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block60Data* block60_data_ref (Block60Data* _data60_);
static void block60_data_unref (void * _userdata_);
static void __lambda41_ (BoxesUnattendedInstaller* self);
static void ___lambda41__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_unattended_installer_fetch_user_avatar (BoxesUnattendedInstaller* self, GtkImage* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_fetch_user_avatar_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static GtkEntry* boxes_unattended_installer_create_input_entry (BoxesUnattendedInstaller* self, const gchar* text, gboolean mandatory, gboolean visibility);
static void __lambda43_ (BoxesUnattendedInstaller* self);
gboolean boxes_unattended_installer_get_ready_for_express (BoxesUnattendedInstaller* self);
static void ___lambda43__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void __lambda44_ (Block60Data* _data60_);
static void ___lambda44__gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean __lambda45_ (Block60Data* _data60_);
static gboolean ___lambda45__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void __lambda46_ (BoxesUnattendedInstaller* self);
static void ___lambda46__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void __lambda47_ (BoxesUnattendedInstaller* self);
static void ___lambda47__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_installer_on_key_text_inserted (BoxesUnattendedInstaller* self, const gchar* text, gint text_length, gint* position);
static void _boxes_unattended_installer_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
static void boxes_unattended_installer_add_secondary_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file);
static void ___lambda42_ (BoxesUnattendedInstaller* self);
static void ____lambda42__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_unattended_installer_create_disk_image_data_free (gpointer _data);
static gboolean boxes_unattended_installer_create_disk_image_co (BoxesUnattendedInstallerCreateDiskImageData* _data_);
static void boxes_unattended_installer_create_disk_image_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_fetch_user_avatar_data_free (gpointer _data);
static gboolean boxes_unattended_installer_fetch_user_avatar_co (BoxesUnattendedInstallerFetchUserAvatarData* _data_);
static void boxes_unattended_installer_fetch_user_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
static void boxes_unattended_installer_extract_boot_files_data_free (gpointer _data);
static gboolean boxes_unattended_installer_extract_boot_files_co (BoxesUnattendedInstallerExtractBootFilesData* _data_);
gchar* boxes_iso_extractor_get_absolute_path (BoxesISOExtractor* self, const gchar* relative_path, GError** error);
void boxes_copy_file (GFile* src_file, GFile* dest_file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_extract_boot_files_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_setup_drivers_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_drivers_co (BoxesUnattendedInstallerSetupDriversData* _data_);
static GList* boxes_unattended_installer_get_pre_installer_scripts (BoxesUnattendedInstaller* self);
static GList* boxes_unattended_installer_get_pre_installable_drivers (BoxesUnattendedInstaller* self, GList* preinst_scripts);
static void boxes_unattended_installer_setup_drivers_from_list (BoxesUnattendedInstaller* self, GList* drivers, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_setup_drivers_from_list_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static void _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self);
static void boxes_unattended_installer_setup_drivers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static GList* boxes_unattended_installer_get_post_installer_scripts (BoxesUnattendedInstaller* self);
static GList* boxes_unattended_installer_get_post_installable_drivers (BoxesUnattendedInstaller* self, GList* postinst_scripts);
static void _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self);
static void boxes_unattended_installer_setup_drivers_from_list_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_drivers_from_list_co (BoxesUnattendedInstallerSetupDriversFromListData* _data_);
static void boxes_unattended_installer_setup_driver (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_setup_driver_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_setup_drivers_from_list_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_setup_driver_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_driver_co (BoxesUnattendedInstallerSetupDriverData* _data_);
GType boxes_downloader_get_type (void) G_GNUC_CONST;
BoxesDownloader* boxes_downloader_get_instance (void);
void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_setup_driver_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesUnattendedRawFile* boxes_unattended_raw_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
BoxesUnattendedRawFile* boxes_unattended_raw_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
GType boxes_unattended_raw_file_get_type (void) G_GNUC_CONST;
static GList* boxes_unattended_installer_get_installable_drivers (BoxesUnattendedInstaller* self, GList* scripts, BoxesUnattendedInstallerDriverInstallableFunc installable_func, void* installable_func_target, BoxesUnattendedInstallerScriptDriverSigningReqFunc signing_req_func, void* signing_req_func_target);
static gboolean __lambda50_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver);
static gboolean ___lambda50__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self);
static OsinfoDeviceDriverSigningReq __lambda51_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static OsinfoDeviceDriverSigningReq ___lambda51__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self);
static gboolean __lambda58_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver);
static gboolean ___lambda58__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self);
static OsinfoDeviceDriverSigningReq __lambda59_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static OsinfoDeviceDriverSigningReq ___lambda59__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self);
static Block61Data* block61_data_ref (Block61Data* _data61_);
static void block61_data_unref (void * _userdata_);
static GList* boxes_unattended_installer_get_drivers (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerDriverTestFunction test_func, void* test_func_target);
static gboolean __lambda49_ (Block61Data* _data61_, OsinfoDeviceDriver* driver);
static gboolean ___lambda49__boxes_unattended_installer_driver_test_function (OsinfoDeviceDriver* driver, gpointer self);
static void _g_free0_ (gpointer var);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
static GList* boxes_unattended_installer_get_scripts (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerScriptTestFunction test_func, void* test_func_target);
static gboolean __lambda48_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static gboolean ___lambda48__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self);
static gboolean __lambda57_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static gboolean ___lambda57__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self);
static gchar** _vala_array_dup4 (gchar** self, int length);
BoxesUnattendedInstaller* boxes_unattended_installer_new (void);
BoxesUnattendedInstaller* boxes_unattended_installer_construct (GType object_type);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
OsinfoDeviceList* boxes_installer_media_get_supported_devices (BoxesInstallerMedia* self);
static GObject * boxes_unattended_installer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_unattended_installer_finalize (GObject* obj);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static void _vala_boxes_unattended_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void _g_object_unref0_ (gpointer var) {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 822 "unattended-installer.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_free (self);
#line 831 "unattended-installer.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1241 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1241 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 844 "unattended-installer.c"
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp0_ = old;
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_g_free0 (_tmp2_);
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		regex = _tmp4_;
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		if (_inner_error_ != NULL) {
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 874 "unattended-installer.c"
				goto __catch73_g_regex_error;
			}
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1243 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			return NULL;
#line 883 "unattended-installer.c"
		}
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp6_ = regex;
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp7_ = replacement;
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) (-1), 0, _tmp7_, 0, &_inner_error_);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp5_ = _tmp8_;
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		if (_inner_error_ != NULL) {
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 899 "unattended-installer.c"
				goto __catch73_g_regex_error;
			}
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
			return NULL;
#line 910 "unattended-installer.c"
		}
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1244 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		return result;
#line 918 "unattended-installer.c"
	}
	goto __finally73;
	__catch73_g_regex_error:
	{
		GError* e = NULL;
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1246 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 932 "unattended-installer.c"
	}
	__finally73:
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	if (_inner_error_ != NULL) {
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1242 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
		return NULL;
#line 943 "unattended-installer.c"
	}
}


static gchar* boxes_unattended_installer_escape_mkisofs_path (const gchar* path) {
	gchar* result = NULL;
	gchar* str = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = path;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = string_replace (_tmp0_, "\\", "\\\\");
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	str = _tmp1_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = string_replace (str, "=", "\\=");
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp2_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (str);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 970 "unattended-installer.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self ? g_object_ref (self) : NULL;
#line 977 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error) {
	BoxesUnattendedInstaller * self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
	OsinfoOs* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	OsinfoMedia* _tmp4_ = NULL;
	OsinfoMedia* _tmp5_ = NULL;
	BoxesInstallerMedia* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	BoxesInstallerMedia* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	BoxesInstallerMedia* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	BoxesInstallerMedia* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	BoxesInstallerMedia* _tmp17_ = NULL;
	OsinfoResources* _tmp18_ = NULL;
	OsinfoResources* _tmp19_ = NULL;
	OsinfoInstallScriptList* _tmp20_ = NULL;
	OsinfoInstallScriptList* _tmp21_ = NULL;
	OsinfoInstallConfig* _tmp22_ = NULL;
	OsinfoInstallScriptList* _tmp23_ = NULL;
	GList* _tmp24_ = NULL;
	OsinfoDeviceList* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	const gchar* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (scripts != NULL, NULL);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) boxes_installer_media_construct (object_type);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = media;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_->os;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->os);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->os = _tmp2_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = media;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _tmp3_->os_media;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->os_media);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->os_media = _tmp5_;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = media;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_->label;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->label);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->label = _tmp8_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = media;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _tmp9_->device_file;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->device_file);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->device_file = _tmp11_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = media;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_->from_image;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->from_image = _tmp13_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = media;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = _tmp14_->mount_point;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->mount_point);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->mount_point = _tmp16_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = media;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp18_ = _tmp17_->resources;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = _g_object_ref0 (_tmp18_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->resources);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->resources = _tmp19_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp20_ = scripts;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = _g_object_ref0 (_tmp20_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->scripts);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->scripts = _tmp21_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp22_ = osinfo_install_config_new ("http://live.gnome.org/Boxes/unattended");
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->config);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->config = _tmp22_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = NULL;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = NULL;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp23_ = scripts;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp24_ = osinfo_list_get_elements ((OsinfoList*) _tmp23_);
#line 1112 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp24_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 1120 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 1124 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp25_ = NULL;
				OsinfoInstallScript* _tmp26_ = NULL;
				gchar* filename = NULL;
				OsinfoInstallScript* _tmp27_ = NULL;
				const gchar* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				OsinfoInstallScript* _tmp30_ = NULL;
				const gchar* _tmp31_ = NULL;
				BoxesUnattendedScriptFile* _tmp32_ = NULL;
				BoxesUnattendedScriptFile* _tmp33_ = NULL;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp25_ = s;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp25_) : NULL);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp26_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp27_ = script;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp28_ = osinfo_install_script_get_expected_filename (_tmp27_);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp29_ = g_strdup (_tmp28_);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				filename = _tmp29_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp30_ = script;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp31_ = filename;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp32_ = boxes_unattended_script_file_new (self, _tmp30_, _tmp31_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp33_ = _tmp32_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_unattended_installer_add_unattended_file (self, (BoxesUnattendedFile*) _tmp33_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_tmp33_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (filename);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 1167 "unattended-installer.c"
			}
		}
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 1172 "unattended-installer.c"
	}
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp34_ = osinfo_devicelist_new ();
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->additional_devices);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->additional_devices = _tmp34_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp35_ = boxes_get_timezone ();
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->timezone);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->timezone = _tmp35_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = boxes_unattended_installer_get_preferred_language (self);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->lang);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->lang = _tmp36_;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp37_ = self->priv->lang;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp38_ = g_strdup (_tmp37_);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->kbd);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->kbd = _tmp38_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp39_ = boxes_unattended_installer_get_product_key_format (self);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->product_key_format);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->product_key_format = _tmp39_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_ui (self);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self;
#line 1210 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error) {
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return boxes_unattended_installer_construct_from_media (BOXES_TYPE_UNATTENDED_INSTALLER, media, scripts, error);
#line 1217 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_to_continue_installation (BoxesInstallerMedia* base, const gchar* vm_name) {
	BoxesUnattendedInstaller * self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* path = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	gboolean _tmp10_ = FALSE;
	OsinfoMedia* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp20_ = FALSE;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (vm_name != NULL);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = vm_name;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = string_replace (_tmp0_, " ", "-");
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->hostname);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->hostname = _tmp1_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = boxes_unattended_installer_get_user_unattended (self, "unattended.img");
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	path = _tmp2_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = path;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = g_file_new_for_path (_tmp3_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->disk_file);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->disk_file = _tmp4_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->priv->secondary_unattended_files;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_list_length (_tmp5_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 1268 "unattended-installer.c"
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GFile* _tmp9_ = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = boxes_unattended_installer_get_user_unattended (self, "unattended.iso");
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp7_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = path;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = g_file_new_for_path (_tmp8_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->secondary_disk_file);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->secondary_disk_file = _tmp9_;
#line 1286 "unattended-installer.c"
	}
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = ((BoxesInstallerMedia*) self)->os_media;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_tmp11_, "kernel-path", &_tmp12_, NULL);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = _tmp13_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = _tmp14_ != NULL;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp14_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp15_) {
#line 1302 "unattended-installer.c"
		OsinfoMedia* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp16_ = ((BoxesInstallerMedia*) self)->os_media;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_get (_tmp16_, "initrd-path", &_tmp17_, NULL);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = _tmp17_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = _tmp18_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = _tmp19_ != NULL;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp19_);
#line 1319 "unattended-installer.c"
	} else {
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = FALSE;
#line 1323 "unattended-installer.c"
	}
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp20_ = _tmp10_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp20_) {
#line 1329 "unattended-installer.c"
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GFile* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		GFile* _tmp26_ = NULL;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp21_ = boxes_unattended_installer_get_user_unattended (self, "kernel");
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp21_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp22_ = path;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->kernel_file);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->kernel_file = _tmp23_;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = boxes_unattended_installer_get_user_unattended (self, "initrd");
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp24_;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp25_ = path;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp26_ = g_file_new_for_path (_tmp25_);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->initrd_file);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->initrd_file = _tmp26_;
#line 1364 "unattended-installer.c"
	}
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (path);
#line 1368 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation_data_free (gpointer _data) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->vm_name);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerPrepareForInstallationData, _data_);
#line 1383 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstaller * self;
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerPrepareForInstallationData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_real_prepare_for_installation);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_real_prepare_for_installation_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = vm_name;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->vm_name);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->vm_name = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_for_installation_co (_data_);
#line 1425 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation_finish (BoxesInstallerMedia* base, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 1435 "unattended-installer.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1439 "unattended-installer.c"
}


static void boxes_unattended_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_for_installation_co (_data_);
#line 1453 "unattended-installer.c"
}


static void _vala_array_add8 (gchar*** array, int* length, int* size, gchar* value) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if ((*length) == (*size)) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 1464 "unattended-installer.c"
	}
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[(*length)++] = value;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[*length] = NULL;
#line 1470 "unattended-installer.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self ? g_error_copy (self) : NULL;
#line 1477 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_prepare_for_installation_co (BoxesUnattendedInstallerPrepareForInstallationData* _data_) {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 1486 "unattended-installer.c"
		goto _state_0;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 1490 "unattended-installer.c"
		goto _state_1;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 1494 "unattended-installer.c"
		goto _state_2;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 3:
#line 1498 "unattended-installer.c"
		goto _state_3;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 4:
#line 1502 "unattended-installer.c"
		goto _state_4;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 5:
#line 1506 "unattended-installer.c"
		goto _state_5;
		default:
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 1511 "unattended-installer.c"
	}
	_state_0:
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->self->priv->express_toggle;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = FALSE;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = gtk_switch_get_active (_data_->_tmp0_);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = FALSE;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_data_->_tmp2_) {
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:167: Unattended installation disabled.");
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1534 "unattended-installer.c"
		} else {
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1538 "unattended-installer.c"
		}
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 1544 "unattended-installer.c"
	}
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->vm_name;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_installer_media_prepare_to_continue_installation ((BoxesInstallerMedia*) _data_->self, _data_->_tmp3_);
#line 1552 "unattended-installer.c"
	{
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp4_ = NULL;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp4_ = _data_->cancellable;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_create_disk_image (_data_->self, _data_->_tmp4_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 1564 "unattended-installer.c"
		_state_1:
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_create_disk_image_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1570 "unattended-installer.c"
			goto __catch74_g_error;
		}
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = NULL;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = _data_->self->priv->unattended_files;
#line 1577 "unattended-installer.c"
		{
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->unattended_file_collection = _data_->_tmp5_;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (_data_->unattended_file_it = _data_->unattended_file_collection; _data_->unattended_file_it != NULL; _data_->unattended_file_it = _data_->unattended_file_it->next) {
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = NULL;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->unattended_file_it->data);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->unattended_file = _data_->_tmp6_;
#line 1589 "unattended-installer.c"
				{
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = _data_->unattended_file;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = _data_->cancellable;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_state_ = 2;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_file_copy (_data_->_tmp7_, _data_->_tmp8_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 1605 "unattended-installer.c"
					_state_2:
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_file_copy_finish (_data_->_tmp7_, _data_->_res_, &_data_->_inner_error_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_inner_error_ != NULL) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->unattended_file);
#line 1613 "unattended-installer.c"
						goto __catch74_g_error;
					}
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->unattended_file);
#line 1618 "unattended-installer.c"
				}
			}
		}
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = NULL;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = _data_->self->secondary_disk_file;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp9_ != NULL) {
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp10_ = NULL;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp10_ = _data_->self->secondary_disk_file;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp11_ = NULL;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp11_ = g_file_get_path (_data_->_tmp10_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->secondary_disk_path = _data_->_tmp11_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp12_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp12_ = _data_->secondary_disk_path;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:183: Creating secondary disk image '%s'...", _data_->_tmp12_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp13_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp13_ = g_strdup ("mkisofs");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp14_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp14_ = g_strdup ("-graft-points");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp15_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp15_ = g_strdup ("-J");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp16_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp16_ = g_strdup ("-rock");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp17_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp17_ = g_strdup ("-o");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp18_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp18_ = _data_->secondary_disk_path;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp19_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp19_ = g_strdup (_data_->_tmp18_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_ = g_new0 (gchar*, 6 + 1);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[0] = _data_->_tmp13_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[1] = _data_->_tmp14_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[2] = _data_->_tmp15_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[3] = _data_->_tmp16_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[4] = _data_->_tmp17_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp20_[5] = _data_->_tmp19_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv_length1 = 0;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_argv_size_ = 0;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv = _data_->_tmp20_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv_length1 = 6;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_argv_size_ = _data_->argv_length1;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp21_ = NULL;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp21_ = _data_->self->priv->secondary_unattended_files;
#line 1702 "unattended-installer.c"
			{
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_vala1_unattended_file_collection = _data_->_tmp21_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				for (_data_->_vala1_unattended_file_it = _data_->_vala1_unattended_file_collection; _data_->_vala1_unattended_file_it != NULL; _data_->_vala1_unattended_file_it = _data_->_vala1_unattended_file_it->next) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = NULL;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->_vala1_unattended_file_it->data);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_vala1_unattended_file = _data_->_tmp22_;
#line 1714 "unattended-installer.c"
					{
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp23_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp23_ = _data_->_vala1_unattended_file;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp24_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp24_ = boxes_unattended_file_get_dest_name (_data_->_tmp23_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp25_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp25_ = _data_->_tmp24_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp26_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp26_ = boxes_unattended_installer_escape_mkisofs_path (_data_->_tmp25_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->dest_path = _data_->_tmp26_;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp27_ = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp27_ = _data_->_vala1_unattended_file;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp28_ = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp28_ = boxes_unattended_file_get_src_path (_data_->_tmp27_);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp29_ = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp29_ = _data_->_tmp28_;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp30_ = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp30_ = boxes_unattended_installer_escape_mkisofs_path (_data_->_tmp29_);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->src_path = _data_->_tmp30_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp31_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp31__length1 = 0;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp31_ = _data_->argv;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp31__length1 = _data_->argv_length1;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp32_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp32_ = _data_->dest_path;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp33_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp33_ = g_strconcat (_data_->_tmp32_, "=", NULL);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp34_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp34_ = _data_->_tmp33_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp35_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp35_ = _data_->src_path;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp36_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp36_ = g_strconcat (_data_->_tmp34_, _data_->_tmp35_, NULL);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_vala_array_add8 (&_data_->argv, &_data_->argv_length1, &_data_->_argv_size_, _data_->_tmp36_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->_tmp34_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->src_path);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->dest_path);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->_vala1_unattended_file);
#line 1790 "unattended-installer.c"
					}
				}
			}
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp37_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp37__length1 = 0;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp37_ = _data_->argv;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp37__length1 = _data_->argv_length1;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp38_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp38_ = _data_->cancellable;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_state_ = 3;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_exec (_data_->_tmp37_, _data_->_tmp37__length1, _data_->_tmp38_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 1812 "unattended-installer.c"
			_state_3:
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_exec_finish (_data_->_res_, NULL, NULL, &_data_->_inner_error_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_ != NULL) {
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->secondary_disk_path);
#line 1822 "unattended-installer.c"
				goto __catch74_g_error;
			}
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp39_ = NULL;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp39_ = _data_->secondary_disk_path;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:193: Created secondary disk image '%s'...", _data_->_tmp39_);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->secondary_disk_path);
#line 1835 "unattended-installer.c"
		}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp41_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp41_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp42_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_get (_data_->_tmp41_, "kernel-path", &_data_->_tmp42_, NULL);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp43_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp43_ = _data_->_tmp42_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp44_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp44_ = _data_->_tmp43_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp45_ = FALSE;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp45_ = _data_->_tmp44_ != NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->_tmp44_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp45_) {
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp46_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp46_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp47_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_object_get (_data_->_tmp46_, "initrd-path", &_data_->_tmp47_, NULL);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp48_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp48_ = _data_->_tmp47_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp49_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp49_ = _data_->_tmp48_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp40_ = _data_->_tmp49_ != NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->_tmp49_);
#line 1881 "unattended-installer.c"
		} else {
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp40_ = FALSE;
#line 1885 "unattended-installer.c"
		}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp50_ = FALSE;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp50_ = _data_->_tmp40_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp50_) {
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp51_ = NULL;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp51_ = ((BoxesInstallerMedia*) _data_->self)->device_file;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52_ = NULL;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52_ = boxes_iso_extractor_new (_data_->_tmp51_);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->extractor = _data_->_tmp52_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp53_ = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp53_ = _data_->extractor;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp54_ = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp54_ = _data_->cancellable;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_state_ = 4;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_iso_extractor_mount_media (_data_->_tmp53_, _data_->_tmp54_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 1917 "unattended-installer.c"
			_state_4:
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_iso_extractor_mount_media_finish (_data_->_tmp53_, _data_->_res_, &_data_->_inner_error_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_ != NULL) {
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->extractor);
#line 1925 "unattended-installer.c"
				goto __catch74_g_error;
			}
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp55_ = NULL;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp55_ = _data_->extractor;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp56_ = NULL;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp56_ = _data_->cancellable;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_state_ = 5;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_extract_boot_files (_data_->self, _data_->_tmp55_, _data_->_tmp56_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 1942 "unattended-installer.c"
			_state_5:
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_extract_boot_files_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_ != NULL) {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->extractor);
#line 1950 "unattended-installer.c"
				goto __catch74_g_error;
			}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->extractor);
#line 1955 "unattended-installer.c"
		}
	}
	goto __finally74;
	__catch74_g_error:
	{
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_installer_media_clean_up ((BoxesInstallerMedia*) _data_->self);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp57_ = NULL;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp57_ = _data_->self->priv->express_toggle;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gtk_switch_set_active (_data_->_tmp57_, FALSE);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp58_ = NULL;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp58_ = _data_->_error_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp59_ = NULL;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp59_ = _g_error_copy0 (_data_->_tmp58_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = _data_->_tmp59_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_error_);
#line 1985 "unattended-installer.c"
		goto __finally74;
	}
	__finally74:
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1999 "unattended-installer.c"
		} else {
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2003 "unattended-installer.c"
		}
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 2009 "unattended-installer.c"
	}
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2015 "unattended-installer.c"
	} else {
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2019 "unattended-installer.c"
	}
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 2025 "unattended-installer.c"
}


static void boxes_unattended_installer_real_setup_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain) {
	BoxesUnattendedInstaller * self;
	GVirConfigDomain* _tmp0_ = NULL;
	GtkSwitch* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GFile* _tmp4_ = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp5_ = NULL;
	GVirConfigDomain* _tmp6_ = NULL;
	GVirConfigDomainDisk* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = domain;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->setup_domain_config (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia), _tmp0_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->priv->express_toggle;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = gtk_switch_get_active (_tmp1_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp3_) {
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 2059 "unattended-installer.c"
	}
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = self->disk_file;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (_tmp4_ != NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = boxes_unattended_installer_get_unattended_disk_config (self, OSINFO_PATH_FORMAT_UNIX);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp5_;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = domain;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = disk;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_add_device (_tmp6_, (GVirConfigDomainDevice*) _tmp7_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = self->secondary_disk_file;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp8_ != NULL) {
#line 2079 "unattended-installer.c"
		GVirConfigDomainDisk* _tmp9_ = NULL;
		GVirConfigDomain* _tmp10_ = NULL;
		GVirConfigDomainDisk* _tmp11_ = NULL;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = boxes_unattended_installer_get_secondary_unattended_disk_config (self, OSINFO_PATH_FORMAT_UNIX);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (disk);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		disk = _tmp9_;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = domain;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = disk;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_add_device (_tmp10_, (GVirConfigDomainDevice*) _tmp11_);
#line 2095 "unattended-installer.c"
	}
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (disk);
#line 2099 "unattended-installer.c"
}


void boxes_unattended_installer_configure_install_script (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gboolean _tmp20_ = FALSE;
	GtkEntry* _tmp21_ = NULL;
	gboolean _tmp25_ = FALSE;
	const gchar* _tmp30_ = NULL;
	OsinfoInstallConfig* _tmp33_ = NULL;
	const gchar* _tmp34_ = NULL;
	OsinfoInstallConfig* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	OsinfoInstallConfig* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	OsinfoInstallConfig* _tmp39_ = NULL;
	OsinfoMedia* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	OsinfoOs* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	const gchar* _tmp46_ = NULL;
	GVirConfigDomainDisk* disk_config = NULL;
	OsinfoInstallScript* _tmp53_ = NULL;
	OsinfoPathFormat _tmp54_ = 0;
	OsinfoPathFormat _tmp55_ = 0;
	GVirConfigDomainDisk* _tmp56_ = NULL;
	gchar* device_path = NULL;
	OsinfoInstallScript* _tmp57_ = NULL;
	OsinfoPathFormat _tmp58_ = 0;
	OsinfoPathFormat _tmp59_ = 0;
	GVirConfigDomainDisk* _tmp60_ = NULL;
	const gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	OsinfoInstallConfig* _tmp63_ = NULL;
	const gchar* _tmp64_ = NULL;
	BoxesUnattendedAvatarFile* _tmp65_ = NULL;
	OsinfoInstallConfig* _tmp80_ = NULL;
	OsinfoInstallConfig* _tmp81_ = NULL;
	const gchar* _tmp82_ = NULL;
	GFile* _tmp83_ = NULL;
	OsinfoInstallConfig* _tmp96_ = NULL;
	gboolean _tmp97_ = FALSE;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (script != NULL);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_password (self);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_ != NULL;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp2_);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp3_) {
#line 2165 "unattended-installer.c"
		OsinfoInstallConfig* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		OsinfoInstallConfig* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = self->config;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = boxes_unattended_installer_get_password (self);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _tmp5_;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = _tmp6_;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_password (_tmp4_, _tmp7_);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp7_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = self->config;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = boxes_unattended_installer_get_password (self);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = _tmp9_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = _tmp10_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_admin_password (_tmp8_, _tmp11_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp11_);
#line 2198 "unattended-installer.c"
	}
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = boxes_unattended_installer_get_username (self);
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp13_ != NULL) {
#line 2206 "unattended-installer.c"
		OsinfoInstallConfig* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		OsinfoInstallConfig* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp14_ = self->config;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp15_ = boxes_unattended_installer_get_username (self);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp16_ = _tmp15_;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_login (_tmp14_, _tmp16_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp17_ = self->config;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = boxes_unattended_installer_get_username (self);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = _tmp18_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_realname (_tmp17_, _tmp19_);
#line 2229 "unattended-installer.c"
	}
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = self->priv->key_entry;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp21_ != NULL) {
#line 2235 "unattended-installer.c"
		GtkEntry* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp22_ = self->priv->key_entry;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = gtk_entry_get_text (_tmp22_);
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = _tmp23_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = _tmp24_ != NULL;
#line 2247 "unattended-installer.c"
	} else {
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = FALSE;
#line 2251 "unattended-installer.c"
	}
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp25_ = _tmp20_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp25_) {
#line 2257 "unattended-installer.c"
		OsinfoInstallConfig* _tmp26_ = NULL;
		GtkEntry* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp26_ = self->config;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp27_ = self->priv->key_entry;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp28_ = gtk_entry_get_text (_tmp27_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp29_ = _tmp28_;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_reg_product_key (_tmp26_, _tmp29_);
#line 2272 "unattended-installer.c"
	}
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp30_ = self->priv->timezone;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp30_ != NULL) {
#line 2278 "unattended-installer.c"
		OsinfoInstallConfig* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp31_ = self->config;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp32_ = self->priv->timezone;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_l10n_timezone (_tmp31_, _tmp32_);
#line 2287 "unattended-installer.c"
	}
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp33_ = self->config;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp34_ = self->priv->lang;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_l10n_language (_tmp33_, _tmp34_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp35_ = self->config;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = self->priv->kbd;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_l10n_keyboard (_tmp35_, _tmp36_);
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp37_ = self->config;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp38_ = self->priv->hostname;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_hostname (_tmp37_, _tmp38_);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp39_ = self->config;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp40_ = ((BoxesInstallerMedia*) self)->os_media;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_tmp40_, "architecture", &_tmp41_, NULL);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp42_ = _tmp41_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp43_ = _tmp42_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_hardware_arch (_tmp39_, _tmp43_);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp43_);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp44_ = ((BoxesInstallerMedia*) self)->os;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp45_ = osinfo_os_get_distro (_tmp44_);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp46_ = _tmp45_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_strcmp0 (_tmp46_, "win") == 0) {
#line 2329 "unattended-installer.c"
		OsinfoInstallConfig* _tmp47_ = NULL;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp47_ = self->config;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_target_disk (_tmp47_, "C");
#line 2335 "unattended-installer.c"
	} else {
		const gchar* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
		gboolean _tmp50_ = FALSE;
		OsinfoInstallConfig* _tmp51_ = NULL;
		const gchar* _tmp52_ = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp49_ = boxes_installer_media_get_supports_virtio_disk ((BoxesInstallerMedia*) self);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp50_ = _tmp49_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp50_) {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp48_ = "/dev/vda";
#line 2350 "unattended-installer.c"
		} else {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp48_ = "/dev/sda";
#line 2354 "unattended-installer.c"
		}
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp51_ = self->config;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp52_ = _tmp48_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_target_disk (_tmp51_, _tmp52_);
#line 2362 "unattended-installer.c"
	}
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp53_ = script;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp54_ = osinfo_install_script_get_path_format (_tmp53_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp55_ = _tmp54_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp56_ = boxes_unattended_installer_get_unattended_disk_config (self, _tmp55_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk_config = _tmp56_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp57_ = script;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp58_ = osinfo_install_script_get_path_format (_tmp57_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp59_ = _tmp58_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp60_ = disk_config;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp61_ = gvir_config_domain_disk_get_target_dev (_tmp60_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp62_ = boxes_unattended_installer_device_name_to_path (self, _tmp59_, _tmp61_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	device_path = _tmp62_;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp63_ = self->config;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp64_ = device_path;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_script_disk (_tmp63_, _tmp64_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp65_ = self->priv->avatar_file;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp65_ != NULL) {
#line 2398 "unattended-installer.c"
		const gchar* _tmp66_ = NULL;
		OsinfoInstallScript* _tmp67_ = NULL;
		OsinfoPathFormat _tmp68_ = 0;
		OsinfoPathFormat _tmp69_ = 0;
		gchar* location = NULL;
		const gchar* _tmp70_ = NULL;
		BoxesUnattendedAvatarFile* _tmp71_ = NULL;
		const gchar* _tmp72_ = NULL;
		const gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		OsinfoInstallConfig* _tmp75_ = NULL;
		const gchar* _tmp76_ = NULL;
		OsinfoInstallConfig* _tmp77_ = NULL;
		OsinfoInstallConfig* _tmp78_ = NULL;
		const gchar* _tmp79_ = NULL;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp67_ = script;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp68_ = osinfo_install_script_get_path_format (_tmp67_);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp69_ = _tmp68_;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp69_ == OSINFO_PATH_FORMAT_UNIX) {
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp66_ = "/";
#line 2424 "unattended-installer.c"
		} else {
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp66_ = "\\";
#line 2428 "unattended-installer.c"
		}
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp70_ = _tmp66_;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp71_ = self->priv->avatar_file;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp72_ = boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) _tmp71_);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp73_ = _tmp72_;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp74_ = g_strconcat (_tmp70_, _tmp73_, NULL);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		location = _tmp74_;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp75_ = self->config;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp76_ = location;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_avatar_location (_tmp75_, _tmp76_);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp77_ = self->config;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp78_ = self->config;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp79_ = osinfo_install_config_get_script_disk (_tmp78_);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_avatar_disk (_tmp77_, _tmp79_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (location);
#line 2458 "unattended-installer.c"
	}
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp80_ = self->config;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp81_ = self->config;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp82_ = osinfo_install_config_get_script_disk (_tmp81_);
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_pre_install_drivers_disk (_tmp80_, _tmp82_);
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp83_ = self->secondary_disk_file;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp83_ != NULL) {
#line 2472 "unattended-installer.c"
		OsinfoInstallScript* _tmp84_ = NULL;
		OsinfoPathFormat _tmp85_ = 0;
		OsinfoPathFormat _tmp86_ = 0;
		GVirConfigDomainDisk* _tmp87_ = NULL;
		OsinfoInstallScript* _tmp88_ = NULL;
		OsinfoPathFormat _tmp89_ = 0;
		OsinfoPathFormat _tmp90_ = 0;
		GVirConfigDomainDisk* _tmp91_ = NULL;
		const gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		OsinfoInstallConfig* _tmp94_ = NULL;
		const gchar* _tmp95_ = NULL;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp84_ = script;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp85_ = osinfo_install_script_get_path_format (_tmp84_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp86_ = _tmp85_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp87_ = boxes_unattended_installer_get_secondary_unattended_disk_config (self, _tmp86_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (disk_config);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		disk_config = _tmp87_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp88_ = script;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp89_ = osinfo_install_script_get_path_format (_tmp88_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp90_ = _tmp89_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp91_ = disk_config;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp92_ = gvir_config_domain_disk_get_target_dev (_tmp91_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp93_ = boxes_unattended_installer_device_name_to_path (self, _tmp90_, _tmp92_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (device_path);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		device_path = _tmp93_;
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp94_ = self->config;
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp95_ = device_path;
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_post_install_drivers_disk (_tmp94_, _tmp95_);
#line 2519 "unattended-installer.c"
	}
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp96_ = self->config;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp97_ = self->priv->driver_signing;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_driver_signing (_tmp96_, _tmp97_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (device_path);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (disk_config);
#line 2531 "unattended-installer.c"
}


static void boxes_unattended_installer_real_setup_post_install_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain) {
	BoxesUnattendedInstaller * self;
	GFile* _tmp0_ = NULL;
	GFile* _tmp5_ = NULL;
	GVirConfigDomain* _tmp10_ = NULL;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->disk_file;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp0_ != NULL) {
#line 2548 "unattended-installer.c"
		gchar* path = NULL;
		GFile* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp1_ = self->disk_file;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = g_file_get_path (_tmp1_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp2_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = domain;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = path;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_remove_disk_from_domain_config (self, _tmp3_, _tmp4_);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 2568 "unattended-installer.c"
	}
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->secondary_disk_file;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp5_ != NULL) {
#line 2574 "unattended-installer.c"
		gchar* path = NULL;
		GFile* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GVirConfigDomain* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = self->secondary_disk_file;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = g_file_get_path (_tmp6_);
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp7_;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = domain;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = path;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_remove_disk_from_domain_config (self, _tmp8_, _tmp9_);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 2594 "unattended-installer.c"
	}
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = domain;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->setup_post_install_domain_config (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia), _tmp10_);
#line 2600 "unattended-installer.c"
}


static void boxes_unattended_installer_real_populate_setup_vbox (BoxesInstallerMedia* base, GtkBox* setup_vbox) {
	BoxesUnattendedInstaller * self;
	GtkBox* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkBox* _tmp6_ = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (setup_vbox != NULL);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = setup_vbox;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 2621 "unattended-installer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		child_collection = _tmp1_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 2629 "unattended-installer.c"
			GtkWidget* child = NULL;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			child = (GtkWidget*) child_it->data;
#line 2633 "unattended-installer.c"
			{
				GtkBox* _tmp2_ = NULL;
				GtkWidget* _tmp3_ = NULL;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = setup_vbox;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = child;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				gtk_container_remove ((GtkContainer*) _tmp2_, _tmp3_);
#line 2643 "unattended-installer.c"
			}
		}
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (child_collection);
#line 2648 "unattended-installer.c"
	}
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = setup_vbox;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->priv->setup_label;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_box_pack_start (_tmp4_, (GtkWidget*) _tmp5_, FALSE, FALSE, (guint) 0);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = setup_vbox;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = self->priv->setup_hbox;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_box_pack_start (_tmp6_, (GtkWidget*) _tmp7_, FALSE, FALSE, (guint) 0);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = setup_vbox;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp8_);
#line 2666 "unattended-installer.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 2673 "unattended-installer.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_free (self);
#line 2682 "unattended-installer.c"
}


static GList* boxes_unattended_installer_real_get_vm_properties (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
	GList* result = NULL;
	GList* properties = NULL;
	GList* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->get_vm_properties (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	properties = _tmp0_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_express_install (self);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp2_) {
#line 2705 "unattended-installer.c"
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesPair* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		BoxesPair* _tmp11_ = NULL;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = _ ("Username");
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = boxes_unattended_installer_get_username (self);
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = _tmp4_;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = boxes_pair_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp3_, _tmp5_);
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		properties = g_list_append (properties, _tmp6_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = _ ("Password");
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = boxes_unattended_installer_get_hidden_password (self);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = _tmp8_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = _tmp9_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = boxes_pair_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp7_, _tmp10_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		properties = g_list_append (properties, _tmp11_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp10_);
#line 2739 "unattended-installer.c"
	}
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = properties;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 2745 "unattended-installer.c"
}


static void boxes_unattended_installer_real_set_direct_boot_params (BoxesInstallerMedia* base, GVirConfigDomainOs* domain_os) {
	BoxesUnattendedInstaller * self;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_ = NULL;
	gboolean _tmp3_ = FALSE;
	OsinfoInstallScript* script = NULL;
	OsinfoInstallScriptList* _tmp4_ = NULL;
	OsinfoEntity* _tmp5_ = NULL;
	OsinfoInstallScript* _tmp6_ = NULL;
	GVirConfigDomainOs* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GVirConfigDomainOs* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	GVirConfigDomainOs* _tmp15_ = NULL;
	OsinfoInstallScript* _tmp16_ = NULL;
	OsinfoOs* _tmp17_ = NULL;
	OsinfoInstallConfig* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain_os != NULL);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->kernel_file;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_ == NULL) {
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = TRUE;
#line 2782 "unattended-installer.c"
	} else {
		GFile* _tmp2_ = NULL;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = self->initrd_file;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 2789 "unattended-installer.c"
	}
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp0_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp3_) {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 2797 "unattended-installer.c"
	}
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = self->scripts;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_list_get_nth ((OsinfoList*) _tmp4_, 0);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp5_) : NULL);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	script = _tmp6_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = domain_os;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = self->kernel_file;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = g_file_get_path (_tmp8_);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _tmp9_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_kernel (_tmp7_, _tmp10_);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp10_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = domain_os;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = self->initrd_file;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = g_file_get_path (_tmp12_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = _tmp13_;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_ramdisk (_tmp11_, _tmp14_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp14_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = domain_os;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = script;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = ((BoxesInstallerMedia*) self)->os;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp18_ = self->config;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = osinfo_install_script_generate_command_line (_tmp16_, _tmp17_, _tmp18_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp20_ = _tmp19_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_cmdline (_tmp15_, _tmp20_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp20_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (script);
#line 2849 "unattended-installer.c"
}


static void boxes_unattended_installer_real_clean_up (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
	GError * _inner_error_ = NULL;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->clean_up (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 2860 "unattended-installer.c"
	{
		GFile* _tmp0_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp4_ = NULL;
		GFile* _tmp6_ = NULL;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = self->disk_file;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp0_ != NULL) {
#line 2870 "unattended-installer.c"
			GFile* _tmp1_ = NULL;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp1_ = self->disk_file;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp1_, &_inner_error_);
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_inner_error_ != NULL) {
#line 2878 "unattended-installer.c"
				goto __catch75_g_error;
			}
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->disk_file);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->disk_file = NULL;
#line 2885 "unattended-installer.c"
		}
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = self->secondary_disk_file;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp2_ != NULL) {
#line 2891 "unattended-installer.c"
			GFile* _tmp3_ = NULL;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = self->secondary_disk_file;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp3_, &_inner_error_);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_inner_error_ != NULL) {
#line 2899 "unattended-installer.c"
				goto __catch75_g_error;
			}
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->secondary_disk_file);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->secondary_disk_file = NULL;
#line 2906 "unattended-installer.c"
		}
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = self->kernel_file;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp4_ != NULL) {
#line 2912 "unattended-installer.c"
			GFile* _tmp5_ = NULL;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp5_ = self->kernel_file;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp5_, &_inner_error_);
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_inner_error_ != NULL) {
#line 2920 "unattended-installer.c"
				goto __catch75_g_error;
			}
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->kernel_file);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->kernel_file = NULL;
#line 2927 "unattended-installer.c"
		}
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = self->initrd_file;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp6_ != NULL) {
#line 2933 "unattended-installer.c"
			GFile* _tmp7_ = NULL;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp7_ = self->initrd_file;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp7_, &_inner_error_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_inner_error_ != NULL) {
#line 2941 "unattended-installer.c"
				goto __catch75_g_error;
			}
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->initrd_file);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->initrd_file = NULL;
#line 2948 "unattended-installer.c"
		}
	}
	goto __finally75;
	__catch75_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_error_ = _inner_error_;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_inner_error_ = NULL;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = _error_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = _tmp8_->message;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:342: Failed to clean-up: %s", _tmp9_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_error_);
#line 2969 "unattended-installer.c"
	}
	__finally75:
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_inner_error_ != NULL) {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_inner_error_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 2980 "unattended-installer.c"
	}
}


static void boxes_unattended_installer_real_clean_up_preparation_cache (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->clean_up_preparation_cache (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = NULL;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = NULL;
#line 2999 "unattended-installer.c"
}


gchar* boxes_unattended_installer_get_user_unattended (BoxesUnattendedInstaller* self, const gchar* suffix) {
	gchar* result = NULL;
	gchar* filename = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->hostname;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	filename = _tmp1_;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = suffix;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp2_ != NULL) {
#line 3023 "unattended-installer.c"
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = filename;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = suffix;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = g_strconcat ("-", _tmp4_, NULL);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _tmp5_;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = g_strconcat (_tmp3_, _tmp6_, NULL);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (filename);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		filename = _tmp7_;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp6_);
#line 3045 "unattended-installer.c"
	}
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = filename;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = boxes_get_user_pkgcache (_tmp8_);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp9_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (filename);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3057 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_data_free (gpointer _data) {
	BoxesUnattendedInstallerPrepareData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerPrepareData, _data_);
#line 3072 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare (BoxesInstallerMedia* base, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstaller * self;
	BoxesUnattendedInstallerPrepareData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerPrepareData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_real_prepare);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_real_prepare_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = progress;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_co (_data_);
#line 3114 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_finish (BoxesInstallerMedia* base, GAsyncResult* _res_) {
	BoxesUnattendedInstallerPrepareData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3122 "unattended-installer.c"
}


static void boxes_unattended_installer_prepare_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerPrepareData* _data_;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_co (_data_);
#line 3136 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_prepare_co (BoxesUnattendedInstallerPrepareData* _data_) {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 3145 "unattended-installer.c"
		goto _state_0;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 3149 "unattended-installer.c"
		goto _state_1;
		default:
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 3154 "unattended-installer.c"
	}
	_state_0:
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->progress;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _data_->cancellable;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers (_data_->self, _data_->_tmp0_, _data_->_tmp1_, boxes_unattended_installer_prepare_ready, _data_);
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3171 "unattended-installer.c"
	_state_1:
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_finish (_data_->self, _data_->_res_);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3179 "unattended-installer.c"
	} else {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3183 "unattended-installer.c"
	}
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3189 "unattended-installer.c"
}


static Block60Data* block60_data_ref (Block60Data* _data60_) {
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_atomic_int_inc (&_data60_->_ref_count_);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return _data60_;
#line 3198 "unattended-installer.c"
}


static void block60_data_unref (void * _userdata_) {
	Block60Data* _data60_;
	_data60_ = (Block60Data*) _userdata_;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_atomic_int_dec_and_test (&_data60_->_ref_count_)) {
#line 3207 "unattended-installer.c"
		BoxesUnattendedInstaller * self;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self = _data60_->self;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data60_->notebook);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_slice_free (Block60Data, _data60_);
#line 3217 "unattended-installer.c"
	}
}


static void __lambda41_ (BoxesUnattendedInstaller* self) {
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_notify ((GObject*) self, "ready-to-create");
#line 3225 "unattended-installer.c"
}


static void ___lambda41__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda41_ (self);
#line 3232 "unattended-installer.c"
}


static void __lambda43_ (BoxesUnattendedInstaller* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_ready_for_express (self);
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 422 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_) {
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_emit_by_name ((BoxesInstallerMedia*) self, "user-wants-to-create");
#line 3247 "unattended-installer.c"
	} else {
		gboolean _tmp2_ = FALSE;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gboolean _tmp6_ = FALSE;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = boxes_unattended_installer_get_username (self);
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = _tmp3_;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (g_strcmp0 (_tmp4_, "") != 0) {
#line 3259 "unattended-installer.c"
			const gchar* _tmp5_ = NULL;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp5_ = self->priv->product_key_format;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = _tmp5_ != NULL;
#line 3265 "unattended-installer.c"
		} else {
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = FALSE;
#line 3269 "unattended-installer.c"
		}
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _tmp2_;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp6_) {
#line 3275 "unattended-installer.c"
			GtkEntry* _tmp7_ = NULL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp7_ = self->priv->key_entry;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp7_);
#line 3281 "unattended-installer.c"
		}
	}
}


static void ___lambda43__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda43_ (self);
#line 3290 "unattended-installer.c"
}


static void __lambda44_ (Block60Data* _data60_) {
	BoxesUnattendedInstaller * self;
	GtkNotebook* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = _data60_->self;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _data60_->notebook;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_notebook_next_page (_tmp0_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->priv->password_entry;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 3308 "unattended-installer.c"
}


static void ___lambda44__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda44_ (self);
#line 3315 "unattended-installer.c"
}


static gboolean __lambda45_ (Block60Data* _data60_) {
	BoxesUnattendedInstaller * self;
	gboolean result = FALSE;
	GtkEntry* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	guint _tmp2_ = 0U;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = _data60_->self;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->password_entry;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_entry_get_text_length (_tmp0_);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp2_ == ((guint) 0)) {
#line 3335 "unattended-installer.c"
		GtkNotebook* _tmp3_ = NULL;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = _data60_->notebook;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gtk_notebook_prev_page (_tmp3_);
#line 3341 "unattended-installer.c"
	}
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = FALSE;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3347 "unattended-installer.c"
}


static gboolean ___lambda45__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda45_ (self);
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3356 "unattended-installer.c"
}


static void __lambda46_ (BoxesUnattendedInstaller* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_ready_for_express (self);
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_) {
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_emit_by_name ((BoxesInstallerMedia*) self, "user-wants-to-create");
#line 3371 "unattended-installer.c"
	} else {
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = boxes_unattended_installer_get_username (self);
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = _tmp2_;
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (g_strcmp0 (_tmp3_, "") == 0) {
#line 3381 "unattended-installer.c"
			GtkEntry* _tmp4_ = NULL;
#line 462 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp4_ = self->priv->username_entry;
#line 462 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp4_);
#line 3387 "unattended-installer.c"
		} else {
			const gchar* _tmp5_ = NULL;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp5_ = self->priv->product_key_format;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_tmp5_ != NULL) {
#line 3394 "unattended-installer.c"
				GtkEntry* _tmp6_ = NULL;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = self->priv->key_entry;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 3400 "unattended-installer.c"
			}
		}
	}
}


static void ___lambda46__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda46_ (self);
#line 3410 "unattended-installer.c"
}


static void __lambda47_ (BoxesUnattendedInstaller* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_ready_for_express (self);
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_) {
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_emit_by_name ((BoxesInstallerMedia*) self, "user-wants-to-create");
#line 3425 "unattended-installer.c"
	} else {
		GtkEntry* _tmp2_ = NULL;
		guint _tmp3_ = 0U;
		guint _tmp4_ = 0U;
		const gchar* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = self->priv->key_entry;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = gtk_entry_get_text_length (_tmp2_);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = _tmp3_;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = self->priv->product_key_format;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = strlen (_tmp5_);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = _tmp6_;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp4_ == ((guint) _tmp7_)) {
#line 3447 "unattended-installer.c"
			GtkEntry* _tmp8_ = NULL;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp8_ = self->priv->username_entry;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 3453 "unattended-installer.c"
		}
	}
}


static void ___lambda47__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda47_ (self);
#line 3462 "unattended-installer.c"
}


static void _boxes_unattended_installer_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_on_key_text_inserted (self, new_text, new_text_length, position);
#line 3469 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_ui (BoxesUnattendedInstaller* self) {
	Block60Data* _data60_;
	const gchar* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkLabel* _tmp4_ = NULL;
	GtkBox* _tmp5_ = NULL;
	GtkBox* _tmp6_ = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkGrid* _tmp8_ = NULL;
	GtkBox* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	GtkGrid* _tmp13_ = NULL;
	GtkGrid* _tmp14_ = NULL;
	GtkLabel* express_label = NULL;
	const gchar* _tmp15_ = NULL;
	GtkLabel* _tmp16_ = NULL;
	GtkLabel* _tmp17_ = NULL;
	GtkLabel* _tmp18_ = NULL;
	GtkLabel* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	GtkGrid* _tmp21_ = NULL;
	GtkLabel* _tmp22_ = NULL;
	GtkSwitch* _tmp23_ = NULL;
	GtkSwitch* _tmp24_ = NULL;
	OsinfoMedia* _tmp25_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	GtkSwitch* _tmp28_ = NULL;
	GtkSwitch* _tmp29_ = NULL;
	GtkSwitch* _tmp30_ = NULL;
	GtkSwitch* _tmp31_ = NULL;
	GtkGrid* _tmp32_ = NULL;
	GtkSwitch* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	GtkImage* avatar = NULL;
	GtkImage* _tmp35_ = NULL;
	GtkImage* _tmp36_ = NULL;
	GtkImage* _tmp37_ = NULL;
	GtkImage* _tmp38_ = NULL;
	GtkImage* _tmp39_ = NULL;
	GtkGrid* _tmp40_ = NULL;
	GtkImage* _tmp41_ = NULL;
	GtkImage* _tmp42_ = NULL;
	GtkImage* _tmp43_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp44_ = NULL;
	GtkLabel* _tmp45_ = NULL;
	GtkLabel* _tmp46_ = NULL;
	GtkLabel* _tmp47_ = NULL;
	GtkLabel* _tmp48_ = NULL;
	GtkLabel* _tmp49_ = NULL;
	GtkGrid* _tmp50_ = NULL;
	GtkLabel* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	GtkEntry* _tmp53_ = NULL;
	GtkEntry* _tmp54_ = NULL;
	GtkEntry* _tmp55_ = NULL;
	GtkEntry* _tmp56_ = NULL;
	GtkEntry* _tmp57_ = NULL;
	GtkGrid* _tmp58_ = NULL;
	GtkEntry* _tmp59_ = NULL;
	gint _tmp60_ = 0;
	const gchar* _tmp61_ = NULL;
	GtkLabel* _tmp62_ = NULL;
	GtkLabel* _tmp63_ = NULL;
	GtkLabel* _tmp64_ = NULL;
	GtkLabel* _tmp65_ = NULL;
	GtkGrid* _tmp66_ = NULL;
	GtkLabel* _tmp67_ = NULL;
	GtkNotebook* _tmp68_ = NULL;
	GtkNotebook* _tmp69_ = NULL;
	GtkNotebook* _tmp70_ = NULL;
	GtkNotebook* _tmp71_ = NULL;
	GtkNotebook* _tmp72_ = NULL;
	GtkButton* button = NULL;
	const gchar* _tmp73_ = NULL;
	GtkButton* _tmp74_ = NULL;
	GtkButton* _tmp75_ = NULL;
	GtkButton* _tmp76_ = NULL;
	GtkNotebook* _tmp77_ = NULL;
	GtkButton* _tmp78_ = NULL;
	GtkEntry* _tmp79_ = NULL;
	GtkNotebook* _tmp80_ = NULL;
	GtkEntry* _tmp81_ = NULL;
	GtkButton* _tmp82_ = NULL;
	GtkEntry* _tmp83_ = NULL;
	GtkEntry* _tmp84_ = NULL;
	GtkGrid* _tmp85_ = NULL;
	GtkNotebook* _tmp86_ = NULL;
	gint _tmp87_ = 0;
	GtkGrid* _tmp88_ = NULL;
	GList* _tmp89_ = NULL;
	const gchar* _tmp98_ = NULL;
	const gchar* _tmp99_ = NULL;
	GtkLabel* _tmp100_ = NULL;
	GtkLabel* _tmp101_ = NULL;
	GtkLabel* _tmp102_ = NULL;
	GtkLabel* _tmp103_ = NULL;
	GtkLabel* _tmp104_ = NULL;
	GtkGrid* _tmp105_ = NULL;
	GtkLabel* _tmp106_ = NULL;
	gint _tmp107_ = 0;
	GtkSwitch* _tmp108_ = NULL;
	GtkLabel* _tmp109_ = NULL;
	GtkEntry* _tmp110_ = NULL;
	GtkEntry* _tmp111_ = NULL;
	const gchar* _tmp112_ = NULL;
	gint _tmp113_ = 0;
	gint _tmp114_ = 0;
	GtkEntry* _tmp115_ = NULL;
	const gchar* _tmp116_ = NULL;
	gint _tmp117_ = 0;
	gint _tmp118_ = 0;
	GtkEntry* _tmp119_ = NULL;
	GtkEntry* _tmp120_ = NULL;
	GtkEntry* _tmp121_ = NULL;
	GtkEntry* _tmp122_ = NULL;
	GtkStyleContext* _tmp123_ = NULL;
	GtkGrid* _tmp124_ = NULL;
	GtkEntry* _tmp125_ = NULL;
	gint _tmp126_ = 0;
	GtkSwitch* _tmp127_ = NULL;
	GtkEntry* _tmp128_ = NULL;
	GtkEntry* _tmp129_ = NULL;
	gint _tmp130_ = 0;
	GtkEntry* _tmp131_ = NULL;
	gulong _tmp132_ = 0UL;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data60_ = g_slice_new0 (Block60Data);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data60_->_ref_count_ = 1;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data60_->self = g_object_ref (self);
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _ ("Choose express install to automatically preconfigure the box with opti" \
"mal settings.");
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp1_);
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_label);
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_label = _tmp1_;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = self->priv->setup_label;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_set (_tmp2_, "wrap", TRUE, NULL);
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = self->priv->setup_label;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_label_set_width_chars (_tmp3_, 30);
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = self->priv->setup_label;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_START);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp5_);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_hbox);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_hbox = _tmp5_;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = self->priv->setup_hbox;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_START);
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = self->priv->setup_hbox;
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_set ((GtkWidget*) _tmp7_, "margin", 24, NULL);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = (GtkGrid*) gtk_grid_new ();
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp8_);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_grid);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_grid = _tmp8_;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = self->priv->setup_hbox;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = self->priv->setup_grid;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_box_pack_start (_tmp9_, (GtkWidget*) _tmp10_, FALSE, FALSE, (guint) 0);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = self->priv->setup_grid;
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_set_column_spacing (_tmp11_, 0);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = self->priv->setup_grid;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_set_column_homogeneous (_tmp12_, FALSE);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = self->priv->setup_grid;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_set_row_spacing (_tmp13_, 0);
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = self->priv->setup_grid;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_set_row_homogeneous (_tmp14_, TRUE);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = _ ("Express Install");
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = (GtkLabel*) gtk_label_new (_tmp15_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp16_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	express_label = _tmp16_;
#line 386 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = express_label;
#line 386 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp17_, 10);
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp18_ = express_label;
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp18_, 15);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = express_label;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp19_, GTK_ALIGN_END);
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp20_ = express_label;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp20_, GTK_ALIGN_CENTER);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = self->priv->setup_grid;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp22_ = express_label;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp21_, (GtkWidget*) _tmp22_, 0, 0, 2, 1);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp23_ = (GtkSwitch*) gtk_switch_new ();
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp23_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->express_toggle);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->express_toggle = _tmp23_;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp24_ = self->priv->express_toggle;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp25_ = ((BoxesInstallerMedia*) self)->os_media;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_tmp25_, "live", &_tmp26_, NULL);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp27_ = _tmp26_;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_switch_set_active (_tmp24_, !_tmp27_);
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp28_ = self->priv->express_toggle;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp28_, 15);
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp29_ = self->priv->express_toggle;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp29_, GTK_ALIGN_START);
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp30_ = self->priv->express_toggle;
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp30_, GTK_ALIGN_CENTER);
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp31_ = self->priv->express_toggle;
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object ((GObject*) _tmp31_, "notify::active", (GCallback) ___lambda41__g_object_notify, self, 0);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp32_ = self->priv->setup_grid;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp33_ = self->priv->express_toggle;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp32_, (GtkWidget*) _tmp33_, 2, 0, 1, 1);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp34_ = self->priv->setup_grid_n_rows;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_grid_n_rows = _tmp34_ + 1;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp35_ = (GtkImage*) gtk_image_new_from_icon_name ("avatar-default", 0);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp35_);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	avatar = _tmp35_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = avatar;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_image_set_pixel_size (_tmp36_, 64);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp37_ = avatar;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp37_, 15);
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp38_ = avatar;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp38_, GTK_ALIGN_CENTER);
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp39_ = avatar;
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp39_, GTK_ALIGN_CENTER);
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp40_ = self->priv->setup_grid;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp41_ = avatar;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp40_, (GtkWidget*) _tmp41_, 0, 1, 1, 2);
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp42_ = avatar;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp42_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp43_ = avatar;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar (self, _tmp43_, NULL, NULL);
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp44_ = _ ("Username");
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp45_ = (GtkLabel*) gtk_label_new (_tmp44_);
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp45_);
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	label = _tmp45_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp46_ = label;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp46_, 10);
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp47_ = label;
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp47_, 10);
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp48_ = label;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp48_, GTK_ALIGN_END);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp49_ = label;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp49_, GTK_ALIGN_BASELINE);
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp50_ = self->priv->setup_grid;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp51_ = label;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp50_, (GtkWidget*) _tmp51_, 1, 1, 1, 1);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp52_ = g_get_user_name ();
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp53_ = boxes_unattended_installer_create_input_entry (self, _tmp52_, TRUE, TRUE);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->username_entry = _tmp53_;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp54_ = self->priv->username_entry;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp54_, 10);
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp55_ = self->priv->username_entry;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp55_, GTK_ALIGN_FILL);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp56_ = self->priv->username_entry;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp56_, GTK_ALIGN_BASELINE);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp57_ = self->priv->username_entry;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object (_tmp57_, "activate", (GCallback) ___lambda43__gtk_entry_activate, self, 0);
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp58_ = self->priv->setup_grid;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp59_ = self->priv->username_entry;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp58_, (GtkWidget*) _tmp59_, 2, 1, 1, 1);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp60_ = self->priv->setup_grid_n_rows;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_grid_n_rows = _tmp60_ + 1;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp61_ = _ ("Password");
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp62_ = (GtkLabel*) gtk_label_new (_tmp61_);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp62_);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (label);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	label = _tmp62_;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp63_ = label;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp63_, 10);
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp64_ = label;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp64_, GTK_ALIGN_END);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp65_ = label;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp65_, GTK_ALIGN_BASELINE);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp66_ = self->priv->setup_grid;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp67_ = label;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp66_, (GtkWidget*) _tmp67_, 1, 2, 1, 1);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp68_ = (GtkNotebook*) gtk_notebook_new ();
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp68_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data60_->notebook = _tmp68_;
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp69_ = _data60_->notebook;
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_notebook_set_show_tabs (_tmp69_, FALSE);
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp70_ = _data60_->notebook;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_notebook_set_show_border (_tmp70_, FALSE);
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp71_ = _data60_->notebook;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp71_, GTK_ALIGN_FILL);
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp72_ = _data60_->notebook;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp72_, GTK_ALIGN_CENTER);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp73_ = _ ("_Add Password");
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp74_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp73_);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp74_);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	button = _tmp74_;
#line 444 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp75_ = button;
#line 444 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp75_, TRUE);
#line 445 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp76_ = button;
#line 445 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp76_, GTK_ALIGN_BASELINE);
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp77_ = _data60_->notebook;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp78_ = button;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_notebook_append_page (_tmp77_, (GtkWidget*) _tmp78_, NULL);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp79_ = boxes_unattended_installer_create_input_entry (self, "", FALSE, FALSE);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->password_entry = _tmp79_;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp80_ = _data60_->notebook;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp81_ = self->priv->password_entry;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_notebook_append_page (_tmp80_, (GtkWidget*) _tmp81_, NULL);
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp82_ = button;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_data (_tmp82_, "clicked", (GCallback) ___lambda44__gtk_button_clicked, block60_data_ref (_data60_), (GClosureNotify) block60_data_unref, 0);
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp83_ = self->priv->password_entry;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_data ((GtkWidget*) _tmp83_, "focus-out-event", (GCallback) ___lambda45__gtk_widget_focus_out_event, block60_data_ref (_data60_), (GClosureNotify) block60_data_unref, 0);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp84_ = self->priv->password_entry;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object (_tmp84_, "activate", (GCallback) ___lambda46__gtk_entry_activate, self, 0);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp85_ = self->priv->setup_grid;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp86_ = _data60_->notebook;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp85_, (GtkWidget*) _tmp86_, 2, 2, 1, 1);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp87_ = self->priv->setup_grid_n_rows;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_grid_n_rows = _tmp87_ + 1;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp88_ = self->priv->setup_grid;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp89_ = gtk_container_get_children ((GtkContainer*) _tmp88_);
#line 3964 "unattended-installer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		child_collection = _tmp89_;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 3972 "unattended-installer.c"
			GtkWidget* child = NULL;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			child = (GtkWidget*) child_it->data;
#line 3976 "unattended-installer.c"
			{
				gboolean _tmp90_ = FALSE;
				GtkWidget* _tmp91_ = NULL;
				GtkLabel* _tmp92_ = NULL;
				gboolean _tmp95_ = FALSE;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp91_ = child;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp92_ = express_label;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp91_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, GTK_TYPE_WIDGET, GtkWidget)) {
#line 3988 "unattended-installer.c"
					GtkWidget* _tmp93_ = NULL;
					GtkSwitch* _tmp94_ = NULL;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp93_ = child;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp94_ = self->priv->express_toggle;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp90_ = _tmp93_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp94_, GTK_TYPE_WIDGET, GtkWidget);
#line 3997 "unattended-installer.c"
				} else {
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp90_ = FALSE;
#line 4001 "unattended-installer.c"
				}
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp95_ = _tmp90_;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp95_) {
#line 4007 "unattended-installer.c"
					GtkSwitch* _tmp96_ = NULL;
					GtkWidget* _tmp97_ = NULL;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp96_ = self->priv->express_toggle;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp97_ = child;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_bind_property_with_closures ((GObject*) _tmp96_, "active", (GObject*) _tmp97_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 4016 "unattended-installer.c"
				}
			}
		}
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (child_collection);
#line 4022 "unattended-installer.c"
	}
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp98_ = self->priv->product_key_format;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp98_ == NULL) {
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (button);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (label);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (avatar);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (express_label);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		block60_data_unref (_data60_);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data60_ = NULL;
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 4042 "unattended-installer.c"
	}
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp99_ = _ ("Product Key");
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp100_ = (GtkLabel*) gtk_label_new (_tmp99_);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp100_);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (label);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	label = _tmp100_;
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp101_ = label;
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp101_, 15);
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp102_ = label;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp102_, 10);
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp103_ = label;
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp103_, GTK_ALIGN_END);
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp104_ = label;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp104_, GTK_ALIGN_CENTER);
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp105_ = self->priv->setup_grid;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp106_ = label;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp107_ = self->priv->setup_grid_n_rows;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp105_, (GtkWidget*) _tmp106_, 0, _tmp107_, 2, 1);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp108_ = self->priv->express_toggle;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp109_ = label;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp108_, "active", (GObject*) _tmp109_, "sensitive", 0, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp110_ = boxes_unattended_installer_create_input_entry (self, "", TRUE, TRUE);
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->key_entry = _tmp110_;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp111_ = self->priv->key_entry;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp112_ = self->priv->product_key_format;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp113_ = strlen (_tmp112_);
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp114_ = _tmp113_;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_entry_set_width_chars (_tmp111_, _tmp114_);
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp115_ = self->priv->key_entry;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp116_ = self->priv->product_key_format;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp117_ = strlen (_tmp116_);
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp118_ = _tmp117_;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_entry_set_max_length (_tmp115_, _tmp118_);
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp119_ = self->priv->key_entry;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp119_, 15);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp120_ = self->priv->key_entry;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp120_, GTK_ALIGN_FILL);
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp121_ = self->priv->key_entry;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp121_, GTK_ALIGN_CENTER);
#line 490 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp122_ = self->priv->key_entry;
#line 490 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp123_ = gtk_widget_get_style_context ((GtkWidget*) _tmp122_);
#line 490 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_style_context_add_class (_tmp123_, "boxes-product-key-entry");
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp124_ = self->priv->setup_grid;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp125_ = self->priv->key_entry;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp126_ = self->priv->setup_grid_n_rows;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_grid_attach (_tmp124_, (GtkWidget*) _tmp125_, 2, _tmp126_, 1, 1);
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp127_ = self->priv->express_toggle;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp128_ = self->priv->key_entry;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp127_, "active", (GObject*) _tmp128_, "sensitive", 0, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp129_ = self->priv->key_entry;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object (_tmp129_, "activate", (GCallback) ___lambda47__gtk_entry_activate, self, 0);
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp130_ = self->priv->setup_grid_n_rows;
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->setup_grid_n_rows = _tmp130_ + 1;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp131_ = self->priv->key_entry;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp132_ = g_signal_connect_object ((GtkEditable*) _tmp131_, "insert-text", (GCallback) _boxes_unattended_installer_on_key_text_inserted_gtk_editable_insert_text, self, 0);
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->key_inserted_id = _tmp132_;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (button);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (label);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (avatar);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (express_label);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	block60_data_unref (_data60_);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data60_ = NULL;
#line 4168 "unattended-installer.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 965 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 966 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 966 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 966 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 966 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	return result;
#line 4186 "unattended-installer.c"
}


static void boxes_unattended_installer_on_key_text_inserted (BoxesUnattendedInstaller* self, const gchar* text, gint text_length, gint* position) {
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp41_ = NULL;
	GtkEntry* _tmp53_ = NULL;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (text != NULL);
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = g_strdup ("");
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_result_ = _tmp0_;
#line 4203 "unattended-installer.c"
	{
		guint i = 0U;
		guint j = 0U;
		gint _tmp1_ = 0;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		i = (guint) 0;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp1_ = *position;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		j = (guint) _tmp1_;
#line 4214 "unattended-installer.c"
		{
			gboolean _tmp2_ = FALSE;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = TRUE;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			while (TRUE) {
#line 4221 "unattended-installer.c"
				gboolean _tmp3_ = FALSE;
				gboolean _tmp4_ = FALSE;
				guint _tmp5_ = 0U;
				gint _tmp6_ = 0;
				gboolean _tmp11_ = FALSE;
				gchar character = '\0';
				const gchar* _tmp12_ = NULL;
				guint _tmp13_ = 0U;
				gchar _tmp14_ = '\0';
				gchar allowed_char = '\0';
				const gchar* _tmp15_ = NULL;
				guint _tmp16_ = 0U;
				gchar _tmp17_ = '\0';
				gboolean skip_input_char = FALSE;
				gchar _tmp18_ = '\0';
				guint _tmp33_ = 0U;
				gboolean _tmp34_ = FALSE;
				const gchar* _tmp35_ = NULL;
				gchar _tmp36_ = '\0';
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				guint _tmp40_ = 0U;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = _tmp2_;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (!_tmp3_) {
#line 4249 "unattended-installer.c"
				}
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = FALSE;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = i;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = text_length;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp5_ < ((guint) _tmp6_)) {
#line 4259 "unattended-installer.c"
					guint _tmp7_ = 0U;
					const gchar* _tmp8_ = NULL;
					gint _tmp9_ = 0;
					gint _tmp10_ = 0;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp7_ = j;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = self->priv->product_key_format;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = strlen (_tmp8_);
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp10_ = _tmp9_;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp4_ = _tmp7_ < ((guint) _tmp10_);
#line 4274 "unattended-installer.c"
				} else {
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp4_ = FALSE;
#line 4278 "unattended-installer.c"
				}
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = _tmp4_;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (!_tmp11_) {
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					break;
#line 4286 "unattended-installer.c"
				}
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = text;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = i;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14_ = string_get (_tmp12_, (glong) _tmp13_);
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				character = _tmp14_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp15_ = self->priv->product_key_format;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp16_ = j;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = string_get (_tmp15_, (glong) _tmp16_);
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				allowed_char = _tmp17_;
#line 511 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				skip_input_char = FALSE;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp18_ = allowed_char;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				switch (_tmp18_) {
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					case '@':
#line 4312 "unattended-installer.c"
					{
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4316 "unattended-installer.c"
					}
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					case '%':
#line 4320 "unattended-installer.c"
					{
						gchar _tmp19_ = '\0';
						gboolean _tmp20_ = FALSE;
#line 517 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp19_ = character;
#line 517 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp20_ = g_ascii_isalpha (_tmp19_);
#line 517 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						if (!_tmp20_) {
#line 518 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							skip_input_char = TRUE;
#line 4332 "unattended-installer.c"
						}
#line 519 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4336 "unattended-installer.c"
					}
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					case '#':
#line 4340 "unattended-installer.c"
					{
						gchar _tmp21_ = '\0';
						gboolean _tmp22_ = FALSE;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp21_ = character;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp22_ = g_ascii_isdigit (_tmp21_);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						if (!_tmp22_) {
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							skip_input_char = TRUE;
#line 4352 "unattended-installer.c"
						}
#line 524 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4356 "unattended-installer.c"
					}
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					case '$':
#line 4360 "unattended-installer.c"
					{
						gchar _tmp23_ = '\0';
						gboolean _tmp24_ = FALSE;
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp23_ = character;
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp24_ = g_ascii_isalnum (_tmp23_);
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						if (!_tmp24_) {
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							skip_input_char = TRUE;
#line 4372 "unattended-installer.c"
						}
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4376 "unattended-installer.c"
					}
					default:
					{
						gchar _tmp25_ = '\0';
						gchar _tmp26_ = '\0';
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp25_ = character;
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp26_ = allowed_char;
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						if (_tmp25_ != _tmp26_) {
#line 4388 "unattended-installer.c"
							const gchar* _tmp27_ = NULL;
							gchar _tmp28_ = '\0';
							gchar* _tmp29_ = NULL;
							gchar* _tmp30_ = NULL;
							gchar* _tmp31_ = NULL;
							guint _tmp32_ = 0U;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp27_ = _result_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp28_ = allowed_char;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp29_ = g_strdup_printf ("%c", _tmp28_);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp30_ = _tmp29_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp31_ = g_strconcat (_tmp27_, _tmp30_, NULL);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_g_free0 (_result_);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_result_ = _tmp31_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_g_free0 (_tmp30_);
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							_tmp32_ = j;
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							j = _tmp32_ + 1;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
							continue;
#line 4417 "unattended-installer.c"
						}
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4421 "unattended-installer.c"
					}
				}
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp33_ = i;
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				i = _tmp33_ + 1;
#line 543 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp34_ = skip_input_char;
#line 543 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp34_) {
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					continue;
#line 4434 "unattended-installer.c"
				}
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp35_ = _result_;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp36_ = character;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp37_ = g_strdup_printf ("%c", _tmp36_);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp38_ = _tmp37_;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp39_ = g_strconcat (_tmp35_, _tmp38_, NULL);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_result_);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_result_ = _tmp39_;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_tmp38_);
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp40_ = j;
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				j = _tmp40_ + 1;
#line 4456 "unattended-installer.c"
			}
		}
	}
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp41_ = _result_;
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_strcmp0 (_tmp41_, "") != 0) {
#line 4464 "unattended-installer.c"
		GtkEntry* _tmp42_ = NULL;
		gulong _tmp43_ = 0UL;
		GtkEntry* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		const gchar* _tmp48_ = NULL;
		gint _tmp49_ = 0;
		gint _tmp50_ = 0;
		GtkEntry* _tmp51_ = NULL;
		gulong _tmp52_ = 0UL;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp42_ = self->priv->key_entry;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp43_ = self->priv->key_inserted_id;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_handler_block (_tmp42_, _tmp43_);
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp44_ = self->priv->key_entry;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp45_ = _result_;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp46_ = g_utf8_strup (_tmp45_, (gssize) (-1));
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp47_ = _tmp46_;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp48_ = _result_;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp49_ = strlen (_tmp48_);
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp50_ = _tmp49_;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gtk_editable_insert_text ((GtkEditable*) _tmp44_, _tmp47_, _tmp50_, position);
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp47_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp51_ = self->priv->key_entry;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp52_ = self->priv->key_inserted_id;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_handler_unblock (_tmp51_, _tmp52_);
#line 4506 "unattended-installer.c"
	}
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp53_ = self->priv->key_entry;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_stop_emission_by_name (_tmp53_, "insert-text");
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_result_);
#line 4514 "unattended-installer.c"
}


static GVirConfigDomainDisk* boxes_unattended_installer_get_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format) {
	GVirConfigDomainDisk* result = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GVirConfigDomainDisk* _tmp2_ = NULL;
	GVirConfigDomainDisk* _tmp3_ = NULL;
	GVirConfigDomainDisk* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	OsinfoOs* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = gvir_config_domain_disk_new ();
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp0_;
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = disk;
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_type (_tmp1_, GVIR_CONFIG_DOMAIN_DISK_FILE);
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = disk;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_name (_tmp2_, "qemu");
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = disk;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_format (_tmp3_, GVIR_CONFIG_DOMAIN_DISK_FORMAT_RAW);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = disk;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->disk_file;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_source (_tmp4_, _tmp7_);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp7_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = ((BoxesInstallerMedia*) self)->os;
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = osinfo_os_get_distro (_tmp8_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _tmp9_;
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_strcmp0 (_tmp10_, "win") == 0) {
#line 4570 "unattended-installer.c"
		const gchar* _tmp11_ = NULL;
		OsinfoPathFormat _tmp12_ = 0;
		GVirConfigDomainDisk* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GVirConfigDomainDisk* _tmp15_ = NULL;
		GVirConfigDomainDisk* _tmp16_ = NULL;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = path_format;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp12_ == OSINFO_PATH_FORMAT_DOS) {
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp11_ = "A";
#line 4583 "unattended-installer.c"
		} else {
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp11_ = "fd";
#line 4587 "unattended-installer.c"
		}
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp13_ = disk;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp14_ = _tmp11_;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_dev (_tmp13_, _tmp14_);
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp15_ = disk;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_guest_device_type (_tmp15_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_FLOPPY);
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp16_ = disk;
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_bus (_tmp16_, GVIR_CONFIG_DOMAIN_DISK_BUS_FDC);
#line 4603 "unattended-installer.c"
	} else {
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		GVirConfigDomainDisk* _tmp27_ = NULL;
		GVirConfigDomainDisk* _tmp28_ = NULL;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp17_ = boxes_installer_media_get_supports_virtio_disk ((BoxesInstallerMedia*) self);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = _tmp17_;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp18_) {
#line 4615 "unattended-installer.c"
			const gchar* _tmp19_ = NULL;
			OsinfoPathFormat _tmp20_ = 0;
			GVirConfigDomainDisk* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp20_ = path_format;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_tmp20_ == OSINFO_PATH_FORMAT_UNIX) {
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp19_ = "sda";
#line 4626 "unattended-installer.c"
			} else {
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp19_ = "E";
#line 4630 "unattended-installer.c"
			}
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp21_ = disk;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp22_ = _tmp19_;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gvir_config_domain_disk_set_target_dev (_tmp21_, _tmp22_);
#line 4638 "unattended-installer.c"
		} else {
			const gchar* _tmp23_ = NULL;
			OsinfoPathFormat _tmp24_ = 0;
			GVirConfigDomainDisk* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp24_ = path_format;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_tmp24_ == OSINFO_PATH_FORMAT_UNIX) {
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp23_ = "sdb";
#line 4650 "unattended-installer.c"
			} else {
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp23_ = "E";
#line 4654 "unattended-installer.c"
			}
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp25_ = disk;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp26_ = _tmp23_;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gvir_config_domain_disk_set_target_dev (_tmp25_, _tmp26_);
#line 4662 "unattended-installer.c"
		}
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp27_ = disk;
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_guest_device_type (_tmp27_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_DISK);
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp28_ = disk;
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_bus (_tmp28_, GVIR_CONFIG_DOMAIN_DISK_BUS_USB);
#line 4672 "unattended-installer.c"
	}
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = disk;
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4678 "unattended-installer.c"
}


static GVirConfigDomainDisk* boxes_unattended_installer_get_secondary_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format) {
	GVirConfigDomainDisk* result = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GVirConfigDomainDisk* _tmp2_ = NULL;
	GVirConfigDomainDisk* _tmp3_ = NULL;
	GVirConfigDomainDisk* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	OsinfoPathFormat _tmp9_ = 0;
	GVirConfigDomainDisk* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GVirConfigDomainDisk* _tmp12_ = NULL;
	GVirConfigDomainDisk* _tmp13_ = NULL;
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = gvir_config_domain_disk_new ();
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp0_;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = disk;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_type (_tmp1_, GVIR_CONFIG_DOMAIN_DISK_FILE);
#line 587 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = disk;
#line 587 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_name (_tmp2_, "qemu");
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = disk;
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_format (_tmp3_, GVIR_CONFIG_DOMAIN_DISK_FORMAT_RAW);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = disk;
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->secondary_disk_file;
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_;
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_source (_tmp4_, _tmp7_);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp7_);
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = path_format;
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp9_ == OSINFO_PATH_FORMAT_DOS) {
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = "E";
#line 4735 "unattended-installer.c"
	} else {
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = "hdd";
#line 4739 "unattended-installer.c"
	}
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = disk;
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = _tmp8_;
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_target_dev (_tmp10_, _tmp11_);
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = disk;
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_guest_device_type (_tmp12_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM);
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = disk;
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_target_bus (_tmp13_, GVIR_CONFIG_DOMAIN_DISK_BUS_IDE);
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = disk;
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4759 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_device_name_to_path (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format, const gchar* name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	OsinfoPathFormat _tmp1_ = 0;
#line 597 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 597 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = path_format;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_ == OSINFO_PATH_FORMAT_UNIX) {
#line 4775 "unattended-installer.c"
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = name;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = g_strconcat ("/dev/", _tmp2_, NULL);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp0_);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp3_;
#line 4786 "unattended-installer.c"
	} else {
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = name;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = g_strdup (_tmp4_);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp0_);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp5_;
#line 4798 "unattended-installer.c"
	}
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4804 "unattended-installer.c"
}


static void boxes_unattended_installer_add_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file) {
	BoxesUnattendedFile* _tmp0_ = NULL;
	BoxesUnattendedFile* _tmp1_ = NULL;
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (file != NULL);
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = file;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = g_list_append (self->priv->unattended_files, _tmp1_);
#line 4821 "unattended-installer.c"
}


static void boxes_unattended_installer_add_secondary_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file) {
	BoxesUnattendedFile* _tmp0_ = NULL;
	BoxesUnattendedFile* _tmp1_ = NULL;
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (file != NULL);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = file;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = g_list_append (self->priv->secondary_unattended_files, _tmp1_);
#line 4838 "unattended-installer.c"
}


static void ___lambda42_ (BoxesUnattendedInstaller* self) {
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_notify ((GObject*) self, "ready-to-create");
#line 4845 "unattended-installer.c"
}


static void ____lambda42__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	___lambda42_ (self);
#line 4852 "unattended-installer.c"
}


static GtkEntry* boxes_unattended_installer_create_input_entry (BoxesUnattendedInstaller* self, const gchar* text, gboolean mandatory, gboolean visibility) {
	GtkEntry* result = NULL;
	GtkEntry* entry = NULL;
	GtkEntry* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GtkEntry* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 609 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 609 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (text != NULL, NULL);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = (GtkEntry*) gtk_entry_new ();
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp0_);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	entry = _tmp0_;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = entry;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = visibility;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_entry_set_visibility (_tmp1_, _tmp2_);
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = entry;
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp3_, TRUE);
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = entry;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = text;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_entry_set_text (_tmp4_, _tmp5_);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = mandatory;
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp6_) {
#line 4896 "unattended-installer.c"
		GtkEntry* _tmp7_ = NULL;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = entry;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_signal_connect_object ((GObject*) _tmp7_, "notify::text", (GCallback) ____lambda42__g_object_notify, self, 0);
#line 4902 "unattended-installer.c"
	}
#line 620 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = entry;
#line 620 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4908 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_data_free (gpointer _data) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerCreateDiskImageData, _data_);
#line 4921 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image (BoxesUnattendedInstaller* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerCreateDiskImageData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_create_disk_image);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_create_disk_image_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_create_disk_image_co (_data_);
#line 4950 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 4960 "unattended-installer.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4964 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_create_disk_image_co (_data_);
#line 4978 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_create_disk_image_co (BoxesUnattendedInstallerCreateDiskImageData* _data_) {
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 4987 "unattended-installer.c"
		goto _state_0;
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 4991 "unattended-installer.c"
		goto _state_1;
		default:
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 4996 "unattended-installer.c"
	}
	_state_0:
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_get_unattended ("disk.img");
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->template_path = _data_->_tmp0_;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_file_new_for_path (_data_->template_path);
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->template_file = _data_->_tmp1_;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = _data_->self->disk_file;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = g_file_get_path (_data_->_tmp2_);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:627: Creating disk image for unattended inst" \
"allation at '%s'..", _data_->_tmp4_);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp4_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = _data_->self->disk_file;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->cancellable;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_file_copy_async (_data_->template_file, _data_->_tmp5_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, _data_->_tmp6_, NULL, NULL, boxes_unattended_installer_create_disk_image_ready, _data_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5041 "unattended-installer.c"
	_state_1:
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_file_copy_finish (_data_->template_file, _data_->_res_, &_data_->_inner_error_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->template_file);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->template_path);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5059 "unattended-installer.c"
		} else {
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5063 "unattended-installer.c"
		}
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5069 "unattended-installer.c"
	}
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = _data_->self->disk_file;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = g_file_get_path (_data_->_tmp7_);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = NULL;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:629: Floppy image for unattended installatio" \
"n created at '%s'", _data_->_tmp9_);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp9_);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->template_file);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->template_path);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5095 "unattended-installer.c"
	} else {
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5099 "unattended-installer.c"
	}
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5105 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_data_free (gpointer _data) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->avatar);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerFetchUserAvatarData, _data_);
#line 5118 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar (BoxesUnattendedInstaller* self, GtkImage* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	GtkImage* _tmp2_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerFetchUserAvatarData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_fetch_user_avatar);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_fetch_user_avatar_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = avatar;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->avatar);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->avatar = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar_co (_data_);
#line 5147 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5155 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar_co (_data_);
#line 5169 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_fetch_user_avatar_co (BoxesUnattendedInstallerFetchUserAvatarData* _data_) {
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 5178 "unattended-installer.c"
		goto _state_0;
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 5182 "unattended-installer.c"
		goto _state_1;
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 5186 "unattended-installer.c"
		goto _state_2;
		default:
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 5191 "unattended-installer.c"
	}
	_state_0:
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_unattended_installer_accounts;
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp0_ == NULL) {
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5204 "unattended-installer.c"
		} else {
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5208 "unattended-installer.c"
		}
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5214 "unattended-installer.c"
	}
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_get_user_name ();
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = g_strdup (_data_->_tmp1_);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->username = _data_->_tmp2_;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->username;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = g_strconcat ("/var/lib/AccountsService/icons/", _data_->_tmp3_, NULL);
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->avatar_path = _data_->_tmp4_;
#line 5236 "unattended-installer.c"
	{
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = NULL;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = boxes_unattended_installer_accounts;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp6_ = NULL;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp6_ = g_get_user_name ();
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_fdo_accounts_FindUserByName (_data_->_tmp5_, _data_->_tmp6_, boxes_unattended_installer_fetch_user_avatar_ready, _data_);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5252 "unattended-installer.c"
		_state_1:
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = NULL;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = boxes_fdo_accounts_FindUserByName_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->path = _data_->_tmp7_;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_inner_error_ != NULL) {
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_->domain == G_IO_ERROR) {
#line 5264 "unattended-installer.c"
				goto __catch76_g_io_error;
			}
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->avatar_path);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->username);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_data_->_inner_error_);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 5277 "unattended-installer.c"
		}
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = NULL;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = _data_->path;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 2;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_async_initable_new_async (BOXES_FDO_TYPE_ACCOUNTS_USER_PROXY, 0, NULL, boxes_unattended_installer_fetch_user_avatar_ready, _data_, "g-flags", 0, "g-name", "org.freedesktop.Accounts", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", _data_->_tmp8_, "g-interface-name", "org.freedesktop.Accounts.User", NULL);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5289 "unattended-installer.c"
		_state_2:
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = NULL;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = g_async_initable_new_finish (_data_->_source_object_, _data_->_res_, &_data_->_inner_error_);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->user = (BoxesFdoAccountsUser*) _data_->_tmp9_;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_inner_error_ != NULL) {
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->path);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_->domain == G_IO_ERROR) {
#line 5303 "unattended-installer.c"
				goto __catch76_g_io_error;
			}
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->path);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->avatar_path);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->username);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_data_->_inner_error_);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 5318 "unattended-installer.c"
		}
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = NULL;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = _data_->user;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = NULL;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = boxes_fdo_accounts_user_get_IconFile (_data_->_tmp10_);
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = NULL;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->avatar_path = _data_->_tmp12_;
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->user);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->path);
#line 5340 "unattended-installer.c"
	}
	goto __finally76;
	__catch76_g_io_error:
	{
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = NULL;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = _data_->username;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = NULL;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = _data_->_error_;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = NULL;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = _data_->_tmp14_->message;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_warning ("unattended-installer.vala:644: Failed to retrieve information about us" \
"er '%s': %s", _data_->_tmp13_, _data_->_tmp15_);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_error_);
#line 5365 "unattended-installer.c"
	}
	__finally76:
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->username);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_data_->_inner_error_);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5380 "unattended-installer.c"
	}
	{
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = NULL;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = _data_->avatar_path;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp17_ = NULL;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp17_ = gdk_pixbuf_new_from_file_at_scale (_data_->_tmp16_, 64, 64, TRUE, &_data_->_inner_error_);
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->pixbuf = _data_->_tmp17_;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_inner_error_ != NULL) {
#line 5395 "unattended-installer.c"
			goto __catch77_g_error;
		}
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp18_ = NULL;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp18_ = _data_->avatar;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp19_ = NULL;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp19_ = _data_->pixbuf;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_set (_data_->_tmp18_, "pixbuf", _data_->_tmp19_, NULL);
#line 651 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->avatar_format = NULL;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = NULL;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = _data_->self->scripts;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp21_ = NULL;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp21_ = osinfo_list_get_elements ((OsinfoList*) _data_->_tmp20_);
#line 5418 "unattended-installer.c"
		{
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->s_collection = _data_->_tmp21_;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (_data_->s_it = _data_->s_collection; _data_->s_it != NULL; _data_->s_it = _data_->s_it->next) {
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->s = (OsinfoEntity*) _data_->s_it->data;
#line 5426 "unattended-installer.c"
				{
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = NULL;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = _data_->s;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = NULL;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp22_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _data_->_tmp22_) : NULL);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->script = _data_->_tmp23_;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp24_ = NULL;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp24_ = _data_->script;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp25_ = NULL;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp25_ = osinfo_install_script_get_avatar_format (_data_->_tmp24_);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp26_ = NULL;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp26_ = _data_->_tmp25_;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp27_ = NULL;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp27_ = _g_object_ref0 (_data_->_tmp26_);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->avatar_format);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->avatar_format = _data_->_tmp27_;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp28_ = NULL;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp28_ = _data_->avatar_format;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_tmp28_ != NULL) {
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->script);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 5468 "unattended-installer.c"
					}
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->script);
#line 5472 "unattended-installer.c"
				}
			}
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_list_free0 (_data_->s_collection);
#line 5477 "unattended-installer.c"
		}
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = NULL;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = _data_->avatar_path;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = NULL;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = _data_->avatar_format;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp32_ = NULL;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp32_ = boxes_unattended_avatar_file_new (_data_->self, _data_->_tmp30_, _data_->_tmp31_, &_data_->_inner_error_);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = _data_->_tmp32_;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_inner_error_ != NULL) {
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->avatar_format);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->pixbuf);
#line 5499 "unattended-installer.c"
			goto __catch77_g_error;
		}
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->self->priv->avatar_file);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->self->priv->avatar_file = _data_->_tmp29_;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp33_ = NULL;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp33_ = _data_->self->priv->avatar_file;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_add_unattended_file (_data_->self, (BoxesUnattendedFile*) _data_->_tmp33_);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->avatar_format);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->pixbuf);
#line 5516 "unattended-installer.c"
	}
	goto __finally77;
	__catch77_g_error:
	{
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp34_ = NULL;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp34_ = _data_->avatar_path;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp35_ = NULL;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp35_ = _data_->_vala1__error_;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp36_ = NULL;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp36_ = _data_->_tmp35_->message;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:662: Failed to load user avatar file '%s': %" \
"s", _data_->_tmp34_, _data_->_tmp36_);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 5541 "unattended-installer.c"
	}
	__finally77:
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->username);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_data_->_inner_error_);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5556 "unattended-installer.c"
	}
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->avatar_path);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->username);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5566 "unattended-installer.c"
	} else {
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5570 "unattended-installer.c"
	}
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5576 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_data_free (gpointer _data) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->extractor);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerExtractBootFilesData, _data_);
#line 5591 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files (BoxesUnattendedInstaller* self, BoxesISOExtractor* extractor, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesISOExtractor* _tmp1_ = NULL;
	BoxesISOExtractor* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerExtractBootFilesData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_extract_boot_files);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_extract_boot_files_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = extractor;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->extractor);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->extractor = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_extract_boot_files_co (_data_);
#line 5630 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 5640 "unattended-installer.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5644 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_extract_boot_files_co (_data_);
#line 5658 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_extract_boot_files_co (BoxesUnattendedInstallerExtractBootFilesData* _data_) {
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 5667 "unattended-installer.c"
		goto _state_0;
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 5671 "unattended-installer.c"
		goto _state_1;
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 5675 "unattended-installer.c"
		goto _state_2;
		default:
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 5680 "unattended-installer.c"
	}
	_state_0:
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->extractor;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_data_->_tmp1_, "kernel-path", &_data_->_tmp2_, NULL);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = boxes_iso_extractor_get_absolute_path (_data_->_tmp0_, _data_->_tmp4_, &_data_->_inner_error_);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp4_);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->src_path = _data_->_tmp6_;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5725 "unattended-installer.c"
		} else {
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5729 "unattended-installer.c"
		}
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5735 "unattended-installer.c"
	}
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = _data_->src_path;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = g_file_new_for_path (_data_->_tmp7_);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->src_file = _data_->_tmp8_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = NULL;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = _data_->src_file;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = NULL;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = _data_->self->kernel_file;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp11_ = NULL;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp11_ = _data_->cancellable;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_copy_file (_data_->_tmp9_, _data_->_tmp10_, _data_->_tmp11_, boxes_unattended_installer_extract_boot_files_ready, _data_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5765 "unattended-installer.c"
	_state_1:
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_copy_file_finish (_data_->_res_, &_data_->_inner_error_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->src_file);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->src_path);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5783 "unattended-installer.c"
		} else {
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5787 "unattended-installer.c"
		}
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5793 "unattended-installer.c"
	}
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp13_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp13_ = _data_->extractor;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp14_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp14_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp15_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_data_->_tmp14_, "initrd-path", &_data_->_tmp15_, NULL);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = boxes_iso_extractor_get_absolute_path (_data_->_tmp13_, _data_->_tmp17_, &_data_->_inner_error_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = NULL;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp17_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp12_ = _data_->_tmp19_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->src_file);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->src_path);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5841 "unattended-installer.c"
		} else {
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5845 "unattended-installer.c"
		}
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5851 "unattended-installer.c"
	}
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->src_path);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->src_path = _data_->_tmp12_;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp20_ = NULL;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp20_ = _data_->src_path;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = NULL;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = g_file_new_for_path (_data_->_tmp20_);
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->src_file);
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->src_file = _data_->_tmp21_;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = NULL;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = _data_->src_file;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp23_ = NULL;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp23_ = _data_->self->initrd_file;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp24_ = NULL;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp24_ = _data_->cancellable;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 2;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_copy_file (_data_->_tmp22_, _data_->_tmp23_, _data_->_tmp24_, boxes_unattended_installer_extract_boot_files_ready, _data_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5887 "unattended-installer.c"
	_state_2:
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_copy_file_finish (_data_->_res_, &_data_->_inner_error_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_inner_error_ != NULL) {
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->src_file);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->src_path);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5905 "unattended-installer.c"
		} else {
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5909 "unattended-installer.c"
		}
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5915 "unattended-installer.c"
	}
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->src_file);
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->src_path);
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5925 "unattended-installer.c"
	} else {
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5929 "unattended-installer.c"
	}
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5935 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_get_product_key_format (BoxesUnattendedInstaller* self) {
	gchar* result = NULL;
	OsinfoInstallScriptList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->scripts;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_list_get_elements ((OsinfoList*) _tmp0_);
#line 5949 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp1_;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 5957 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 5961 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp2_ = NULL;
				OsinfoInstallScript* _tmp3_ = NULL;
				OsinfoInstallConfigParam* param = NULL;
				OsinfoInstallScript* _tmp4_ = NULL;
				OsinfoInstallConfigParam* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
				OsinfoInstallConfigParam* _tmp7_ = NULL;
				gboolean _tmp10_ = FALSE;
				gchar* format = NULL;
				OsinfoInstallScript* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = s;
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp2_) : NULL);
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp3_;
#line 681 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = script;
#line 681 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = osinfo_install_script_get_config_param (_tmp4_, OSINFO_INSTALL_CONFIG_PROP_REG_PRODUCTKEY);
#line 681 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				param = _tmp5_;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = param;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp7_ == NULL) {
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = TRUE;
#line 5995 "unattended-installer.c"
				} else {
					OsinfoInstallConfigParam* _tmp8_ = NULL;
					gboolean _tmp9_ = FALSE;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = param;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = osinfo_install_config_param_is_optional (_tmp8_);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = _tmp9_;
#line 6005 "unattended-installer.c"
				}
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = _tmp6_;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp10_) {
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (param);
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					continue;
#line 6017 "unattended-installer.c"
				}
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = script;
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = osinfo_install_script_get_product_key_format (_tmp11_);
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = g_strdup (_tmp12_);
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				format = _tmp13_;
#line 686 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14_ = format;
#line 686 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp14_ != NULL) {
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					result = format;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (param);
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (s_collection);
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return result;
#line 6041 "unattended-installer.c"
				}
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (format);
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (param);
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 6049 "unattended-installer.c"
			}
		}
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 6054 "unattended-installer.c"
	}
#line 690 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = NULL;
#line 690 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6060 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriversData, _data_);
#line 6075 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers (BoxesUnattendedInstaller* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriversData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_drivers);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_drivers_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = progress;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_co (_data_);
#line 6114 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6122 "unattended-installer.c"
}


static void _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self) {
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_add_unattended_file (self, file);
#line 6129 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_co (_data_);
#line 6143 "unattended-installer.c"
}


static void _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self) {
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_add_secondary_unattended_file (self, file);
#line 6150 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_co (BoxesUnattendedInstallerSetupDriversData* _data_) {
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 6159 "unattended-installer.c"
		goto _state_0;
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 6163 "unattended-installer.c"
		goto _state_1;
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 6167 "unattended-installer.c"
		goto _state_2;
		default:
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 6172 "unattended-installer.c"
	}
	_state_0:
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->progress;
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _ ("Downloading device drivers...");
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_activity_progress_set_info (_data_->_tmp0_, _data_->_tmp1_);
#line 698 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 698 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = boxes_unattended_installer_get_pre_installer_scripts (_data_->self);
#line 698 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->scripts = _data_->_tmp2_;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->scripts;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = boxes_unattended_installer_get_pre_installable_drivers (_data_->self, _data_->_tmp3_);
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _data_->_tmp4_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->drivers;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = 0U;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = g_list_length (_data_->_tmp6_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp7_ != ((guint) 0)) {
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = NULL;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = _data_->scripts;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = 0U;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = g_list_length (_data_->_tmp8_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = _data_->_tmp9_ != ((guint) 0);
#line 6221 "unattended-installer.c"
	} else {
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = FALSE;
#line 6225 "unattended-installer.c"
	}
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = FALSE;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = _data_->_tmp5_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp10_) {
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = NULL;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = _data_->progress;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = NULL;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = boxes_activity_progress_add_child_activity (_data_->_tmp11_, 0.5);
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->drivers_progress = _data_->_tmp12_;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = NULL;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = _data_->drivers;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = NULL;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = _data_->drivers_progress;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = NULL;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = _data_->cancellable;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list (_data_->self, _data_->_tmp13_, _data_->_tmp14_, _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func, _data_->self, _data_->_tmp15_, boxes_unattended_installer_setup_drivers_ready, _data_);
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 6261 "unattended-installer.c"
		_state_1:
#line 703 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list_finish (_data_->self, _data_->_res_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->drivers_progress);
#line 6267 "unattended-installer.c"
	} else {
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = NULL;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = _data_->progress;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_activity_progress_set_progress (_data_->_tmp16_, 0.5);
#line 6275 "unattended-installer.c"
	}
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = NULL;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = boxes_unattended_installer_get_post_installer_scripts (_data_->self);
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->scripts = _data_->_tmp17_;
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = NULL;
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = _data_->scripts;
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = NULL;
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = boxes_unattended_installer_get_post_installable_drivers (_data_->self, _data_->_tmp18_);
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _data_->_tmp19_;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = NULL;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = _data_->drivers;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = 0U;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = g_list_length (_data_->_tmp21_);
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp22_ != ((guint) 0)) {
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp23_ = NULL;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp23_ = _data_->scripts;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = 0U;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = g_list_length (_data_->_tmp23_);
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = _data_->_tmp24_ != ((guint) 0);
#line 6317 "unattended-installer.c"
	} else {
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = FALSE;
#line 6321 "unattended-installer.c"
	}
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp25_ = FALSE;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp25_ = _data_->_tmp20_;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp25_) {
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp26_ = NULL;
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp26_ = _data_->progress;
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp27_ = NULL;
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp27_ = boxes_activity_progress_add_child_activity (_data_->_tmp26_, 0.5);
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_vala1_drivers_progress = _data_->_tmp27_;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp28_ = NULL;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp28_ = _data_->drivers;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = NULL;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = _data_->_vala1_drivers_progress;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = NULL;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = _data_->cancellable;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 2;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list (_data_->self, _data_->_tmp28_, _data_->_tmp29_, _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func, _data_->self, _data_->_tmp30_, boxes_unattended_installer_setup_drivers_ready, _data_);
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 6357 "unattended-installer.c"
		_state_2:
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list_finish (_data_->self, _data_->_res_);
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->_vala1_drivers_progress);
#line 6363 "unattended-installer.c"
	} else {
#line 714 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = NULL;
#line 714 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = _data_->progress;
#line 714 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_activity_progress_set_progress (_data_->_tmp31_, 1.0);
#line 6371 "unattended-installer.c"
	}
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6381 "unattended-installer.c"
	} else {
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6385 "unattended-installer.c"
	}
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 6391 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriversFromListData, _data_);
#line 6406 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list (BoxesUnattendedInstaller* self, GList* drivers, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp4_ = NULL;
	void* _tmp4__target = NULL;
	GCancellable* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriversFromListData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_drivers_from_list);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_drivers_from_list_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = drivers;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _tmp1_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = progress;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp3_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = add_func;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4__target = add_func_target;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func_target = _tmp4__target;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp6_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_from_list_co (_data_);
#line 6460 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6468 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_from_list_co (_data_);
#line 6482 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_from_list_co (BoxesUnattendedInstallerSetupDriversFromListData* _data_) {
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 6491 "unattended-installer.c"
		goto _state_0;
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 6495 "unattended-installer.c"
		goto _state_1;
		default:
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 6500 "unattended-installer.c"
	}
	_state_0:
#line 721 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 721 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->drivers;
#line 721 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = 0U;
#line 721 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_list_length (_data_->_tmp0_);
#line 721 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver_progress_scale = 1. / _data_->_tmp1_;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = _data_->drivers;
#line 6517 "unattended-installer.c"
	{
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->driver_collection = _data_->_tmp2_;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->driver_it = _data_->driver_collection; _data_->driver_it != NULL; _data_->driver_it = _data_->driver_it->next) {
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp3_ = NULL;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp3_ = _g_object_ref0 ((OsinfoDeviceDriver*) _data_->driver_it->data);
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->driver = _data_->_tmp3_;
#line 6529 "unattended-installer.c"
			{
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp4_ = NULL;
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp4_ = _data_->progress;
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp5_ = 0.0;
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp5_ = _data_->driver_progress_scale;
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = NULL;
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = boxes_activity_progress_add_child_activity (_data_->_tmp4_, _data_->_tmp5_);
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->driver_progress = _data_->_tmp6_;
#line 6545 "unattended-installer.c"
				{
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = NULL;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = _data_->driver;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = NULL;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = _data_->driver_progress;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9_ = NULL;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9__target = NULL;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9_ = _data_->add_func;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9__target = _data_->add_func_target;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp10_ = NULL;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp10_ = _data_->cancellable;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_state_ = 1;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_installer_setup_driver (_data_->self, _data_->_tmp7_, _data_->_tmp8_, _data_->_tmp9_, _data_->_tmp9__target, _data_->_tmp10_, boxes_unattended_installer_setup_drivers_from_list_ready, _data_);
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 6573 "unattended-installer.c"
					_state_1:
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_installer_setup_driver_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_inner_error_ != NULL) {
#line 6579 "unattended-installer.c"
						goto __catch78_g_error;
					}
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp11_ = NULL;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp11_ = _data_->self->priv->additional_devices;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp12_ = NULL;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp12_ = _data_->driver;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp13_ = NULL;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp13_ = osinfo_device_driver_get_devices (_data_->_tmp12_);
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					osinfo_list_add_all ((OsinfoList*) _data_->_tmp11_, (OsinfoList*) _data_->_tmp13_);
#line 6596 "unattended-installer.c"
				}
				goto __finally78;
				__catch78_g_error:
				{
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->e = _data_->_inner_error_;
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_inner_error_ = NULL;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp14_ = NULL;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp14_ = _data_->driver;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp15_ = NULL;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp15_ = osinfo_device_driver_get_location (_data_->_tmp14_);
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp16_ = NULL;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp16_ = _data_->e;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp17_ = NULL;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp17_ = _data_->_tmp16_->message;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:729: Failed to make use of drivers at '%s': " \
"%s", _data_->_tmp15_, _data_->_tmp17_);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_error_free0 (_data_->e);
#line 6625 "unattended-installer.c"
				}
				__finally78:
				{
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp18_ = NULL;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp18_ = _data_->driver_progress;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_activity_progress_set_progress (_data_->_tmp18_, 1.0);
#line 6635 "unattended-installer.c"
				}
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_data_->_inner_error_ != NULL) {
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver_progress);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_clear_error (&_data_->_inner_error_);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 6649 "unattended-installer.c"
				}
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver_progress);
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver);
#line 6655 "unattended-installer.c"
			}
		}
	}
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6663 "unattended-installer.c"
	} else {
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6667 "unattended-installer.c"
	}
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 6673 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->driver);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriverData, _data_);
#line 6690 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	OsinfoDeviceDriver* _tmp1_ = NULL;
	OsinfoDeviceDriver* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp5_ = NULL;
	void* _tmp5__target = NULL;
	GCancellable* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriverData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_driver);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_driver_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = driver;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->driver);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = progress;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp4_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = add_func;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5__target = add_func_target;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func = _tmp5_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func_target = _tmp5__target;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = cancellable;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp7_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_driver_co (_data_);
#line 6749 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 6759 "unattended-installer.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6763 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_driver_co (_data_);
#line 6777 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_driver_co (BoxesUnattendedInstallerSetupDriverData* _data_) {
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 6786 "unattended-installer.c"
		goto _state_0;
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 6790 "unattended-installer.c"
		goto _state_1;
		default:
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 6795 "unattended-installer.c"
	}
	_state_0:
#line 740 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 740 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_downloader_get_instance ();
#line 740 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->downloader = _data_->_tmp0_;
#line 742 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver_files = NULL;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _data_->driver;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = osinfo_device_driver_get_location (_data_->_tmp1_);
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = g_strdup (_data_->_tmp2_);
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->location = _data_->_tmp3_;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->location;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = g_compute_checksum_for_string (G_CHECKSUM_MD5, _data_->_tmp4_, (gsize) (-1));
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->location_checksum = _data_->_tmp5_;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->driver;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = osinfo_device_driver_get_files (_data_->_tmp6_);
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->files = _data_->_tmp7_;
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = _data_->files;
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = 0U;
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = g_list_length (_data_->_tmp8_);
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->file_progress_scale = 1. / _data_->_tmp9_;
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = NULL;
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = _data_->files;
#line 6854 "unattended-installer.c"
	{
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->filename_collection = _data_->_tmp10_;
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->filename_it = _data_->filename_collection; _data_->filename_it != NULL; _data_->filename_it = _data_->filename_it->next) {
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->filename = (const gchar*) _data_->filename_it->data;
#line 6862 "unattended-installer.c"
			{
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp11_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp11_ = _data_->location;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp12_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp12_ = g_strconcat (_data_->_tmp11_, "/", NULL);
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp13_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp13_ = _data_->_tmp12_;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp14_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp14_ = _data_->filename;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp15_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp15_ = g_strconcat (_data_->_tmp13_, _data_->_tmp14_, NULL);
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp16_ = NULL;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp16_ = _data_->_tmp15_;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp13_);
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file_uri = _data_->_tmp16_;
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp17_ = NULL;
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp17_ = _data_->file_uri;
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp18_ = NULL;
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp18_ = g_file_new_for_uri (_data_->_tmp17_);
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file = _data_->_tmp18_;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp19_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp19_ = _data_->location_checksum;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp20_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp20_ = g_strconcat (_data_->_tmp19_, "-", NULL);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp22_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp22_ = _data_->file;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp23_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp23_ = g_file_get_basename (_data_->_tmp22_);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp24_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp25_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp25_ = g_strconcat (_data_->_tmp21_, _data_->_tmp24_, NULL);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp26_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp26_ = _data_->_tmp25_;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp27_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp27_ = boxes_get_drivers_cache (_data_->_tmp26_);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp28_ = NULL;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp28_ = _data_->_tmp27_;
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp26_);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp24_);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp21_);
#line 752 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_path = _data_->_tmp28_;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp29_ = NULL;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp29_ = _data_->progress;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp30_ = 0.0;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp30_ = _data_->file_progress_scale;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp31_ = NULL;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp31_ = boxes_activity_progress_add_child_activity (_data_->_tmp29_, _data_->_tmp30_);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file_progress = _data_->_tmp31_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp33_ = NULL;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp33_ = _data_->downloader;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp34_ = NULL;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp34_ = _data_->file;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp35_ = NULL;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp35_ = _data_->cached_path;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp36_ = NULL;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp36_ = _data_->file_progress;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_state_ = 1;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_downloader_download (_data_->_tmp33_, _data_->_tmp34_, _data_->_tmp35_, _data_->_tmp36_, boxes_unattended_installer_setup_driver_ready, _data_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				return FALSE;
#line 6986 "unattended-installer.c"
				_state_1:
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp37_ = NULL;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp37_ = boxes_downloader_download_finish (_data_->_tmp33_, _data_->_res_, &_data_->_inner_error_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp32_ = _data_->_tmp37_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_data_->_inner_error_ != NULL) {
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_error_free (_data_->_inner_error_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->file_progress);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->cached_path);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->file);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->file_uri);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (_data_->files);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->location_checksum);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->location);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					__g_list_free__g_object_unref0_0 (_data_->driver_files);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->downloader);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_state_ == 0) {
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 7022 "unattended-installer.c"
					} else {
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete (_data_->_async_result);
#line 7026 "unattended-installer.c"
					}
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_unref (_data_->_async_result);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 7032 "unattended-installer.c"
				}
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file = _data_->_tmp32_;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp38_ = NULL;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp38_ = _data_->file_progress;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_activity_progress_set_progress (_data_->_tmp38_, 1.0);
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp39_ = NULL;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp39_ = _data_->cached_path;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp40_ = NULL;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp40_ = _data_->filename;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp41_ = NULL;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp41_ = boxes_unattended_raw_file_new (_data_->self, _data_->_tmp39_, _data_->_tmp40_);
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->driver_files = g_list_append (_data_->driver_files, (BoxesUnattendedFile*) _data_->_tmp41_);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file_progress);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->cached_path);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->file_uri);
#line 7066 "unattended-installer.c"
			}
		}
	}
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp42_ = NULL;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp42_ = _data_->driver_files;
#line 7074 "unattended-installer.c"
	{
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->driver_file_collection = _data_->_tmp42_;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->driver_file_it = _data_->driver_file_collection; _data_->driver_file_it != NULL; _data_->driver_file_it = _data_->driver_file_it->next) {
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp43_ = NULL;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp43_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->driver_file_it->data);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->driver_file = _data_->_tmp43_;
#line 7086 "unattended-installer.c"
			{
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44_ = NULL;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44__target = NULL;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44_ = _data_->add_func;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44__target = _data_->add_func_target;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp45_ = NULL;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp45_ = _data_->driver_file;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44_ (_data_->_tmp45_, _data_->_tmp44__target);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver_file);
#line 7104 "unattended-installer.c"
			}
		}
	}
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_list_free0 (_data_->files);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->location_checksum);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->location);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->driver_files);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->downloader);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 7122 "unattended-installer.c"
	} else {
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 7126 "unattended-installer.c"
	}
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 7132 "unattended-installer.c"
}


static gboolean __lambda50_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver) {
	gboolean result = FALSE;
	OsinfoDeviceDriver* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = driver;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_device_driver_get_pre_installable (_tmp0_);
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7150 "unattended-installer.c"
}


static gboolean ___lambda50__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda50_ (self, driver);
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7159 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq __lambda51_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	OsinfoDeviceDriverSigningReq result = 0;
	OsinfoInstallScript* _tmp0_ = NULL;
	OsinfoDeviceDriverSigningReq _tmp1_ = 0;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, 0);
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_pre_install_drivers_signing_req (_tmp0_);
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7177 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq ___lambda51__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self) {
	OsinfoDeviceDriverSigningReq result;
	result = __lambda51_ (self, script);
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7186 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_pre_installable_drivers (BoxesUnattendedInstaller* self, GList* preinst_scripts) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = preinst_scripts;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_installable_drivers (self, _tmp0_, ___lambda50__boxes_unattended_installer_driver_installable_func, self, ___lambda51__boxes_unattended_installer_script_driver_signing_req_func, self);
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7204 "unattended-installer.c"
}


static gboolean __lambda58_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver) {
	gboolean result = FALSE;
	OsinfoDeviceDriver* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = driver;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_device_driver_get_pre_installable (_tmp0_);
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = !_tmp1_;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7222 "unattended-installer.c"
}


static gboolean ___lambda58__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda58_ (self, driver);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7231 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq __lambda59_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	OsinfoDeviceDriverSigningReq result = 0;
	OsinfoInstallScript* _tmp0_ = NULL;
	OsinfoDeviceDriverSigningReq _tmp1_ = 0;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, 0);
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_post_install_drivers_signing_req (_tmp0_);
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7249 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq ___lambda59__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self) {
	OsinfoDeviceDriverSigningReq result;
	result = __lambda59_ (self, script);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7258 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_post_installable_drivers (BoxesUnattendedInstaller* self, GList* postinst_scripts) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = postinst_scripts;
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_installable_drivers (self, _tmp0_, ___lambda58__boxes_unattended_installer_driver_installable_func, self, ___lambda59__boxes_unattended_installer_script_driver_signing_req_func, self);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7276 "unattended-installer.c"
}


static Block61Data* block61_data_ref (Block61Data* _data61_) {
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_atomic_int_inc (&_data61_->_ref_count_);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return _data61_;
#line 7285 "unattended-installer.c"
}


static void block61_data_unref (void * _userdata_) {
	Block61Data* _data61_;
	_data61_ = (Block61Data*) _userdata_;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_atomic_int_dec_and_test (&_data61_->_ref_count_)) {
#line 7294 "unattended-installer.c"
		BoxesUnattendedInstaller * self;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self = _data61_->self;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_slice_free (Block61Data, _data61_);
#line 7302 "unattended-installer.c"
	}
}


static gboolean __lambda49_ (Block61Data* _data61_, OsinfoDeviceDriver* driver) {
	BoxesUnattendedInstaller * self;
	gboolean result = FALSE;
	BoxesUnattendedInstallerDriverInstallableFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	OsinfoDeviceDriver* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	OsinfoDeviceDriver* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp7_ = FALSE;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = _data61_->self;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _data61_->installable_func;
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0__target = _data61_->installable_func_target;
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = driver;
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp0_ (_tmp1_, _tmp0__target);
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp2_) {
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = FALSE;
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 7336 "unattended-installer.c"
	}
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = driver;
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_device_driver_get_signed (_tmp4_);
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp5_) {
#line 7344 "unattended-installer.c"
		gboolean _tmp6_ = FALSE;
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _data61_->signing_required;
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = _tmp6_;
#line 7350 "unattended-installer.c"
	} else {
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = FALSE;
#line 7354 "unattended-installer.c"
	}
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp3_;
#line 814 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp7_) {
#line 7360 "unattended-installer.c"
		gboolean _tmp8_ = FALSE;
#line 815 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = _data61_->driver_signing_mutable;
#line 815 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp8_) {
#line 816 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->priv->driver_signing = FALSE;
#line 7368 "unattended-installer.c"
		} else {
			OsinfoDeviceDriver* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp9_ = driver;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp10_ = osinfo_device_driver_get_location (_tmp9_);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:818: Driver from location '%s' is not signed" \
". Ignoring..", _tmp10_);
#line 820 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			result = FALSE;
#line 820 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return result;
#line 7382 "unattended-installer.c"
		}
	}
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = TRUE;
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7389 "unattended-installer.c"
}


static gboolean ___lambda49__boxes_unattended_installer_driver_test_function (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda49_ (self, driver);
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7398 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_installable_drivers (BoxesUnattendedInstaller* self, GList* scripts, BoxesUnattendedInstallerDriverInstallableFunc installable_func, void* installable_func_target, BoxesUnattendedInstallerScriptDriverSigningReqFunc signing_req_func, void* signing_req_func_target) {
	GList* result = NULL;
	Block61Data* _data61_;
	BoxesUnattendedInstallerDriverInstallableFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GList* _tmp1_ = NULL;
	gboolean _tmp10_ = FALSE;
	GList* _tmp21_ = NULL;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_ = g_slice_new0 (Block61Data);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->_ref_count_ = 1;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->self = g_object_ref (self);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = installable_func;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0__target = installable_func_target;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->installable_func = _tmp0_;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->installable_func_target = _tmp0__target;
#line 787 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->signing_required = FALSE;
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = scripts;
#line 7430 "unattended-installer.c"
	{
		GList* script_collection = NULL;
		GList* script_it = NULL;
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		script_collection = _tmp1_;
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (script_it = script_collection; script_it != NULL; script_it = script_it->next) {
#line 7438 "unattended-installer.c"
			OsinfoInstallScript* _tmp2_ = NULL;
			OsinfoInstallScript* script = NULL;
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = _g_object_ref0 ((OsinfoInstallScript*) script_it->data);
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			script = _tmp2_;
#line 7445 "unattended-installer.c"
			{
				BoxesUnattendedInstallerScriptDriverSigningReqFunc _tmp3_ = NULL;
				void* _tmp3__target = NULL;
				OsinfoInstallScript* _tmp4_ = NULL;
				OsinfoDeviceDriverSigningReq _tmp5_ = 0;
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = signing_req_func;
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3__target = signing_req_func_target;
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = script;
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = _tmp3_ (_tmp4_, _tmp3__target);
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp5_ != OSINFO_DEVICE_DRIVER_SIGNING_REQ_NONE) {
#line 7461 "unattended-installer.c"
					OsinfoInstallScript* _tmp6_ = NULL;
					gchar* _tmp7_ = NULL;
					gchar* _tmp8_ = NULL;
					gchar* _tmp9_ = NULL;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = script;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_get ((OsinfoEntity*) _tmp6_, "id", &_tmp7_, NULL);
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = _tmp7_;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = _tmp8_;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:790: Script '%s' requires signed drivers.", _tmp9_);
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_tmp9_);
#line 791 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data61_->signing_required = TRUE;
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					break;
#line 7484 "unattended-installer.c"
				}
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 7488 "unattended-installer.c"
			}
		}
	}
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_->driver_signing_mutable = FALSE;
#line 797 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _data61_->signing_required;
#line 797 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp10_) {
#line 7498 "unattended-installer.c"
		OsinfoInstallScriptList* _tmp11_ = NULL;
		GList* _tmp12_ = NULL;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = self->scripts;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = osinfo_list_get_elements ((OsinfoList*) _tmp11_);
#line 7505 "unattended-installer.c"
		{
			GList* s_collection = NULL;
			GList* s_it = NULL;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s_collection = _tmp12_;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 7513 "unattended-installer.c"
				OsinfoEntity* s = NULL;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				s = (OsinfoEntity*) s_it->data;
#line 7517 "unattended-installer.c"
				{
					OsinfoInstallScript* script = NULL;
					OsinfoEntity* _tmp13_ = NULL;
					OsinfoInstallScript* _tmp14_ = NULL;
					OsinfoInstallScript* _tmp15_ = NULL;
					gboolean _tmp16_ = FALSE;
#line 800 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp13_ = s;
#line 800 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp13_) : NULL);
#line 800 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					script = _tmp14_;
#line 802 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp15_ = script;
#line 802 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp16_ = osinfo_install_script_has_config_param_name (_tmp15_, OSINFO_INSTALL_CONFIG_PROP_DRIVER_SIGNING);
#line 802 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp16_) {
#line 7536 "unattended-installer.c"
						OsinfoInstallScript* _tmp17_ = NULL;
						gchar* _tmp18_ = NULL;
						gchar* _tmp19_ = NULL;
						gchar* _tmp20_ = NULL;
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp17_ = script;
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_object_get ((OsinfoEntity*) _tmp17_, "id", &_tmp18_, NULL);
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp19_ = _tmp18_;
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp20_ = _tmp19_;
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_debug ("unattended-installer.vala:803: Script '%s' allows disabling of driver " \
"signature checks.", _tmp20_);
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_tmp20_);
#line 804 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data61_->driver_signing_mutable = TRUE;
#line 806 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (script);
#line 806 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 7559 "unattended-installer.c"
					}
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 7563 "unattended-installer.c"
				}
			}
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_list_free0 (s_collection);
#line 7568 "unattended-installer.c"
		}
	}
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = boxes_unattended_installer_get_drivers (self, ___lambda49__boxes_unattended_installer_driver_test_function, _data61_);
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp21_;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	block61_data_unref (_data61_);
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data61_ = NULL;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7581 "unattended-installer.c"
}


static void _g_free0_ (gpointer var) {
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	var = (g_free (var), NULL);
#line 7588 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_drivers (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerDriverTestFunction test_func, void* test_func_target) {
	GList* result = NULL;
	GHashTable* drivers = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	OsinfoDeviceDriverList* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	GList* ret = NULL;
	GHashTable* _tmp36_ = NULL;
	GList* _tmp37_ = NULL;
#line 828 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = g_str_hash;
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = g_str_equal;
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	drivers = _tmp2_;
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = ((BoxesInstallerMedia*) self)->os;
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = osinfo_os_get_device_drivers (_tmp3_);
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_list_get_elements ((OsinfoList*) _tmp4_);
#line 7620 "unattended-installer.c"
	{
		GList* d_collection = NULL;
		GList* d_it = NULL;
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		d_collection = _tmp5_;
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (d_it = d_collection; d_it != NULL; d_it = d_it->next) {
#line 7628 "unattended-installer.c"
			OsinfoEntity* d = NULL;
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			d = (OsinfoEntity*) d_it->data;
#line 7632 "unattended-installer.c"
			{
				OsinfoDeviceDriver* driver = NULL;
				OsinfoEntity* _tmp6_ = NULL;
				OsinfoDeviceDriver* _tmp7_ = NULL;
				BoxesCPUArchCompatibility compatibility = 0;
				OsinfoMedia* _tmp8_ = NULL;
				gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				OsinfoDeviceDriver* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				BoxesCPUArchCompatibility _tmp14_ = 0;
				BoxesCPUArchCompatibility _tmp15_ = 0;
				gchar* location = NULL;
				OsinfoDeviceDriver* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				BoxesCPUArchCompatibility _tmp19_ = 0;
#line 832 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = d;
#line 832 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, osinfo_device_driver_get_type ()) ? ((OsinfoDeviceDriver*) _tmp6_) : NULL);
#line 832 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				driver = _tmp7_;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8_ = ((BoxesInstallerMedia*) self)->os_media;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				g_object_get (_tmp8_, "architecture", &_tmp9_, NULL);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = _tmp9_;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = _tmp10_;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = driver;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = osinfo_device_driver_get_architecture (_tmp12_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14_ = boxes_compare_cpu_architectures (_tmp11_, _tmp13_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp15_ = _tmp14_;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_tmp11_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				compatibility = _tmp15_;
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp16_ = driver;
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = osinfo_device_driver_get_location (_tmp16_);
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				location = _tmp18_;
#line 836 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp19_ = compatibility;
#line 836 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp19_ == BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL) {
#line 7689 "unattended-installer.c"
					GHashTable* _tmp20_ = NULL;
					const gchar* _tmp21_ = NULL;
					gchar* _tmp22_ = NULL;
					OsinfoDeviceDriver* _tmp23_ = NULL;
					OsinfoDeviceDriver* _tmp24_ = NULL;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp20_ = drivers;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp21_ = location;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp22_ = g_strdup (_tmp21_);
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp23_ = driver;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp24_ = _g_object_ref0 (_tmp23_);
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_hash_table_replace (_tmp20_, _tmp22_, _tmp24_);
#line 7707 "unattended-installer.c"
				} else {
					gboolean _tmp25_ = FALSE;
					BoxesCPUArchCompatibility _tmp26_ = 0;
					gboolean _tmp30_ = FALSE;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp26_ = compatibility;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp26_ == BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE) {
#line 7716 "unattended-installer.c"
						GHashTable* _tmp27_ = NULL;
						const gchar* _tmp28_ = NULL;
						gconstpointer _tmp29_ = NULL;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp27_ = drivers;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp28_ = location;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp29_ = g_hash_table_lookup (_tmp27_, _tmp28_);
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp25_ = ((OsinfoDeviceDriver*) _tmp29_) == NULL;
#line 7728 "unattended-installer.c"
					} else {
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp25_ = FALSE;
#line 7732 "unattended-installer.c"
					}
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp30_ = _tmp25_;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp30_) {
#line 7738 "unattended-installer.c"
						GHashTable* _tmp31_ = NULL;
						const gchar* _tmp32_ = NULL;
						gchar* _tmp33_ = NULL;
						OsinfoDeviceDriver* _tmp34_ = NULL;
						OsinfoDeviceDriver* _tmp35_ = NULL;
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp31_ = drivers;
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp32_ = location;
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp33_ = g_strdup (_tmp32_);
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp34_ = driver;
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp35_ = _g_object_ref0 (_tmp34_);
#line 839 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_hash_table_insert (_tmp31_, _tmp33_, _tmp35_);
#line 7756 "unattended-installer.c"
					}
				}
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (location);
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (driver);
#line 7763 "unattended-installer.c"
			}
		}
#line 831 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (d_collection);
#line 7768 "unattended-installer.c"
	}
#line 847 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	ret = NULL;
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = drivers;
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp37_ = g_hash_table_get_values (_tmp36_);
#line 7776 "unattended-installer.c"
	{
		GList* driver_collection = NULL;
		GList* driver_it = NULL;
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		driver_collection = _tmp37_;
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (driver_it = driver_collection; driver_it != NULL; driver_it = driver_it->next) {
#line 7784 "unattended-installer.c"
			OsinfoDeviceDriver* driver = NULL;
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			driver = (OsinfoDeviceDriver*) driver_it->data;
#line 7788 "unattended-installer.c"
			{
				BoxesUnattendedInstallerDriverTestFunction _tmp38_ = NULL;
				void* _tmp38__target = NULL;
				OsinfoDeviceDriver* _tmp39_ = NULL;
				gboolean _tmp40_ = FALSE;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp38_ = test_func;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp38__target = test_func_target;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp39_ = driver;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp40_ = _tmp38_ (_tmp39_, _tmp38__target);
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp40_) {
#line 7804 "unattended-installer.c"
					OsinfoDeviceDriver* _tmp41_ = NULL;
					OsinfoDeviceDriver* _tmp42_ = NULL;
#line 850 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp41_ = driver;
#line 850 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp42_ = _g_object_ref0 (_tmp41_);
#line 850 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					ret = g_list_prepend (ret, _tmp42_);
#line 7813 "unattended-installer.c"
				}
			}
		}
#line 848 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (driver_collection);
#line 7819 "unattended-installer.c"
	}
#line 852 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	ret = g_list_reverse (ret);
#line 854 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = ret;
#line 854 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_hash_table_unref0 (drivers);
#line 854 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7829 "unattended-installer.c"
}


static gboolean __lambda48_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	gboolean result = FALSE;
	OsinfoInstallScript* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, FALSE);
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_can_pre_install_drivers (_tmp0_);
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7847 "unattended-installer.c"
}


static gboolean ___lambda48__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self) {
	gboolean result;
	result = __lambda48_ (self, script);
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7856 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_pre_installer_scripts (BoxesUnattendedInstaller* self) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
#line 859 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_scripts (self, ___lambda48__boxes_unattended_installer_script_test_function, self);
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 860 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7871 "unattended-installer.c"
}


static gboolean __lambda57_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	gboolean result = FALSE;
	OsinfoInstallScript* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, FALSE);
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_can_post_install_drivers (_tmp0_);
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7889 "unattended-installer.c"
}


static gboolean ___lambda57__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self) {
	gboolean result;
	result = __lambda57_ (self, script);
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7898 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_post_installer_scripts (BoxesUnattendedInstaller* self) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
#line 863 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_scripts (self, ___lambda57__boxes_unattended_installer_script_test_function, self);
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 864 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7913 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_scripts (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerScriptTestFunction test_func, void* test_func_target) {
	GList* result = NULL;
	GList* scripts = NULL;
	OsinfoInstallScriptList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 867 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 868 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	scripts = NULL;
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->scripts;
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_list_get_elements ((OsinfoList*) _tmp0_);
#line 7930 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp1_;
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 7938 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 7942 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp2_ = NULL;
				OsinfoInstallScript* _tmp3_ = NULL;
				BoxesUnattendedInstallerScriptTestFunction _tmp4_ = NULL;
				void* _tmp4__target = NULL;
				OsinfoInstallScript* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
#line 871 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = s;
#line 871 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp2_) : NULL);
#line 871 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp3_;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = test_func;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4__target = test_func_target;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = script;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = _tmp4_ (_tmp5_, _tmp4__target);
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp6_) {
#line 7967 "unattended-installer.c"
					OsinfoInstallScript* _tmp7_ = NULL;
					OsinfoInstallScript* _tmp8_ = NULL;
#line 874 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp7_ = script;
#line 874 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = _g_object_ref0 (_tmp7_);
#line 874 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					scripts = g_list_append (scripts, _tmp8_);
#line 7976 "unattended-installer.c"
				}
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 7980 "unattended-installer.c"
			}
		}
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 7985 "unattended-installer.c"
	}
#line 877 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = scripts;
#line 877 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7991 "unattended-installer.c"
}


static gchar** _vala_array_dup4 (gchar** self, int length) {
	gchar** result;
	int i;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = g_new0 (gchar*, length + 1);
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	for (i = 0; i < length; i++) {
#line 8002 "unattended-installer.c"
		gchar* _tmp0_ = NULL;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = g_strdup (self[i]);
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result[i] = _tmp0_;
#line 8008 "unattended-installer.c"
	}
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8012 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_get_preferred_language (BoxesUnattendedInstaller* self) {
	gchar* result = NULL;
	gchar** system_langs = NULL;
	gchar** _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gint system_langs_length1 = 0;
	gint _system_langs_size_ = 0;
	GHashTable* media_langs = NULL;
	GHashFunc _tmp3_ = NULL;
	GEqualFunc _tmp4_ = NULL;
	GHashTable* _tmp5_ = NULL;
	GList* media_langs_list = NULL;
	OsinfoMedia* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	GList* _tmp9_ = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	GList* _tmp19_ = NULL;
	gchar* lang = NULL;
	gchar** _tmp25_ = NULL;
	gint _tmp25__length1 = 0;
	const gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
#line 881 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_ = g_get_language_names ();
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = (_tmp1_ != NULL) ? _vala_array_dup4 (_tmp1_, _vala_array_length (_tmp0_)) : ((gpointer) _tmp1_);
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2__length1 = _vala_array_length (_tmp0_);
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs = _tmp2_;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs_length1 = _tmp2__length1;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_system_langs_size_ = system_langs_length1;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = g_str_hash;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = g_str_equal;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = g_hash_table_new_full (_tmp3_, _tmp4_, _g_free0_, NULL);
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs = _tmp5_;
#line 884 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = ((BoxesInstallerMedia*) self)->os_media;
#line 884 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = osinfo_media_get_languages (_tmp6_);
#line 884 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = _tmp7_;
#line 884 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs_list = _tmp8_;
#line 886 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = media_langs_list;
#line 8077 "unattended-installer.c"
	{
		GList* lang_collection = NULL;
		GList* lang_it = NULL;
#line 886 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection = _tmp9_;
#line 886 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (lang_it = lang_collection; lang_it != NULL; lang_it = lang_it->next) {
#line 8085 "unattended-installer.c"
			const gchar* lang = NULL;
#line 886 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			lang = (const gchar*) lang_it->data;
#line 8089 "unattended-installer.c"
			{
				GHashTable* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
#line 887 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = media_langs;
#line 887 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = lang;
#line 887 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = g_strdup (_tmp11_);
#line 887 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				g_hash_table_add (_tmp10_, _tmp12_);
#line 8102 "unattended-installer.c"
			}
		}
	}
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = system_langs;
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13__length1 = system_langs_length1;
#line 8110 "unattended-installer.c"
	{
		gchar** lang_collection = NULL;
		gint lang_collection_length1 = 0;
		gint _lang_collection_size_ = 0;
		gint lang_it = 0;
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection = _tmp13_;
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection_length1 = _tmp13__length1;
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (lang_it = 0; lang_it < _tmp13__length1; lang_it = lang_it + 1) {
#line 8122 "unattended-installer.c"
			gchar* _tmp14_ = NULL;
			gchar* lang = NULL;
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp14_ = g_strdup (lang_collection[lang_it]);
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			lang = _tmp14_;
#line 8129 "unattended-installer.c"
			{
				GHashTable* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
#line 890 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp15_ = media_langs;
#line 890 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp16_ = lang;
#line 890 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = g_hash_table_contains (_tmp15_, _tmp16_);
#line 890 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp17_) {
#line 8142 "unattended-installer.c"
					const gchar* _tmp18_ = NULL;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp18_ = lang;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:891: matched %s", _tmp18_);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					result = lang;
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (media_langs_list);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_hash_table_unref0 (media_langs);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return result;
#line 8158 "unattended-installer.c"
				}
#line 889 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (lang);
#line 8162 "unattended-installer.c"
			}
		}
	}
#line 896 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = media_langs_list;
#line 896 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp19_ != NULL) {
#line 8170 "unattended-installer.c"
		GList* _tmp20_ = NULL;
		gconstpointer _tmp21_ = NULL;
		GList* _tmp22_ = NULL;
		gconstpointer _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = media_langs_list;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp21_ = g_list_nth_data (_tmp20_, (guint) 0);
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:897: Failed to match system locales with med" \
"ia languages, falling back to %s media language", (const gchar*) _tmp21_);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp22_ = media_langs_list;
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = g_list_nth_data (_tmp22_, (guint) 0);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = g_strdup ((const gchar*) _tmp23_);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = _tmp24_;
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (media_langs_list);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_hash_table_unref0 (media_langs);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 899 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 8198 "unattended-installer.c"
	}
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp25_ = system_langs;
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp25__length1 = system_langs_length1;
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp26_ = _tmp25_[0];
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp27_ = string_replace (_tmp26_, ".utf8", "");
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	lang = _tmp27_;
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp28_ = lang;
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp29_ = string_replace (_tmp28_, ".UTF-8", "");
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (lang);
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	lang = _tmp29_;
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp30_ = lang;
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:904: No media language, using %s locale", _tmp30_);
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = lang;
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_list_free0 (media_langs_list);
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_hash_table_unref0 (media_langs);
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8232 "unattended-installer.c"
}


static void boxes_unattended_installer_remove_disk_from_domain_config (BoxesUnattendedInstaller* self, GVirConfigDomain* domain, const gchar* disk_path) {
	GList* devices = NULL;
	GVirConfigDomain* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GVirConfigDomain* _tmp11_ = NULL;
	GList* _tmp12_ = NULL;
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (disk_path != NULL);
#line 910 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = domain;
#line 910 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gvir_config_domain_get_devices (_tmp0_);
#line 910 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	devices = _tmp1_;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = devices;
#line 8257 "unattended-installer.c"
	{
		GList* device_collection = NULL;
		GList* device_it = NULL;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		device_collection = _tmp2_;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 8265 "unattended-installer.c"
			GVirConfigDomainDevice* _tmp3_ = NULL;
			GVirConfigDomainDevice* device = NULL;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			device = _tmp3_;
#line 8272 "unattended-installer.c"
			{
				GVirConfigDomainDevice* _tmp4_ = NULL;
				GVirConfigDomainDisk* disk = NULL;
				GVirConfigDomainDevice* _tmp5_ = NULL;
				GVirConfigDomainDisk* _tmp6_ = NULL;
				GVirConfigDomainDisk* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = device;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gvir_config_domain_disk_get_type ())) {
#line 913 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (device);
#line 913 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					continue;
#line 8289 "unattended-installer.c"
				}
#line 915 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = device;
#line 915 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp5_) : NULL);
#line 915 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				disk = _tmp6_;
#line 916 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = disk;
#line 916 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8_ = gvir_config_domain_disk_get_source (_tmp7_);
#line 916 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp9_ = disk_path;
#line 916 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 8305 "unattended-installer.c"
					GVirConfigDomainDevice* _tmp10_ = NULL;
#line 917 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp10_ = device;
#line 917 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					devices = g_list_remove (devices, _tmp10_);
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (disk);
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (device);
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					break;
#line 8317 "unattended-installer.c"
				}
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (disk);
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (device);
#line 8323 "unattended-installer.c"
			}
		}
	}
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = domain;
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = devices;
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_set_devices (_tmp11_, _tmp12_);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (devices);
#line 8335 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_construct (GType object_type) {
	BoxesUnattendedInstaller * self = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) boxes_installer_media_construct (object_type);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self;
#line 8345 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_new (void) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return boxes_unattended_installer_construct (BOXES_TYPE_UNATTENDED_INSTALLER);
#line 8352 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_get_need_user_input_for_vm_creation (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesUnattendedInstaller* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_installer_media_get_live ((BoxesInstallerMedia*) self);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = !_tmp1_;
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8371 "unattended-installer.c"
}


gboolean boxes_unattended_installer_get_ready_for_express (BoxesUnattendedInstaller* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gboolean _tmp12_ = FALSE;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_username (self);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_strcmp0 (_tmp2_, "") != 0) {
#line 8389 "unattended-installer.c"
		gboolean _tmp3_ = FALSE;
		const gchar* _tmp4_ = NULL;
		gboolean _tmp11_ = FALSE;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = self->priv->product_key_format;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp4_ == NULL) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = TRUE;
#line 8399 "unattended-installer.c"
		} else {
			GtkEntry* _tmp5_ = NULL;
			guint _tmp6_ = 0U;
			guint _tmp7_ = 0U;
			const gchar* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gint _tmp10_ = 0;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp5_ = self->priv->key_entry;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp6_ = gtk_entry_get_text_length (_tmp5_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp7_ = _tmp6_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp8_ = self->priv->product_key_format;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp9_ = strlen (_tmp8_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp10_ = _tmp9_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = _tmp7_ == ((guint) _tmp10_);
#line 8421 "unattended-installer.c"
		}
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = _tmp3_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp11_;
#line 8427 "unattended-installer.c"
	} else {
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = FALSE;
#line 8431 "unattended-installer.c"
	}
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = _tmp0_;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp12_;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8439 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_get_ready_to_create (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesUnattendedInstaller* self;
	gboolean _tmp0_ = FALSE;
	GtkSwitch* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->priv->express_toggle;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = gtk_switch_get_active (_tmp1_);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp3_) {
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = TRUE;
#line 8463 "unattended-installer.c"
	} else {
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = boxes_unattended_installer_get_ready_for_express (self);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = _tmp4_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp5_;
#line 8473 "unattended-installer.c"
	}
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = _tmp0_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp6_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8481 "unattended-installer.c"
}


static OsinfoDeviceList* boxes_unattended_installer_real_get_supported_devices (BoxesInstallerMedia* base) {
	OsinfoDeviceList* result;
	BoxesUnattendedInstaller* self;
	OsinfoDeviceList* devices = NULL;
	OsinfoDeviceList* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->get_supported_devices (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	devices = _tmp0_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_express_install (self);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp2_) {
#line 8504 "unattended-installer.c"
		OsinfoDeviceList* _tmp3_ = NULL;
		OsinfoDeviceList* _tmp4_ = NULL;
		OsinfoList* _tmp5_ = NULL;
		OsinfoDeviceList* _tmp6_ = NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = devices;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = self->priv->additional_devices;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = osinfo_list_new_union (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp3_) : NULL, (OsinfoList*) _tmp4_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, osinfo_devicelist_get_type ()) ? ((OsinfoDeviceList*) _tmp5_) : NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp6_ == NULL) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_tmp5_);
#line 8521 "unattended-installer.c"
		}
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = _tmp6_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (devices);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 8529 "unattended-installer.c"
	} else {
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = devices;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 8535 "unattended-installer.c"
	}
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (devices);
#line 8539 "unattended-installer.c"
}


gboolean boxes_unattended_installer_get_express_install (BoxesUnattendedInstaller* self) {
	gboolean result;
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->express_toggle;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp2_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8560 "unattended-installer.c"
}


const gchar* boxes_unattended_installer_get_username (BoxesUnattendedInstaller* self) {
	const gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->username_entry;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp2_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8581 "unattended-installer.c"
}


gchar* boxes_unattended_installer_get_password (BoxesUnattendedInstaller* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->password_entry;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp3_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 8605 "unattended-installer.c"
}


static gchar* g_unichar_to_string (gunichar self) {
	gchar* result = NULL;
	gchar* str = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 855 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 7);
#line 855 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	str = (gchar*) _tmp0_;
#line 856 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp1_ = str;
#line 856 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_unichar_to_utf8 (self, _tmp1_);
#line 857 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	result = str;
#line 857 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	return result;
#line 8626 "unattended-installer.c"
}


gchar* boxes_unattended_installer_get_hidden_password (BoxesUnattendedInstaller* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->password_entry;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = strlen (_tmp2_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _tmp3_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp4_ > 0) {
#line 8651 "unattended-installer.c"
		gchar* str = NULL;
		gchar* _tmp5_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = g_strdup ("");
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		str = _tmp5_;
#line 8658 "unattended-installer.c"
		{
			gint i = 0;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			i = 0;
#line 8663 "unattended-installer.c"
			{
				gboolean _tmp6_ = FALSE;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = TRUE;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				while (TRUE) {
#line 8670 "unattended-installer.c"
					gboolean _tmp7_ = FALSE;
					gint _tmp9_ = 0;
					GtkEntry* _tmp10_ = NULL;
					guint _tmp11_ = 0U;
					guint _tmp12_ = 0U;
					const gchar* _tmp13_ = NULL;
					GtkEntry* _tmp14_ = NULL;
					gunichar _tmp15_ = 0U;
					gchar* _tmp16_ = NULL;
					gchar* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp7_ = _tmp6_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (!_tmp7_) {
#line 8686 "unattended-installer.c"
						gint _tmp8_ = 0;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp8_ = i;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						i = _tmp8_ + 1;
#line 8692 "unattended-installer.c"
					}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = FALSE;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = i;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp10_ = self->priv->password_entry;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp11_ = gtk_entry_get_text_length (_tmp10_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp12_ = _tmp11_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (!(((guint) _tmp9_) < _tmp12_)) {
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 8708 "unattended-installer.c"
					}
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp13_ = str;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp14_ = self->priv->password_entry;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp15_ = gtk_entry_get_invisible_char (_tmp14_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp16_ = g_unichar_to_string (_tmp15_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp17_ = _tmp16_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp18_ = g_strconcat (_tmp13_, _tmp17_, NULL);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (str);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					str = _tmp18_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_tmp17_);
#line 8728 "unattended-installer.c"
				}
			}
		}
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = str;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 8736 "unattended-installer.c"
	} else {
		const gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = _ ("no password");
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = g_strdup (_tmp19_);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = _tmp20_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 8748 "unattended-installer.c"
	}
}


static GObject * boxes_unattended_installer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesUnattendedInstaller * self;
	BoxesFdoAccounts* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	parent_class = G_OBJECT_CLASS (boxes_unattended_installer_parent_class);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_accounts;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp0_ == NULL) {
#line 8769 "unattended-installer.c"
		{
			BoxesFdoAccounts* _tmp1_ = NULL;
			BoxesFdoAccounts* _tmp2_ = NULL;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = g_initable_new (BOXES_FDO_TYPE_ACCOUNTS_PROXY, NULL, &_inner_error_, "g-flags", 0, "g-name", "org.freedesktop.Accounts", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", "/org/freedesktop/Accounts", "g-interface-name", "org.freedesktop.Accounts", NULL);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp1_ = (BoxesFdoAccounts*) _tmp2_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_inner_error_ != NULL) {
#line 8779 "unattended-installer.c"
				goto __catch79_g_error;
			}
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (boxes_unattended_installer_accounts);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_accounts = _tmp1_;
#line 8786 "unattended-installer.c"
		}
		goto __finally79;
		__catch79_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp3_ = NULL;
			const gchar* _tmp4_ = NULL;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_error_ = _inner_error_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_inner_error_ = NULL;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = _error_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp4_ = _tmp3_->message;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_warning ("unattended-installer.vala:112: Failed to connect to D-Bus service '%s'" \
": %s", "org.freedesktop.Accounts", _tmp4_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_error_free0 (_error_);
#line 8806 "unattended-installer.c"
		}
		__finally79:
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_inner_error_ != NULL) {
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_inner_error_);
#line 8815 "unattended-installer.c"
		}
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return obj;
#line 8820 "unattended-installer.c"
}


static void boxes_unattended_installer_class_init (BoxesUnattendedInstallerClass * klass) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_parent_class = g_type_class_peek_parent (klass);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedInstallerPrivate));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_to_continue_installation = boxes_unattended_installer_real_prepare_to_continue_installation;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_for_installation = boxes_unattended_installer_real_prepare_for_installation;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_for_installation_finish = boxes_unattended_installer_real_prepare_for_installation_finish;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->setup_domain_config = boxes_unattended_installer_real_setup_domain_config;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->setup_post_install_domain_config = boxes_unattended_installer_real_setup_post_install_domain_config;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->populate_setup_vbox = boxes_unattended_installer_real_populate_setup_vbox;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_vm_properties = boxes_unattended_installer_real_get_vm_properties;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->set_direct_boot_params = boxes_unattended_installer_real_set_direct_boot_params;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->clean_up = boxes_unattended_installer_real_clean_up;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->clean_up_preparation_cache = boxes_unattended_installer_real_clean_up_preparation_cache;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare = boxes_unattended_installer_real_prepare;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->prepare_finish = boxes_unattended_installer_real_prepare_finish;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_need_user_input_for_vm_creation = boxes_unattended_installer_real_get_need_user_input_for_vm_creation;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_ready_to_create = boxes_unattended_installer_real_get_ready_to_create;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_supported_devices = boxes_unattended_installer_real_get_supported_devices;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_installer_get_property;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_unattended_installer_constructor;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_installer_finalize;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION, g_param_spec_boolean ("need-user-input-for-vm-creation", "need-user-input-for-vm-creation", "need-user-input-for-vm-creation", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_READY_FOR_EXPRESS, g_param_spec_boolean ("ready-for-express", "ready-for-express", "ready-for-express", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE, g_param_spec_boolean ("ready-to-create", "ready-to-create", "ready-to-create", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES, g_param_spec_object ("supported-devices", "supported-devices", "supported-devices", osinfo_devicelist_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_EXPRESS_INSTALL, g_param_spec_boolean ("express-install", "express-install", "express-install", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_USERNAME, g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_PASSWORD, g_param_spec_string ("password", "password", "password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_HIDDEN_PASSWORD, g_param_spec_string ("hidden-password", "hidden-password", "hidden-password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 8881 "unattended-installer.c"
}


static void boxes_unattended_installer_instance_init (BoxesUnattendedInstaller * self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv = BOXES_UNATTENDED_INSTALLER_GET_PRIVATE (self);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->driver_signing = TRUE;
#line 8890 "unattended-installer.c"
}


static void boxes_unattended_installer_finalize (GObject* obj) {
	BoxesUnattendedInstaller * self;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->disk_file);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->secondary_disk_file);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->kernel_file);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->initrd_file);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->config);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->scripts);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->product_key_format);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->avatar_file);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_grid);
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_label);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->setup_hbox);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->express_toggle);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->timezone);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->lang);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->hostname);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->kbd);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->additional_devices);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (boxes_unattended_installer_parent_class)->finalize (obj);
#line 8944 "unattended-installer.c"
}


GType boxes_unattended_installer_get_type (void) {
	static volatile gsize boxes_unattended_installer_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_installer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedInstallerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_installer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedInstaller), 0, (GInstanceInitFunc) boxes_unattended_installer_instance_init, NULL };
		GType boxes_unattended_installer_type_id;
		boxes_unattended_installer_type_id = g_type_register_static (BOXES_TYPE_INSTALLER_MEDIA, "BoxesUnattendedInstaller", &g_define_type_info, 0);
		g_once_init_leave (&boxes_unattended_installer_type_id__volatile, boxes_unattended_installer_type_id);
	}
	return boxes_unattended_installer_type_id__volatile;
}


static void _vala_boxes_unattended_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedInstaller * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (property_id) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_installer_media_get_need_user_input_for_vm_creation ((BoxesInstallerMedia*) self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_READY_FOR_EXPRESS:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_unattended_installer_get_ready_for_express (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_installer_media_get_ready_to_create ((BoxesInstallerMedia*) self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_take_object (value, boxes_installer_media_get_supported_devices ((BoxesInstallerMedia*) self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_EXPRESS_INSTALL:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_unattended_installer_get_express_install (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_USERNAME:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_string (value, boxes_unattended_installer_get_username (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_PASSWORD:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_take_string (value, boxes_unattended_installer_get_password (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_HIDDEN_PASSWORD:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_take_string (value, boxes_unattended_installer_get_hidden_password (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 9013 "unattended-installer.c"
		default:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 9019 "unattended-installer.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 9027 "unattended-installer.c"
		int i;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 9035 "unattended-installer.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 9047 "unattended-installer.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 9060 "unattended-installer.c"
		}
	}
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 9065 "unattended-installer.c"
}



