/* app.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <glib/gstdio.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <libgd/gd.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesBrokerAddSourceData BoxesBrokerAddSourceData;

#define BOXES_TYPE_APP_PAGE (boxes_app_page_get_type ())

#define BOXES_TYPE_APPLICATION (boxes_application_get_type ())
#define BOXES_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APPLICATION, BoxesApplication))
#define BOXES_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APPLICATION, BoxesApplicationClass))
#define BOXES_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APPLICATION))
#define BOXES_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APPLICATION))
#define BOXES_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APPLICATION, BoxesApplicationClass))

typedef struct _BoxesApplication BoxesApplication;
typedef struct _BoxesApplicationClass BoxesApplicationClass;
typedef struct _BoxesApplicationPrivate BoxesApplicationPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;

#define BOXES_TYPE_OVIRT_BROKER (boxes_ovirt_broker_get_type ())
#define BOXES_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBroker))
#define BOXES_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))
#define BOXES_IS_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_IS_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_OVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))

typedef struct _BoxesOvirtBroker BoxesOvirtBroker;
typedef struct _BoxesOvirtBrokerClass BoxesOvirtBrokerClass;
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
typedef struct _BoxesAppAddCollectionSourceData BoxesAppAddCollectionSourceData;
typedef struct _Block5Data Block5Data;
typedef struct _BoxesAppSetupSourcesData BoxesAppSetupSourcesData;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
typedef struct _BoxesRevealerPrivate BoxesRevealerPrivate;
typedef struct _Block6Data Block6Data;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;
typedef struct _Block7Data Block7Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block8Data Block8Data;
#define _g_main_context_unref0(var) ((var == NULL) ? NULL : (var = (g_main_context_unref (var), NULL)))
typedef struct _Block9Data Block9Data;
typedef struct _Block10Data Block10Data;

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesBroker* self;
	BoxesCollectionSource* source;
	GList* used_configs;
	BoxesApp* _tmp0_;
	BoxesCollection* _tmp1_;
	GPtrArray* _tmp2_;
	gpointer* _tmp3_;
	gint _tmp3__length1;
	BoxesCollectionItem** item_collection;
	gint item_collection_length1;
	gint _item_collection_size_;
	gint item_it;
	BoxesCollectionItem* _tmp4_;
	BoxesCollectionItem* item;
	BoxesCollectionItem* _tmp5_;
	BoxesCollectionItem* _tmp6_;
	BoxesBoxConfig* _tmp7_;
	BoxesBoxConfig* _tmp8_;
	BoxesCollectionSource* _tmp9_;
	GList* _tmp10_;
};

typedef enum  {
	BOXES_APP_PAGE_MAIN,
	BOXES_APP_PAGE_DISPLAY
} BoxesAppPage;

struct _BoxesApplication {
	GtkApplication parent_instance;
	BoxesApplicationPrivate * priv;
};

struct _BoxesApplicationClass {
	GtkApplicationClass parent_class;
};

struct _BoxesAppPrivate {
	gchar* _uri;
	gboolean is_ready;
	BoxesApplication* application;
	GHashTable* brokers;
	GHashTable* sources;
	guint configure_id;
	GBinding* status_bind;
	gulong got_error_id;
	gboolean ui_is_setup;
	gboolean _selection_mode;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef void (*BoxesAppCallReadyFunc) (void* user_data);
struct _Block1Data {
	int _ref_count_;
	BoxesApp * self;
	BoxesAppCallReadyFunc func;
	gpointer func_target;
	GDestroyNotify func_target_destroy_notify;
};

struct _Block2Data {
	int _ref_count_;
	BoxesApp * self;
	BoxesApp* app;
};

struct _Block3Data {
	int _ref_count_;
	Block2Data * _data2_;
	gchar* uuid;
};

struct _Block4Data {
	int _ref_count_;
	Block2Data * _data2_;
	gchar* arg;
};

struct _BoxesAppAddCollectionSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GHashTable* _tmp3_;
	BoxesCollectionSource* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gconstpointer _tmp8_;
	gboolean _tmp9_;
	BoxesCollectionSource* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	BoxesCollectionSource* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GQuark _tmp19_;
	BoxesRemoteMachine* machine;
	BoxesCollectionSource* _tmp20_;
	BoxesRemoteMachine* _tmp21_;
	BoxesCollection* _tmp22_;
	BoxesRemoteMachine* _tmp23_;
	GError* _error_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	BoxesBroker* broker;
	GHashTable* _tmp26_;
	BoxesCollectionSource* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gconstpointer _tmp31_;
	BoxesBroker* _tmp32_;
	BoxesBroker* _tmp33_;
	BoxesBroker* _tmp34_;
	BoxesBroker* _tmp35_;
	BoxesCollectionSource* _tmp36_;
	GHashTable* _tmp37_;
	BoxesCollectionSource* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	BoxesCollectionSource* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	BoxesCollectionSource* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gboolean _tmp47_;
	BoxesCollectionSource* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GError * _inner_error_;
};

struct _Block5Data {
	int _ref_count_;
	BoxesApp * self;
	GList* new_sources;
	gpointer _async_data_;
};

struct _BoxesAppSetupSourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	Block5Data* _data5_;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GFile* src;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	GFile* dst;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GFile* _tmp10_;
	GFile* _tmp11_;
	GFile* _tmp12_;
	GFile* _tmp13_;
	GError* _error_;
	GError* _tmp14_;
	const gchar* _tmp15_;
	GFile* dir;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GFile* _tmp18_;
	GFile* _tmp19_;
	GFile* _tmp20_;
	GList* _tmp21_;
	GList* source_collection;
	GList* source_it;
	BoxesCollectionSource* _tmp22_;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp23_;
	GVirConnection* _tmp24_;
	GVirConnection* _tmp25_;
	GVirConnection* _tmp26_;
	gboolean _tmp27_;
	BoxesApplication* _tmp28_;
	GError * _inner_error_;
};

struct _BoxesRevealer {
	ClutterActor parent_instance;
	BoxesRevealerPrivate * priv;
	guint duration;
	gboolean resize;
};

struct _BoxesRevealerClass {
	ClutterActorClass parent_class;
};

struct _Block6Data {
	int _ref_count_;
	BoxesApp * self;
	ClutterActor* actor;
	gulong id;
};

struct _BoxesCollectionView {
	BoxesUI parent_instance;
	BoxesCollectionViewPrivate * priv;
	GdMainView* main_view;
};

struct _BoxesCollectionViewClass {
	BoxesUIClass parent_class;
};

struct _Block7Data {
	int _ref_count_;
	BoxesApp * self;
	gint waiting_counter;
};

struct _Block8Data {
	int _ref_count_;
	Block7Data * _data7_;
	BoxesLibvirtMachine* machine;
};

struct _Block9Data {
	int _ref_count_;
	BoxesApp * self;
	GList* selected_items;
};

typedef void (*BoxesNotificationbarOKFunc) (void* user_data);
typedef void (*BoxesNotificationbarCancelFunc) (void* user_data);
struct _Block10Data {
	int _ref_count_;
	BoxesApp * self;
	BoxesMachine* machine;
	gfloat x;
	gfloat y;
	BoxesMachineConnectFlags flags;
};


static gpointer boxes_broker_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_application_parent_class = NULL;
static gpointer boxes_app_parent_class = NULL;
BoxesApp* boxes_app_app = NULL;
static gboolean boxes_app_opt_fullscreen;
static gboolean boxes_app_opt_fullscreen = FALSE;
static gboolean boxes_app_opt_help;
static gboolean boxes_app_opt_help = FALSE;
static gchar* boxes_app_opt_open_uuid;
static gchar* boxes_app_opt_open_uuid = NULL;
static gchar** boxes_app_opt_uris;
static gint boxes_app_opt_uris_length1;
static gchar** boxes_app_opt_uris = NULL;
static gint boxes_app_opt_uris_length1 = 0;
static gint _boxes_app_opt_uris_size_ = 0;
static gchar** boxes_app_opt_search;
static gint boxes_app_opt_search_length1;
static gchar** boxes_app_opt_search = NULL;
static gint boxes_app_opt_search_length1 = 0;
static gint _boxes_app_opt_search_size_ = 0;

GType boxes_broker_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_BROKER_DUMMY_PROPERTY
};
static void boxes_broker_real_add_source_data_free (gpointer _data);
static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesBroker* boxes_broker_construct (GType object_type);
GType boxes_app_page_get_type (void) G_GNUC_CONST;
GType boxes_application_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_APPLICATION_DUMMY_PROPERTY
};
BoxesApplication* boxes_application_new (void);
BoxesApplication* boxes_application_construct (GType object_type);
static void boxes_application_real_startup (GApplication* base);
void boxes_app_startup (BoxesApp* self);
static void boxes_application_real_activate (GApplication* base);
void boxes_app_activate (BoxesApp* self);
static gint boxes_application_real_command_line (GApplication* base, GApplicationCommandLine* cmdline);
gint boxes_app_command_line (BoxesApp* self, GApplicationCommandLine* cmdline);
#define BOXES_APP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_APP, BoxesAppPrivate))
enum  {
	BOXES_APP_DUMMY_PROPERTY,
	BOXES_APP_ACTOR,
	BOXES_APP_FULLSCREEN,
	BOXES_APP_URI,
	BOXES_APP_DEFAULT_CONNECTION,
	BOXES_APP_DEFAULT_SOURCE,
	BOXES_APP_SELECTION_MODE,
	BOXES_APP_SELECTED_ITEMS
};
#define BOXES_APP_configure_id_timeout ((guint) 100)
BoxesApp* boxes_app_new (void);
BoxesApp* boxes_app_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void _g_free0_ (gpointer var);
BoxesCollectionFilter* boxes_collection_filter_new (void);
BoxesCollectionFilter* boxes_collection_filter_construct (GType object_type);
static void __lambda219_ (BoxesApp* self);
gboolean boxes_app_quit (BoxesApp* self);
static void ___lambda219__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda220_ (BoxesApp* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda220__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda221_ (BoxesApp* self);
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static void ___lambda221__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda222_ (BoxesApp* self);
static void ___lambda222__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda223_ (BoxesApp* self);
static void ___lambda223__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda224_ (BoxesApp* self);
static void ___lambda224__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda225_ (BoxesApp* self);
static void ___lambda225__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
BoxesCollection* boxes_collection_new (void);
BoxesCollection* boxes_collection_construct (GType object_type);
static void __lambda205_ (BoxesApp* self, BoxesCollectionItem* item);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void ___lambda205__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void __lambda206_ (BoxesApp* self, BoxesCollectionItem* item);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void ___lambda206__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
GType boxes_ovirt_broker_get_type (void) G_GNUC_CONST;
BoxesOvirtBroker* boxes_ovirt_broker_get_default (void);
static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_);
static void __lambda211_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_);
static void ___lambda211__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda203_ (Block1Data* _data1_);
static void ___lambda203__boxes_app_ready (BoxesApp* _sender, gpointer self);
static void boxes_app_setup_ui (BoxesApp* self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void ___lambda216_ (Block3Data* _data3_);
gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid);
static void ____lambda216__boxes_app_call_ready_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void ____lambda217_ (Block4Data* _data4_);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
void boxes_app_open (BoxesApp* self, const gchar* name);
static void _____lambda217__boxes_app_call_ready_func (gpointer self);
static void ___lambda218_ (BoxesApp* self);
void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value);
void boxes_searchbar_set_visible (BoxesSearchbar* self, gboolean value);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_revealer_set_revealed (BoxesRevealer* self, gboolean value);
static void ____lambda218__boxes_app_call_ready_func (gpointer self);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
gint boxes_app_run (BoxesApp* self, gchar** args, int args_length1);
void boxes_app_shutdown (BoxesApp* self);
void boxes_collection_view_set_visible (BoxesCollectionView* self, gboolean value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
void boxes_collection_remove_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_data_free (gpointer _data);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_app_setup_sources_data_free (gpointer _data);
static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static gboolean __lambda210_ (Block5Data* _data5_, const gchar* filename, GError** error);
static gboolean ___lambda210__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
static void boxes_app_save_window_geometry (BoxesApp* self);
static gboolean boxes_app_get_maximized (BoxesApp* self);
static GVariant* _variant_new1 (gint* value, gint value_length1);
static GVariant* _variant_new2 (gint* value, gint value_length1);
static gint _variant_get3 (GVariant* value);
static gint _variant_get4 (GVariant* value);
static gint _variant_get5 (GVariant* value);
static gint _variant_get6 (GVariant* value);
static gboolean __lambda212_ (BoxesApp* self);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
static gboolean __lambda213_ (BoxesApp* self);
static gboolean ___lambda213__gsource_func (gpointer self);
static gboolean ___lambda212__gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self);
static gboolean __lambda214_ (BoxesApp* self, GdkEventWindowState* event);
static gboolean ___lambda214__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
BoxesClutterWidget* boxes_clutter_widget_new (void);
BoxesClutterWidget* boxes_clutter_widget_construct (GType object_type);
BoxesDisplayPage* boxes_display_page_new (void);
BoxesDisplayPage* boxes_display_page_construct (GType object_type);
GtkWidget* boxes_display_page_get_widget (BoxesDisplayPage* self);
BoxesSelectionbar* boxes_selectionbar_new (void);
BoxesSelectionbar* boxes_selectionbar_construct (GType object_type);
void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result);
void boxes_get_boxes_bg_color (GdkRGBA* result);
static gboolean __lambda215_ (BoxesApp* self);
static gboolean ___lambda215__gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static gboolean boxes_app_on_key_pressed (BoxesApp* self, GtkWidget* widget, GdkEventKey* event);
static gboolean _boxes_app_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
BoxesSidebar* boxes_sidebar_new (void);
BoxesSidebar* boxes_sidebar_construct (GType object_type);
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesSearchbar* boxes_searchbar_new (void);
BoxesSearchbar* boxes_searchbar_construct (GType object_type);
BoxesTopbar* boxes_topbar_new (void);
BoxesTopbar* boxes_topbar_construct (GType object_type);
BoxesNotificationbar* boxes_notificationbar_new (void);
BoxesNotificationbar* boxes_notificationbar_construct (GType object_type);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
BoxesProperties* boxes_properties_new (void);
BoxesProperties* boxes_properties_construct (GType object_type);
BoxesEmptyBoxes* boxes_empty_boxes_new (void);
BoxesEmptyBoxes* boxes_empty_boxes_construct (GType object_type);
GtkWidget* boxes_topbar_get_widget (BoxesTopbar* self);
BoxesRevealer* boxes_revealer_new (gboolean horizontal);
BoxesRevealer* boxes_revealer_construct (GType object_type, gboolean horizontal);
void boxes_revealer_unreveal (BoxesRevealer* self);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
ClutterActor* boxes_notificationbar_get_actor (BoxesNotificationbar* self);
static void boxes_app_set_main_ui_state (BoxesApp* self);
static void boxes_app_position_item_actor_at_icon (BoxesApp* self, BoxesCollectionItem* item);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
void boxes_collection_view_get_item_pos (BoxesCollectionView* self, BoxesCollectionItem* item, gfloat* x, gfloat* y);
ClutterTransition* boxes_animate_actor_geometry (gfloat x, gfloat y, gfloat width, gfloat height);
#define BOXES_MACHINE_SCREENSHOT_WIDTH 180
#define BOXES_MACHINE_SCREENSHOT_HEIGHT 134
static void __lambda226_ (BoxesApp* self, GtkAllocation* allocation);
static gboolean __lambda227_ (BoxesApp* self);
static gboolean ___lambda227__gsource_func (gpointer self);
static void ___lambda226__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static void __lambda228_ (Block6Data* _data6_);
void boxes_actor_remove (ClutterActor* actor);
static void ___lambda228__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self);
static void boxes_app_real_ui_state_changed (BoxesUI* base);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
gboolean boxes_searchbar_get_visible (BoxesSearchbar* self);
const gchar* boxes_ui_state_to_string (BoxesUIState self);
void boxes_app_suspend_machines (BoxesApp* self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ______lambda229_ (Block8Data* _data8_);
static void _______lambda229__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_notificationbar_cancel (BoxesNotificationbar* self);
void boxes_wizard_cleanup (BoxesWizard* self);
void boxes_app_show_properties (BoxesApp* self);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
void boxes_app_remove_selected_items (BoxesApp* self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda175_ (Block9Data* _data9_);
static void ___lambda175__boxes_notificationbar_ok_func (gpointer self);
static void __lambda176_ (Block9Data* _data9_);
static void ___lambda176__boxes_notificationbar_cancel_func (gpointer self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationbarOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationbarCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
gboolean boxes_app_get_selection_mode (BoxesApp* self);
void boxes_app_connect_to (BoxesApp* self, BoxesMachine* machine, gfloat x, gfloat y, BoxesMachineConnectFlags flags);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height);
static void __lambda85_ (BoxesApp* self, const gchar* message);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
static void ___lambda85__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self);
void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void __lambda86_ (Block10Data* _data10_, GObject* obj, GAsyncResult* res);
static void ____lambda87_ (Block10Data* _data10_);
static void _____lambda87__boxes_notificationbar_ok_func (gpointer self);
static void ___lambda86__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
const gchar* boxes_app_get_uri (BoxesApp* self);
void boxes_app_set_uri (BoxesApp* self, const gchar* value);
GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void boxes_app_finalize (GObject* obj);
static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GOptionEntry BOXES_APP_options[8] = {{"version", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Display version number", NULL}, {"help", 'h', (gint) G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &boxes_app_opt_help, NULL, NULL}, {"full-screen", 'f', 0, G_OPTION_ARG_NONE, &boxes_app_opt_fullscreen, "Open in full screen", NULL}, {"checks", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Check virtualization capabilities", NULL}, {"open-uuid", (gchar) 0, 0, G_OPTION_ARG_STRING, &boxes_app_opt_open_uuid, "Open box with UUID", NULL}, {"search", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_search, "Search term", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_uris, "URI to display, broker or installer media", NULL}, {NULL}};

static void boxes_broker_real_add_source_data_free (gpointer _data) {
	BoxesBrokerAddSourceData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesBrokerAddSourceData, _data_);
#line 1029 "app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return self ? g_object_ref (self) : NULL;
#line 1036 "app.c"
}


static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesBrokerAddSourceData* _data_;
	BoxesBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesBrokerAddSourceData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_broker_real_add_source);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_broker_real_add_source_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_real_add_source_co (_data_);
#line 1065 "app.c"
}


static void boxes_broker_real_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
	BoxesBrokerAddSourceData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1073 "app.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1080 "app.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_free (self);
#line 1089 "app.c"
}


static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_) {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 1098 "app.c"
		goto _state_0;
		default:
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 1103 "app.c"
	}
	_state_0:
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->used_configs = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_app_app;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = _data_->_tmp0_->collection;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_->items;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = 0;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->_tmp2_->pdata;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = (gint) _data_->_tmp2_->len;
#line 1128 "app.c"
	{
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = 0;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_item_collection_size_ = 0;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection = _data_->_tmp3_;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = _data_->_tmp3__length1;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->item_it = 0; _data_->item_it < _data_->_tmp3__length1; _data_->item_it = _data_->item_it + 1) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = NULL;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = _g_object_ref0 (_data_->item_collection[_data_->item_it]);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->item = _data_->_tmp4_;
#line 1146 "app.c"
			{
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = NULL;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = _data_->item;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp5_, BOXES_TYPE_MACHINE)) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->item);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 1158 "app.c"
				}
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = NULL;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = _data_->item;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = NULL;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _data_->_tmp6_) : NULL)->config;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = NULL;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->used_configs = g_list_append (_data_->used_configs, _data_->_tmp8_);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->item);
#line 1176 "app.c"
			}
		}
	}
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = NULL;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = _data_->source;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = NULL;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = _data_->used_configs;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_source_purge_stale_box_configs (_data_->_tmp9_, _data_->_tmp10_);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (_data_->used_configs);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1196 "app.c"
	} else {
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1200 "app.c"
	}
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 1206 "app.c"
}


void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source (self, source, _callback_, _user_data_);
#line 1213 "app.c"
}


void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source_finish (self, _res_);
#line 1220 "app.c"
}


BoxesBroker* boxes_broker_construct (GType object_type) {
	BoxesBroker * self = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesBroker*) g_object_new (object_type, NULL);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1230 "app.c"
}


static void boxes_broker_class_init (BoxesBrokerClass * klass) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_parent_class = g_type_class_peek_parent (klass);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_CLASS (klass)->add_source = boxes_broker_real_add_source;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_CLASS (klass)->add_source_finish = boxes_broker_real_add_source_finish;
#line 1241 "app.c"
}


static void boxes_broker_instance_init (BoxesBroker * self) {
}


GType boxes_broker_get_type (void) {
	static volatile gsize boxes_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesBroker), 0, (GInstanceInitFunc) boxes_broker_instance_init, NULL };
		GType boxes_broker_type_id;
		boxes_broker_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesBroker", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&boxes_broker_type_id__volatile, boxes_broker_type_id);
	}
	return boxes_broker_type_id__volatile;
}


GType boxes_app_page_get_type (void) {
	static volatile gsize boxes_app_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_APP_PAGE_MAIN, "BOXES_APP_PAGE_MAIN", "main"}, {BOXES_APP_PAGE_DISPLAY, "BOXES_APP_PAGE_DISPLAY", "display"}, {0, NULL, NULL}};
		GType boxes_app_page_type_id;
		boxes_app_page_type_id = g_enum_register_static ("BoxesAppPage", values);
		g_once_init_leave (&boxes_app_page_type_id__volatile, boxes_app_page_type_id);
	}
	return boxes_app_page_type_id__volatile;
}


BoxesApplication* boxes_application_construct (GType object_type) {
	BoxesApplication * self = NULL;
	GApplicationFlags _tmp0_ = 0;
	GApplicationFlags _tmp1_ = 0;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApplication*) g_object_new (object_type, NULL);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_application_id ((GApplication*) self, "org.gnome.Boxes");
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_application_get_flags ((GApplication*) self);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_flags ((GApplication*) self, _tmp1_ | G_APPLICATION_HANDLES_COMMAND_LINE);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1289 "app.c"
}


BoxesApplication* boxes_application_new (void) {
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return boxes_application_construct (BOXES_TYPE_APPLICATION);
#line 1296 "app.c"
}


static void boxes_application_real_startup (GApplication* base) {
	BoxesApplication * self;
	BoxesApp* _tmp0_ = NULL;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApplication*) base;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_application_parent_class)->startup ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_APPLICATION, GtkApplication));
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_app;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_startup (_tmp0_);
#line 1311 "app.c"
}


static void boxes_application_real_activate (GApplication* base) {
	BoxesApplication * self;
	BoxesApp* _tmp0_ = NULL;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApplication*) base;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_application_parent_class)->activate ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_APPLICATION, GtkApplication));
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_app;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_activate (_tmp0_);
#line 1326 "app.c"
}


static gint boxes_application_real_command_line (GApplication* base, GApplicationCommandLine* cmdline) {
	BoxesApplication * self;
	gint result = 0;
	BoxesApp* _tmp0_ = NULL;
	GApplicationCommandLine* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApplication*) base;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (cmdline != NULL, 0);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_app;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = cmdline;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_command_line (_tmp0_, _tmp1_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 1350 "app.c"
}


static void boxes_application_class_init (BoxesApplicationClass * klass) {
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_application_parent_class = g_type_class_peek_parent (klass);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->startup = boxes_application_real_startup;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->activate = boxes_application_real_activate;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->command_line = boxes_application_real_command_line;
#line 1363 "app.c"
}


static void boxes_application_instance_init (BoxesApplication * self) {
}


GType boxes_application_get_type (void) {
	static volatile gsize boxes_application_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_application_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesApplicationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_application_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesApplication), 0, (GInstanceInitFunc) boxes_application_instance_init, NULL };
		GType boxes_application_type_id;
		boxes_application_type_id = g_type_register_static (GTK_TYPE_APPLICATION, "BoxesApplication", &g_define_type_info, 0);
		g_once_init_leave (&boxes_application_type_id__volatile, boxes_application_type_id);
	}
	return boxes_application_type_id__volatile;
}


static void _g_free0_ (gpointer var) {
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	var = (g_free (var), NULL);
#line 1386 "app.c"
}


static void __lambda219_ (BoxesApp* self) {
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_quit (self);
#line 1393 "app.c"
}


static void ___lambda219__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda219_ (self);
#line 1400 "app.c"
}


static void __lambda220_ (BoxesApp* self) {
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_WIZARD);
#line 1407 "app.c"
}


static void ___lambda220__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda220_ (self);
#line 1414 "app.c"
}


static void __lambda221_ (BoxesApp* self) {
	BoxesCollectionView* _tmp0_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp0_, BOXES_SELECTION_CRITERIA_ALL);
#line 1424 "app.c"
}


static void ___lambda221__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda221_ (self);
#line 1431 "app.c"
}


static void __lambda222_ (BoxesApp* self) {
	BoxesCollectionView* _tmp0_ = NULL;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp0_, BOXES_SELECTION_CRITERIA_RUNNING);
#line 1441 "app.c"
}


static void ___lambda222__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda222_ (self);
#line 1448 "app.c"
}


static void __lambda223_ (BoxesApp* self) {
	BoxesCollectionView* _tmp0_ = NULL;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp0_, BOXES_SELECTION_CRITERIA_NONE);
#line 1458 "app.c"
}


static void ___lambda223__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda223_ (self);
#line 1465 "app.c"
}


static void __lambda224_ (BoxesApp* self) {
	GError * _inner_error_ = NULL;
	{
		GtkApplicationWindow* _tmp0_ = NULL;
		GdkScreen* _tmp1_ = NULL;
		guint32 _tmp2_ = 0U;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = self->window;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp1_ = gtk_window_get_screen ((GtkWindow*) _tmp0_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = gtk_get_current_event_time ();
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_show_uri (_tmp1_, "help:gnome-boxes", _tmp2_, &_inner_error_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 1485 "app.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		e = _inner_error_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = e;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_->message;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:139: Failed to display help: %s", _tmp4_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (e);
#line 1507 "app.c"
	}
	__finally0:
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 1518 "app.c"
	}
}


static void ___lambda224__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda224_ (self);
#line 1526 "app.c"
}


static void __lambda225_ (BoxesApp* self) {
	gchar** authors = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint authors_length1 = 0;
	gint _authors_size_ = 0;
	gchar** artists = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gint artists_length1 = 0;
	gint _artists_size_ = 0;
	GtkApplicationWindow* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_strdup ("Alexander Larsson <alexl@redhat.com>");
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup ("Christophe Fergeau <cfergeau@redhat.com>");
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_strdup ("Marc-André Lureau <marcandre.lureau@gmail.com>");
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_strdup ("Zeeshan Ali (Khattak) <zeeshanak@gnome.org>");
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[0] = _tmp0_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[1] = _tmp1_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[2] = _tmp2_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[3] = _tmp3_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	authors = _tmp4_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	authors_length1 = 4;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_authors_size_ = authors_length1;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_strdup ("Jon McCann <jmccann@redhat.com>");
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_strdup ("Jakub Steiner <jsteiner@redhat.com>");
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_new0 (gchar*, 2 + 1);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_[0] = _tmp5_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_[1] = _tmp6_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	artists = _tmp7_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	artists_length1 = 2;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_artists_size_ = artists_length1;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = self->window;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _ ("translator-credits");
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _ ("A simple GNOME 3 application to access remote or virtual systems");
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_show_about_dialog ((GtkWindow*) _tmp8_, "artists", artists, "authors", authors, "translator-credits", _tmp9_, "comments", _tmp10_, "copyright", "Copyright 2011 Red Hat, Inc.", "license-type", GTK_LICENSE_LGPL_2_1, "logo-icon-name", "gnome-boxes", "version", VERSION, "website", "http://live.gnome.org/Boxes", "wrap-license", TRUE, NULL);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	artists = (_vala_array_free (artists, artists_length1, (GDestroyNotify) g_free), NULL);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	authors = (_vala_array_free (authors, authors_length1, (GDestroyNotify) g_free), NULL);
#line 1600 "app.c"
}


static void ___lambda225__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda225_ (self);
#line 1607 "app.c"
}


BoxesApp* boxes_app_construct (GType object_type) {
	BoxesApp * self = NULL;
	BoxesApp* _tmp0_ = NULL;
	BoxesApplication* _tmp1_ = NULL;
	GSettings* _tmp2_ = NULL;
	GHashFunc _tmp3_ = NULL;
	GEqualFunc _tmp4_ = NULL;
	GHashTable* _tmp5_ = NULL;
	GHashFunc _tmp6_ = NULL;
	GEqualFunc _tmp7_ = NULL;
	GHashTable* _tmp8_ = NULL;
	BoxesCollectionFilter* _tmp9_ = NULL;
	GSimpleAction* action = NULL;
	GSimpleAction* _tmp10_ = NULL;
	GSimpleAction* _tmp11_ = NULL;
	BoxesApplication* _tmp12_ = NULL;
	GSimpleAction* _tmp13_ = NULL;
	GSimpleAction* _tmp14_ = NULL;
	GSimpleAction* _tmp15_ = NULL;
	BoxesApplication* _tmp16_ = NULL;
	GSimpleAction* _tmp17_ = NULL;
	GSimpleAction* _tmp18_ = NULL;
	GSimpleAction* _tmp19_ = NULL;
	BoxesApplication* _tmp20_ = NULL;
	GSimpleAction* _tmp21_ = NULL;
	GSimpleAction* _tmp22_ = NULL;
	GSimpleAction* _tmp23_ = NULL;
	BoxesApplication* _tmp24_ = NULL;
	GSimpleAction* _tmp25_ = NULL;
	GSimpleAction* _tmp26_ = NULL;
	GSimpleAction* _tmp27_ = NULL;
	BoxesApplication* _tmp28_ = NULL;
	GSimpleAction* _tmp29_ = NULL;
	GSimpleAction* _tmp30_ = NULL;
	GSimpleAction* _tmp31_ = NULL;
	BoxesApplication* _tmp32_ = NULL;
	GSimpleAction* _tmp33_ = NULL;
	GSimpleAction* _tmp34_ = NULL;
	GSimpleAction* _tmp35_ = NULL;
	BoxesApplication* _tmp36_ = NULL;
	GSimpleAction* _tmp37_ = NULL;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) boxes_ui_construct (object_type);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (boxes_app_app);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_app = _tmp0_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_application_new ();
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->application);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->application = _tmp1_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_settings_new ("org.gnome.boxes");
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->settings);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->settings = _tmp2_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_str_hash;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_str_equal;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_hash_table_new_full (_tmp3_, _tmp4_, _g_free0_, _g_object_unref0_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->sources = _tmp5_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_str_hash;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_str_equal;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_hash_table_new_full (_tmp6_, _tmp7_, _g_free0_, _g_object_unref0_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->brokers = _tmp8_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = boxes_collection_filter_new ();
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->filter);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->filter = _tmp9_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = g_simple_action_new ("quit", NULL);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp10_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = action;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp11_, "activate", (GCallback) ___lambda219__g_simple_action_activate, self, 0);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = self->priv->application;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = action;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp12_, (GAction*) _tmp13_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = g_simple_action_new ("new", NULL);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp14_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = action;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp15_, "activate", (GCallback) ___lambda220__g_simple_action_activate, self, 0);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = self->priv->application;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = action;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp16_, (GAction*) _tmp17_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_simple_action_new ("select-all", NULL);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp18_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = action;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp19_, "activate", (GCallback) ___lambda221__g_simple_action_activate, self, 0);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = self->priv->application;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = action;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp20_, (GAction*) _tmp21_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = g_simple_action_new ("select-running", NULL);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp22_;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = action;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp23_, "activate", (GCallback) ___lambda222__g_simple_action_activate, self, 0);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = self->priv->application;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = action;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp24_, (GAction*) _tmp25_);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = g_simple_action_new ("select-none", NULL);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp26_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = action;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp27_, "activate", (GCallback) ___lambda223__g_simple_action_activate, self, 0);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp28_ = self->priv->application;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp29_ = action;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp28_, (GAction*) _tmp29_);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp30_ = g_simple_action_new ("help", NULL);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp30_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31_ = action;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp31_, "activate", (GCallback) ___lambda224__g_simple_action_activate, self, 0);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp32_ = self->priv->application;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp33_ = action;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp32_, (GAction*) _tmp33_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = g_simple_action_new ("about", NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp34_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp35_ = action;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp35_, "activate", (GCallback) ___lambda225__g_simple_action_activate, self, 0);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp36_ = self->priv->application;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp37_ = action;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) _tmp36_, (GAction*) _tmp37_);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1812 "app.c"
}


BoxesApp* boxes_app_new (void) {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return boxes_app_construct (BOXES_TYPE_APP);
#line 1819 "app.c"
}


static void __lambda205_ (BoxesApp* self, BoxesCollectionItem* item) {
	BoxesCollectionView* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = item;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_add_item (_tmp0_, _tmp1_);
#line 1834 "app.c"
}


static void ___lambda205__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda205_ (self, item);
#line 1841 "app.c"
}


static void __lambda206_ (BoxesApp* self, BoxesCollectionItem* item) {
	BoxesCollectionView* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = item;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_remove_item (_tmp0_, _tmp1_);
#line 1856 "app.c"
}


static void ___lambda206__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda206_ (self, item);
#line 1863 "app.c"
}


static void __lambda211_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (_result_ != NULL);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _result_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_finish (self, _tmp0_);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->is_ready = TRUE;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_emit_by_name (self, "ready");
#line 1879 "app.c"
}


static void ___lambda211__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda211_ (self, source_object, res);
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (self);
#line 1888 "app.c"
}


void boxes_app_startup (BoxesApp* self) {
	gchar** args = NULL;
	gchar** _tmp0_ = NULL;
	gint args_length1 = 0;
	gint _args_size_ = 0;
	gchar** args2 = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gint args2_length1 = 0;
	gint _args2_size_ = 0;
	GMenu* menu = NULL;
	GMenu* _tmp2_ = NULL;
	GMenu* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GMenu* display_section = NULL;
	GMenu* _tmp5_ = NULL;
	GMenu* _tmp6_ = NULL;
	GMenu* _tmp7_ = NULL;
	GMenu* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GMenu* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GMenu* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	BoxesApplication* _tmp14_ = NULL;
	GMenu* _tmp15_ = NULL;
	BoxesCollection* _tmp16_ = NULL;
	GSettings* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	BoxesCollection* _tmp19_ = NULL;
	BoxesCollection* _tmp20_ = NULL;
	GHashTable* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	BoxesLibvirtBroker* _tmp23_ = NULL;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	args = _tmp0_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	args_length1 = 0;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_args_size_ = args_length1;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = args;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__length1 = args_length1;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	args2 = _tmp1_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	args2_length1 = _tmp1__length1;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_args2_size_ = args2_length1;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_clutter_init (&args2_length1, &args2);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_menu_new ();
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	menu = _tmp2_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = menu;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _ ("New");
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp3_, _tmp4_, "app.new");
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_menu_new ();
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	display_section = _tmp5_;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = menu;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = display_section;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append_section (_tmp6_, NULL, (GMenuModel*) _tmp7_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = menu;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _ ("Help");
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp8_, _tmp9_, "app.help");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = menu;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = _ ("About Boxes");
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp10_, _tmp11_, "app.about");
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = menu;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = _ ("Quit");
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp12_, _tmp13_, "app.quit");
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = self->priv->application;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = menu;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_application_set_app_menu ((GtkApplication*) _tmp14_, (GMenuModel*) _tmp15_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = boxes_collection_new ();
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->collection = _tmp16_;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = self->settings;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_settings_get_int (_tmp17_, "animation-duration");
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->duration = (guint) _tmp18_;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = self->collection;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp19_, "item-added", (GCallback) ___lambda205__boxes_collection_item_added, self, 0);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = self->collection;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp20_, "item-removed", (GCallback) ___lambda206__boxes_collection_item_removed, self, 0);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = self->priv->brokers;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = g_strdup ("libvirt");
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = boxes_libvirt_broker_get_default ();
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_hash_table_insert (_tmp21_, _tmp22_, (BoxesBroker*) _tmp23_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (HAVE_OVIRT) {
#line 2022 "app.c"
		GHashTable* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		BoxesOvirtBroker* _tmp26_ = NULL;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp24_ = self->priv->brokers;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp25_ = g_strdup ("ovirt");
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp26_ = boxes_ovirt_broker_get_default ();
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_hash_table_insert (_tmp24_, _tmp25_, (BoxesBroker*) _tmp26_);
#line 2034 "app.c"
	}
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources (self, ___lambda211__gasync_ready_callback, g_object_ref (self));
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_cpu_vt_capability (NULL, NULL);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_module_kvm_loaded (NULL, NULL);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (display_section);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (menu);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 2048 "app.c"
}


gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type) {
	gboolean result = FALSE;
	GHashTable* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (type != NULL, FALSE);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->brokers;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = type;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_hash_table_contains (_tmp0_, _tmp1_);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 2071 "app.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data1_;
#line 2080 "app.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 2089 "app.c"
		BoxesApp * self;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data1_->self;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		(_data1_->func_target_destroy_notify == NULL) ? NULL : (_data1_->func_target_destroy_notify (_data1_->func_target), NULL);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func_target = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func_target_destroy_notify = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block1Data, _data1_);
#line 2105 "app.c"
	}
}


static void __lambda203_ (Block1Data* _data1_) {
	BoxesApp * self;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data1_->self;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data1_->func;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = _data1_->func_target;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ (_tmp0__target);
#line 2122 "app.c"
}


static void ___lambda203__boxes_app_ready (BoxesApp* _sender, gpointer self) {
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda203_ (self);
#line 2129 "app.c"
}


void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify) {
	Block1Data* _data1_;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gboolean _tmp1_ = FALSE;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->_ref_count_ = 1;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->self = g_object_ref (self);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = func;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = func_target;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	(_data1_->func_target_destroy_notify == NULL) ? NULL : (_data1_->func_target_destroy_notify (_data1_->func_target), NULL);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target_destroy_notify = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func = _tmp0_;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target = _tmp0__target;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target_destroy_notify = func_target_destroy_notify;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->priv->is_ready;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_) {
#line 2168 "app.c"
		BoxesAppCallReadyFunc _tmp2_ = NULL;
		void* _tmp2__target = NULL;
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = _data1_->func;
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2__target = _data1_->func_target;
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ (_tmp2__target);
#line 2177 "app.c"
	}
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_data (self, "ready", (GCallback) ___lambda203__boxes_app_ready, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block1_data_unref (_data1_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = NULL;
#line 2185 "app.c"
}


void boxes_app_activate (BoxesApp* self) {
	GtkApplicationWindow* _tmp0_ = NULL;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_ui (self);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->window;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_present ((GtkWindow*) _tmp0_);
#line 2199 "app.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data2_;
#line 2208 "app.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 2217 "app.c"
		BoxesApp * self;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data2_->self;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data2_->app);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block2Data, _data2_);
#line 2227 "app.c"
	}
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data3_;
#line 2237 "app.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2246 "app.c"
		BoxesApp * self;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data3_->_data2_->self;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data3_->uuid);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data3_->_data2_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_data2_ = NULL;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block3Data, _data3_);
#line 2258 "app.c"
	}
}


static void ___lambda216_ (Block3Data* _data3_) {
	Block2Data* _data2_;
	BoxesApp * self;
	BoxesApp* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = _data3_->_data2_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data2_->self;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data2_->app;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data3_->uuid;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_open_uuid (_tmp0_, _tmp1_);
#line 2278 "app.c"
}


static void ____lambda216__boxes_app_call_ready_func (gpointer self) {
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda216_ (self);
#line 2285 "app.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data4_;
#line 2294 "app.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 2303 "app.c"
		BoxesApp * self;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data4_->_data2_->self;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data4_->arg);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data4_->_data2_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_->_data2_ = NULL;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block4Data, _data4_);
#line 2315 "app.c"
	}
}


static void ____lambda217_ (Block4Data* _data4_) {
	Block2Data* _data2_;
	BoxesApp * self;
	GFile* file = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean is_uri = FALSE;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GFile* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = _data4_->_data2_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data2_->self;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data4_->arg;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_file_new_for_commandline_arg (_tmp0_);
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	file = _tmp1_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data4_->arg;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_uri_parse_scheme (_tmp2_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp4_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	is_uri = _tmp5_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = file;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_file_query_exists (_tmp6_, NULL);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_) {
#line 2361 "app.c"
		gboolean _tmp8_ = FALSE;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = is_uri;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp8_) {
#line 2367 "app.c"
			BoxesWizard* _tmp9_ = NULL;
			GFile* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = self->wizard;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = file;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = g_file_get_uri (_tmp10_);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = _tmp11_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp9_, _tmp12_, TRUE);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp12_);
#line 2384 "app.c"
		} else {
			BoxesWizard* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = self->wizard;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = _data4_->arg;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp13_, _tmp14_, TRUE);
#line 2394 "app.c"
		}
	} else {
		gboolean _tmp15_ = FALSE;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = is_uri;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp15_) {
#line 2402 "app.c"
			BoxesWizard* _tmp16_ = NULL;
			GFile* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = self->wizard;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp17_ = file;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp18_ = g_file_get_uri (_tmp17_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = _tmp18_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp16_, _tmp19_, TRUE);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp19_);
#line 2419 "app.c"
		} else {
			const gchar* _tmp20_ = NULL;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp20_ = _data4_->arg;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_open (self, _tmp20_);
#line 2426 "app.c"
		}
	}
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (file);
#line 2431 "app.c"
}


static void _____lambda217__boxes_app_call_ready_func (gpointer self) {
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	____lambda217_ (self);
#line 2438 "app.c"
}


static void ___lambda218_ (BoxesApp* self) {
	BoxesSearchbar* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	BoxesSearchbar* _tmp4_ = NULL;
	BoxesUIState _tmp5_ = 0;
	BoxesUIState _tmp6_ = 0;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->searchbar;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_app_opt_search;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__length1 = boxes_app_opt_search_length1;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_strjoinv (" ", _tmp1_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_searchbar_set_text (_tmp0_, _tmp3_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp3_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = self->searchbar;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_searchbar_set_visible (_tmp4_, TRUE);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ == BOXES_UI_STATE_COLLECTION) {
#line 2475 "app.c"
		BoxesRevealer* _tmp7_ = NULL;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = self->searchbar_revealer;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_revealer_set_revealed (_tmp7_, TRUE);
#line 2481 "app.c"
	}
}


static void ____lambda218__boxes_app_call_ready_func (gpointer self) {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda218_ (self);
#line 2489 "app.c"
}


gint boxes_app_command_line (BoxesApp* self, GApplicationCommandLine* cmdline) {
	gint result = 0;
	Block2Data* _data2_;
	gchar* parameter_string = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GOptionContext* opt_context = NULL;
	const gchar* _tmp2_ = NULL;
	GOptionContext* _tmp3_ = NULL;
	GOptionContext* _tmp4_ = NULL;
	GOptionContext* _tmp5_ = NULL;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp23_ = FALSE;
	gchar** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	gboolean _tmp29_ = FALSE;
	BoxesApplication* _tmp36_ = NULL;
	BoxesApp* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	gchar** _tmp45_ = NULL;
	gint _tmp45__length1 = 0;
	gboolean _tmp46_ = FALSE;
	GError * _inner_error_ = NULL;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (cmdline != NULL, 0);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->_ref_count_ = 1;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->self = g_object_ref (self);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_fullscreen = FALSE;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_help = FALSE;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (boxes_app_opt_open_uuid);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_open_uuid = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = (_vala_array_free (boxes_app_opt_uris, boxes_app_opt_uris_length1, (GDestroyNotify) g_free), NULL);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris_length1 = 0;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_uris_size_ = boxes_app_opt_uris_length1;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = (_vala_array_free (boxes_app_opt_search, boxes_app_opt_search_length1, (GDestroyNotify) g_free), NULL);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = NULL;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search_length1 = 0;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_search_size_ = boxes_app_opt_search_length1;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _ ("- A simple application to access remote or virtual machines");
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	parameter_string = _tmp1_;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = parameter_string;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_option_context_new (_tmp2_);
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	opt_context = _tmp3_;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = opt_context;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_add_main_entries (_tmp4_, BOXES_APP_options, NULL);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = opt_context;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_set_help_enabled (_tmp5_, FALSE);
#line 2570 "app.c"
	{
		gchar** args1 = NULL;
		GApplicationCommandLine* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gchar** _tmp8_ = NULL;
		gint args1_length1 = 0;
		gint _args1_size_ = 0;
		gchar** args2 = NULL;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		gint args2_length1 = 0;
		gint _args2_size_ = 0;
		GOptionContext* _tmp10_ = NULL;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = cmdline;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = g_application_command_line_get_arguments (_tmp6_, &_tmp7_);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = _tmp8_;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		args1_length1 = _tmp7_;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_args1_size_ = args1_length1;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = args1;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9__length1 = args1_length1;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		args2 = _tmp9_;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		args2_length1 = _tmp9__length1;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_args2_size_ = args2_length1;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = opt_context;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_option_context_parse (_tmp10_, &args2_length1, &args2, &_inner_error_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 2614 "app.c"
				goto __catch1_g_option_error;
			}
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_option_context_free0 (opt_context);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (parameter_string);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			block2_data_unref (_data2_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data2_ = NULL;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_inner_error_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			return 0;
#line 2633 "app.c"
		}
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 2637 "app.c"
	}
	goto __finally1;
	__catch1_g_option_error:
	{
		GError* _error_ = NULL;
		GApplicationCommandLine* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GApplicationCommandLine* _tmp14_ = NULL;
		GOptionContext* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_error_ = _inner_error_;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = cmdline;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _error_;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _tmp12_->message;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp11_, "%s\n", _tmp13_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = cmdline;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = opt_context;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = g_option_context_get_help (_tmp15_, TRUE, NULL);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = _tmp16_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp14_, "%s", _tmp17_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp17_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_error_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2688 "app.c"
	}
	__finally1:
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return 0;
#line 2707 "app.c"
	}
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = boxes_app_opt_help;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp18_) {
#line 2713 "app.c"
		GApplicationCommandLine* _tmp19_ = NULL;
		GOptionContext* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = cmdline;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = opt_context;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp21_ = g_option_context_get_help (_tmp20_, TRUE, NULL);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp22_ = _tmp21_;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp19_, "%s", _tmp22_);
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp22_);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2742 "app.c"
	}
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = boxes_app_opt_uris;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24__length1 = boxes_app_opt_uris_length1;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp24__length1 > 1) {
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = TRUE;
#line 2752 "app.c"
	} else {
		gboolean _tmp25_ = FALSE;
		const gchar* _tmp26_ = NULL;
		gboolean _tmp28_ = FALSE;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp26_ = boxes_app_opt_open_uuid;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp26_ != NULL) {
#line 2761 "app.c"
			gchar** _tmp27_ = NULL;
			gint _tmp27__length1 = 0;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = boxes_app_opt_uris;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27__length1 = boxes_app_opt_uris_length1;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = _tmp27_ != NULL;
#line 2770 "app.c"
		} else {
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = FALSE;
#line 2774 "app.c"
		}
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp28_ = _tmp25_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = _tmp28_;
#line 2780 "app.c"
	}
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp29_ = _tmp23_;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp29_) {
#line 2786 "app.c"
		GApplicationCommandLine* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		GApplicationCommandLine* _tmp32_ = NULL;
		GOptionContext* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp30_ = cmdline;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp31_ = _ ("Too many command line arguments specified.\n");
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp30_, "%s", _tmp31_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp32_ = cmdline;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp33_ = opt_context;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp34_ = g_option_context_get_help (_tmp33_, TRUE, NULL);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp35_ = _tmp34_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp32_, "%s", _tmp35_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp35_);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2823 "app.c"
	}
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp36_ = self->priv->application;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_activate ((GApplication*) _tmp36_);
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp37_ = _g_object_ref0 (self);
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->app = _tmp37_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp38_ = boxes_app_opt_open_uuid;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp38_ != NULL) {
#line 2837 "app.c"
		Block3Data* _data3_;
		const gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_ = g_slice_new0 (Block3Data);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_ref_count_ = 1;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_data2_ = block2_data_ref (_data2_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp39_ = boxes_app_opt_open_uuid;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp40_ = g_strdup (_tmp39_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->uuid = _tmp40_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda216__boxes_app_call_ready_func, block3_data_ref (_data3_), block3_data_unref);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block3_data_unref (_data3_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_ = NULL;
#line 2859 "app.c"
	} else {
		gchar** _tmp41_ = NULL;
		gint _tmp41__length1 = 0;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp41_ = boxes_app_opt_uris;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp41__length1 = boxes_app_opt_uris_length1;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp41_ != NULL) {
#line 2869 "app.c"
			Block4Data* _data4_;
			gchar** _tmp42_ = NULL;
			gint _tmp42__length1 = 0;
			const gchar* _tmp43_ = NULL;
			gchar* _tmp44_ = NULL;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_ = g_slice_new0 (Block4Data);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->_ref_count_ = 1;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->_data2_ = block2_data_ref (_data2_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp42_ = boxes_app_opt_uris;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp42__length1 = boxes_app_opt_uris_length1;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp43_ = _tmp42_[0];
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp44_ = g_strdup (_tmp43_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->arg = _tmp44_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_call_when_ready (self, _____lambda217__boxes_app_call_ready_func, block4_data_ref (_data4_), block4_data_unref);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			block4_data_unref (_data4_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_ = NULL;
#line 2897 "app.c"
		}
	}
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp45_ = boxes_app_opt_search;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp45__length1 = boxes_app_opt_search_length1;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp45_ != NULL) {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda218__boxes_app_call_ready_func, g_object_ref (self), g_object_unref);
#line 2908 "app.c"
	}
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp46_ = boxes_app_opt_fullscreen;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp46_) {
#line 2914 "app.c"
		BoxesApp* _tmp47_ = NULL;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp47_ = _data2_->app;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_fullscreen (_tmp47_, TRUE);
#line 2920 "app.c"
	}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = 0;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_option_context_free0 (opt_context);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (parameter_string);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block2_data_unref (_data2_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = NULL;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 2934 "app.c"
}


gint boxes_app_run (BoxesApp* self, gchar** args, int args_length1) {
	gint result = 0;
	BoxesApplication* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gint _tmp2_ = 0;
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->application;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = args;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__length1 = args_length1;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_application_run ((GApplication*) _tmp0_, _tmp1__length1, _tmp1_);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 2958 "app.c"
}


void boxes_app_shutdown (BoxesApp* self) {
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->application);
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->application = NULL;
#line 2969 "app.c"
}


void boxes_app_open (BoxesApp* self, const gchar* name) {
	BoxesCollectionView* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gpointer* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (name != NULL);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_set_visible (_tmp0_, FALSE);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->collection;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->items;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_->pdata;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3__length1 = (gint) _tmp2_->len;
#line 2997 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp3_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp3__length1;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp3__length1; item_it = item_it + 1) {
#line 3009 "app.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp4_ = _g_object_ref0 (item_collection[item_it]);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp4_;
#line 3016 "app.c"
			{
				BoxesCollectionItem* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = item;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = boxes_collection_item_get_name (_tmp5_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = _tmp6_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp8_ = name;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (g_strcmp0 (_tmp7_, _tmp8_) == 0) {
#line 3032 "app.c"
					BoxesCollectionItem* _tmp9_ = NULL;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp9_ = item;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_app_select_item (self, _tmp9_);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					break;
#line 3042 "app.c"
				}
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 3046 "app.c"
			}
		}
	}
}


gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid) {
	gboolean result = FALSE;
	BoxesCollectionView* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gpointer* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (uuid != NULL, FALSE);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_set_visible (_tmp0_, FALSE);
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->collection;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->items;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_->pdata;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3__length1 = (gint) _tmp2_->len;
#line 3078 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp3_;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp3__length1;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp3__length1; item_it = item_it + 1) {
#line 3090 "app.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp4_ = _g_object_ref0 (item_collection[item_it]);
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp4_;
#line 3097 "app.c"
			{
				BoxesCollectionItem* _tmp5_ = NULL;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
				BoxesMachine* _tmp8_ = NULL;
				BoxesBoxConfig* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				BoxesCollectionItem* _tmp15_ = NULL;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = item;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE)) {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3119 "app.c"
				}
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = item;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp6_) : NULL);
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp7_;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp8_ = machine;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp9_ = _tmp8_->config;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp10_ = boxes_box_config_get_uuid (_tmp9_);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp11_ = _tmp10_;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp12_ = _tmp11_;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp13_ = uuid;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp14_ = g_strcmp0 (_tmp12_, _tmp13_) != 0;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_tmp12_);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp14_) {
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (machine);
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3151 "app.c"
				}
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp15_ = item;
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_select_item (self, _tmp15_);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				result = TRUE;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				return result;
#line 3165 "app.c"
			}
		}
	}
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3173 "app.c"
}


void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user) {
	BoxesMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesCollection* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = by_user;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_machine_delete (_tmp0_, _tmp1_);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->collection;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = machine;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_remove_item (_tmp2_, (BoxesCollectionItem*) _tmp3_);
#line 3198 "app.c"
}


static void boxes_app_add_collection_source_data_free (gpointer _data) {
	BoxesAppAddCollectionSourceData* _data_;
	_data_ = _data;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppAddCollectionSourceData, _data_);
#line 3211 "app.c"
}


void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppAddCollectionSourceData);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_add_collection_source);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_add_collection_source_data_free);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3240 "app.c"
}


void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3248 "app.c"
}


static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3262 "app.c"
}


static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_) {
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label0 = 0;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label1 = 0;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 3275 "app.c"
		goto _state_0;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 3279 "app.c"
		goto _state_1;
		default:
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 3284 "app.c"
	}
	_state_0:
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = _data_->source;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = FALSE;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = boxes_collection_source_get_enabled (_data_->_tmp0_);
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = FALSE;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (!_data_->_tmp2_) {
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3305 "app.c"
		} else {
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3309 "app.c"
		}
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3315 "app.c"
	}
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->self->priv->sources;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = _data_->source;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = boxes_collection_source_get_name (_data_->_tmp4_);
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = g_hash_table_lookup (_data_->_tmp3_, _data_->_tmp7_);
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = FALSE;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = ((BoxesCollectionSource*) _data_->_tmp8_) != NULL;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp7_);
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp9_) {
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = _data_->source;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = boxes_collection_source_get_name (_data_->_tmp10_);
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = NULL;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = NULL;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:384: Attempt to add duplicate collection source '%s', ignorin" \
"g..", _data_->_tmp13_);
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp13_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3373 "app.c"
		} else {
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3377 "app.c"
		}
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3383 "app.c"
	}
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = _data_->source;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = boxes_collection_source_get_source_type (_data_->_tmp14_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = 0U;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = (NULL == _data_->_tmp17_) ? 0 : g_quark_from_string (_data_->_tmp17_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_free (_data_->_tmp17_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if ((_data_->_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("vnc")))) || (_data_->_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("spice"))))) {
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 3411 "app.c"
			default:
			{
				{
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = NULL;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = _data_->source;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = NULL;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = boxes_remote_machine_new (_data_->_tmp20_, &_data_->_inner_error_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->machine = _data_->_tmp21_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					if (_data_->_inner_error_ != NULL) {
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3429 "app.c"
							goto __catch2_boxes_error;
						}
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						g_clear_error (&_data_->_inner_error_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						return FALSE;
#line 3438 "app.c"
					}
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = NULL;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = _data_->self->collection;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = NULL;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = _data_->machine;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_collection_add_item (_data_->_tmp22_, (BoxesCollectionItem*) _data_->_tmp23_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->machine);
#line 3452 "app.c"
				}
				goto __finally2;
				__catch2_boxes_error:
				{
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_inner_error_ = NULL;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = NULL;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = _data_->_error_;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = NULL;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = _data_->_tmp24_->message;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:395: %s", _data_->_tmp25_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_error_free0 (_data_->_error_);
#line 3473 "app.c"
				}
				__finally2:
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_data_->_inner_error_ != NULL) {
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_clear_error (&_data_->_inner_error_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 3484 "app.c"
				}
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 3488 "app.c"
			}
		}
	} else {
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 3494 "app.c"
			default:
			{
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = _data_->self->priv->brokers;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = _data_->source;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = boxes_collection_source_get_source_type (_data_->_tmp27_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = g_hash_table_lookup (_data_->_tmp26_, _data_->_tmp30_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = _g_object_ref0 ((BoxesBroker*) _data_->_tmp31_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = _data_->_tmp32_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_data_->_tmp30_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->broker = _data_->_tmp33_;
#line 401 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = NULL;
#line 401 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = _data_->broker;
#line 401 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_data_->_tmp34_ != NULL) {
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = NULL;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = _data_->broker;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = NULL;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = _data_->source;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_state_ = 1;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source (_data_->_tmp35_, _data_->_tmp36_, boxes_app_add_collection_source_ready, _data_);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 3553 "app.c"
					_state_1:
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source_finish (_data_->_tmp35_, _data_->_res_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = _data_->self->priv->sources;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = _data_->source;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = boxes_collection_source_get_name (_data_->_tmp38_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = _data_->_tmp39_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = _data_->source;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = _g_object_ref0 (_data_->_tmp41_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_hash_table_insert (_data_->_tmp37_, _data_->_tmp40_, _data_->_tmp42_);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = NULL;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = _data_->source;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = NULL;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = boxes_collection_source_get_name (_data_->_tmp43_);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = NULL;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = _data_->_tmp44_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = NULL;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = _data_->_tmp45_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = FALSE;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = g_strcmp0 (_data_->_tmp46_, "QEMU Session") == 0;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp46_);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					if (_data_->_tmp47_) {
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-connection");
#line 406 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-source");
#line 3611 "app.c"
					}
				} else {
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = NULL;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = _data_->source;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = NULL;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = boxes_collection_source_get_source_type (_data_->_tmp48_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = NULL;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = _data_->_tmp49_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = NULL;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = _data_->_tmp50_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:409: Unsupported source type %s", _data_->_tmp51_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp51_);
#line 3634 "app.c"
				}
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->broker);
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 3640 "app.c"
			}
		}
	}
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3648 "app.c"
	} else {
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3652 "app.c"
	}
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 3658 "app.c"
}


static void boxes_app_setup_sources_data_free (gpointer _data) {
	BoxesAppSetupSourcesData* _data_;
	_data_ = _data;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppSetupSourcesData, _data_);
#line 3669 "app.c"
}


static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
	BoxesApp* _tmp0_ = NULL;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppSetupSourcesData);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_setup_sources);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_setup_sources_data_free);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 3688 "app.c"
}


static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppSetupSourcesData* _data_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3696 "app.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data5_;
#line 3705 "app.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 3714 "app.c"
		BoxesApp * self;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data5_->self;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data5_->new_sources);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block5Data, _data5_);
#line 3724 "app.c"
	}
}


static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 3739 "app.c"
}


static gboolean __lambda210_ (Block5Data* _data5_, const gchar* filename, GError** error) {
	BoxesApp * self;
	gboolean result = FALSE;
	BoxesCollectionSource* source = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data5_->self;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = filename;
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_source_new_with_file (_tmp0_, &_inner_error_);
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	source = _tmp1_;
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_propagate_error (error, _inner_error_);
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3767 "app.c"
	}
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (source);
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data5_->new_sources = g_list_append (_data5_->new_sources, _tmp2_);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (source);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3779 "app.c"
}


static gboolean ___lambda210__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error) {
	gboolean result;
	result = __lambda210_ (self, filename, error);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3788 "app.c"
}


static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_) {
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 3797 "app.c"
		goto _state_0;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 3801 "app.c"
		goto _state_1;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 2:
#line 3805 "app.c"
		goto _state_2;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case 3:
#line 3809 "app.c"
		goto _state_3;
		default:
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 3814 "app.c"
	}
	_state_0:
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_ = g_slice_new0 (Block5Data);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->_ref_count_ = 1;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->self = g_object_ref (_data_->self);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->_async_data_ = _data_;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_get_user_pkgconfig_source ("QEMU Session");
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = NULL;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = FALSE;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = g_file_test (_data_->_tmp1_, G_FILE_TEST_IS_REGULAR);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = FALSE;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = !_data_->_tmp2_;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp1_);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp3_) {
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = NULL;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = boxes_get_pkgdata_source ("QEMU_Session");
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = NULL;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp6_ = NULL;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp6_ = g_file_new_for_path (_data_->_tmp5_);
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = NULL;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp5_);
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->src = _data_->_tmp7_;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = boxes_get_user_pkgconfig_source ("QEMU Session");
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = g_file_new_for_path (_data_->_tmp9_);
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp9_);
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->dst = _data_->_tmp11_;
#line 3885 "app.c"
		{
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = NULL;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = _data_->src;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = NULL;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = _data_->dst;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_state_ = 1;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_async (_data_->_tmp12_, _data_->_tmp13_, G_FILE_COPY_NONE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_app_setup_sources_ready, _data_);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 3901 "app.c"
			_state_1:
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_data_->_inner_error_ != NULL) {
#line 3907 "app.c"
				goto __catch3_g_error;
			}
		}
		goto __finally3;
		__catch3_g_error:
		{
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_inner_error_ = NULL;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = NULL;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = _data_->_error_;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = NULL;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = _data_->_tmp14_->message;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("app.vala:423: Can't setup default sources: %s", _data_->_tmp15_);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_error_free0 (_data_->_error_);
#line 3930 "app.c"
		}
		__finally3:
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->dst);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->src);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			block5_data_unref (_data_->_data5_);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_data5_ = NULL;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_data_->_inner_error_);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 3949 "app.c"
		}
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->dst);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->src);
#line 3955 "app.c"
	}
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = NULL;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = boxes_get_user_pkgconfig_source (NULL);
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = NULL;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp18_ = NULL;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp18_ = g_file_new_for_path (_data_->_tmp17_);
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = NULL;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp17_);
#line 427 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->dir = _data_->_tmp19_;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->new_sources = NULL;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = NULL;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = _data_->dir;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_state_ = 2;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir (_data_->_tmp20_, ___lambda210__boxes_foreach_filename_from_dir_func, _data_->_data5_, boxes_app_setup_sources_ready, _data_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 3989 "app.c"
	_state_2:
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir_finish (_data_->_res_);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = NULL;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = _data_->_data5_->new_sources;
#line 3997 "app.c"
	{
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->source_collection = _data_->_tmp21_;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->source_it = _data_->source_collection; _data_->source_it != NULL; _data_->source_it = _data_->source_it->next) {
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp22_ = NULL;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp22_ = _g_object_ref0 ((BoxesCollectionSource*) _data_->source_it->data);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->source = _data_->_tmp22_;
#line 4009 "app.c"
			{
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp23_ = NULL;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp23_ = _data_->source;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_state_ = 3;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source (_data_->self, _data_->_tmp23_, boxes_app_setup_sources_ready, _data_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				return FALSE;
#line 4021 "app.c"
				_state_3:
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source_finish (_data_->self, _data_->_res_);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->source);
#line 4027 "app.c"
			}
		}
	}
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp24_ = NULL;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp24_ = boxes_app_get_default_connection (_data_->self);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp25_ = NULL;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp26_ = NULL;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp27_ = FALSE;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp27_ = _data_->_tmp26_ == NULL;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->_tmp26_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp27_) {
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_printerr ("Missing or failing default libvirt connection\n");
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp28_ = NULL;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp28_ = _data_->self->priv->application;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_release ((GApplication*) _data_->_tmp28_);
#line 4059 "app.c"
	}
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->dir);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block5_data_unref (_data_->_data5_);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_ = NULL;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4071 "app.c"
	} else {
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4075 "app.c"
	}
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4081 "app.c"
}


static GVariant* _variant_new1 (gint* value, gint value_length1) {
	gint* _tmp10_;
	GVariantBuilder _tmp11_;
	int _tmp12_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = value;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_variant_builder_init (&_tmp11_, G_VARIANT_TYPE ("ai"));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	for (_tmp12_ = 0; _tmp12_ < value_length1; _tmp12_++) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_variant_builder_add_value (&_tmp11_, g_variant_new_int32 (*_tmp10_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_++;
#line 4099 "app.c"
	}
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp11_));
#line 4103 "app.c"
}


static GVariant* _variant_new2 (gint* value, gint value_length1) {
	gint* _tmp22_;
	GVariantBuilder _tmp23_;
	int _tmp24_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = value;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_variant_builder_init (&_tmp23_, G_VARIANT_TYPE ("ai"));
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	for (_tmp24_ = 0; _tmp24_ < value_length1; _tmp24_++) {
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_variant_builder_add_value (&_tmp23_, g_variant_new_int32 (*_tmp22_));
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp22_++;
#line 4121 "app.c"
	}
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp23_));
#line 4125 "app.c"
}


static void boxes_app_save_window_geometry (BoxesApp* self) {
	gint width = 0;
	gint height = 0;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkApplicationWindow* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	GSettings* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	gint* _tmp8_ = NULL;
	gint* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GVariant* _tmp13_ = NULL;
	GtkApplicationWindow* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	GSettings* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	gint* _tmp20_ = NULL;
	gint* _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	GVariant* _tmp25_ = NULL;
#line 444 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_maximized (self);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_) {
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 4166 "app.c"
	}
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->window;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_get_size ((GtkWindow*) _tmp2_, &_tmp3_, &_tmp4_);
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	width = _tmp3_;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	height = _tmp4_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = self->settings;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = width;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = height;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_new0 (gint, 2);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_[0] = _tmp6_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_[1] = _tmp7_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _tmp8_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9__length1 = 2;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = _variant_new1 (_tmp9_, 2);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_settings_set_value (_tmp5_, "window-size", _tmp13_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_variant_unref0 (_tmp13_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = (g_free (_tmp9_), NULL);
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = self->window;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_get_position ((GtkWindow*) _tmp14_, &_tmp15_, &_tmp16_);
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	x = _tmp15_;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	y = _tmp16_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = self->settings;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = x;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = y;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = g_new0 (gint, 2);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_[0] = _tmp18_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_[1] = _tmp19_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = _tmp20_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21__length1 = 2;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = _variant_new2 (_tmp21_, 2);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_settings_set_value (_tmp17_, "window-position", _tmp25_);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_variant_unref0 (_tmp25_);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = (g_free (_tmp21_), NULL);
#line 4232 "app.c"
}


static gint _variant_get3 (GVariant* value) {
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_get_int32 (value);
#line 4239 "app.c"
}


static gint _variant_get4 (GVariant* value) {
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_get_int32 (value);
#line 4246 "app.c"
}


static gint _variant_get5 (GVariant* value) {
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_get_int32 (value);
#line 4253 "app.c"
}


static gint _variant_get6 (GVariant* value) {
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return g_variant_get_int32 (value);
#line 4260 "app.c"
}


static gboolean __lambda213_ (BoxesApp* self) {
	gboolean result = FALSE;
#line 506 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->configure_id = (guint) 0;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_save_window_geometry (self);
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4274 "app.c"
}


static gboolean ___lambda213__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda213_ (self);
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4283 "app.c"
}


static gboolean __lambda212_ (BoxesApp* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	guint _tmp2_ = 0U;
	guint _tmp4_ = 0U;
#line 500 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_fullscreen (self);
#line 500 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 500 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_) {
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = FALSE;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 4303 "app.c"
	}
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->priv->configure_id;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 4309 "app.c"
		guint _tmp3_ = 0U;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = self->priv->configure_id;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_source_remove (_tmp3_);
#line 4315 "app.c"
	}
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_APP_configure_id_timeout, ___lambda213__gsource_func, g_object_ref (self), g_object_unref);
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->configure_id = _tmp4_;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4325 "app.c"
}


static gboolean ___lambda212__gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self) {
	gboolean result;
	result = __lambda212_ (self);
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4334 "app.c"
}


static gboolean __lambda214_ (BoxesApp* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
	GdkEventWindowState _tmp0_ = {0};
	GdkWindowState _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GSettings* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = *event;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_.changed_mask;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if ((_tmp1_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN) {
#line 516 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_notify ((GObject*) self, "fullscreen");
#line 4357 "app.c"
	}
#line 518 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_get_fullscreen (self);
#line 518 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 518 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp3_) {
#line 519 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = FALSE;
#line 519 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 4369 "app.c"
	}
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = self->settings;
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_app_get_maximized (self);
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_settings_set_boolean (_tmp4_, "window-maximized", _tmp6_);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4383 "app.c"
}


static gboolean ___lambda214__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = __lambda214_ (self, event);
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4392 "app.c"
}


static gboolean __lambda215_ (BoxesApp* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_quit (self);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4405 "app.c"
}


static gboolean ___lambda215__gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = __lambda215_ (self);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4414 "app.c"
}


static gboolean _boxes_app_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_app_on_key_pressed (self, _sender, event);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4423 "app.c"
}


static void boxes_app_setup_ui (BoxesApp* self) {
	gboolean _tmp0_ = FALSE;
	GtkSettings* _tmp1_ = NULL;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp2_ = NULL;
	BoxesApplication* _tmp10_ = NULL;
	GtkApplicationWindow* _tmp11_ = NULL;
	GtkApplicationWindow* _tmp12_ = NULL;
	GVariant* size = NULL;
	GSettings* _tmp13_ = NULL;
	GVariant* _tmp14_ = NULL;
	GVariant* _tmp15_ = NULL;
	gsize _tmp16_ = 0UL;
	GSettings* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	GVariant* position = NULL;
	GSettings* _tmp33_ = NULL;
	GVariant* _tmp34_ = NULL;
	GVariant* _tmp35_ = NULL;
	gsize _tmp36_ = 0UL;
	GtkApplicationWindow* _tmp50_ = NULL;
	GtkApplicationWindow* _tmp51_ = NULL;
	GtkBox* main_vbox = NULL;
	GtkBox* _tmp52_ = NULL;
	GtkApplicationWindow* _tmp53_ = NULL;
	GtkBox* _tmp54_ = NULL;
	GtkNotebook* _tmp55_ = NULL;
	GtkNotebook* _tmp56_ = NULL;
	GtkNotebook* _tmp57_ = NULL;
	GtkBox* _tmp58_ = NULL;
	GtkNotebook* _tmp59_ = NULL;
	BoxesClutterWidget* _tmp60_ = NULL;
	GtkNotebook* _tmp61_ = NULL;
	BoxesClutterWidget* _tmp62_ = NULL;
	BoxesDisplayPage* _tmp63_ = NULL;
	GtkNotebook* _tmp64_ = NULL;
	BoxesDisplayPage* _tmp65_ = NULL;
	GtkWidget* _tmp66_ = NULL;
	GtkWidget* _tmp67_ = NULL;
	BoxesSelectionbar* _tmp68_ = NULL;
	GtkBox* _tmp69_ = NULL;
	BoxesSelectionbar* _tmp70_ = NULL;
	BoxesClutterWidget* _tmp71_ = NULL;
	ClutterActor* _tmp72_ = NULL;
	ClutterStage* _tmp73_ = NULL;
	ClutterStage* _tmp74_ = NULL;
	GdkRGBA _tmp75_ = {0};
	ClutterColor _tmp76_ = {0};
	GtkApplicationWindow* _tmp77_ = NULL;
	GtkApplicationWindow* _tmp78_ = NULL;
	ClutterBinLayout* _tmp79_ = NULL;
	ClutterStage* _tmp80_ = NULL;
	ClutterBinLayout* _tmp81_ = NULL;
	ClutterStage* _tmp82_ = NULL;
	GtkClutterTexture* background = NULL;
	GtkClutterTexture* _tmp83_ = NULL;
	GtkClutterTexture* _tmp84_ = NULL;
	GtkClutterTexture* _tmp91_ = NULL;
	GtkClutterTexture* _tmp92_ = NULL;
	GtkClutterTexture* _tmp93_ = NULL;
	GtkClutterTexture* _tmp94_ = NULL;
	GtkClutterTexture* _tmp95_ = NULL;
	ClutterStage* _tmp96_ = NULL;
	GtkClutterTexture* _tmp97_ = NULL;
	BoxesSidebar* _tmp98_ = NULL;
	BoxesCollectionView* _tmp99_ = NULL;
	BoxesSearchbar* _tmp100_ = NULL;
	BoxesTopbar* _tmp101_ = NULL;
	BoxesNotificationbar* _tmp102_ = NULL;
	BoxesWizard* _tmp103_ = NULL;
	BoxesProperties* _tmp104_ = NULL;
	BoxesEmptyBoxes* _tmp105_ = NULL;
	ClutterActor* vbox_actor = NULL;
	ClutterActor* _tmp106_ = NULL;
	ClutterActor* _tmp107_ = NULL;
	ClutterBoxLayout* vbox = NULL;
	ClutterBoxLayout* _tmp108_ = NULL;
	ClutterActor* _tmp109_ = NULL;
	ClutterBoxLayout* _tmp110_ = NULL;
	ClutterBoxLayout* _tmp111_ = NULL;
	ClutterActor* _tmp112_ = NULL;
	ClutterActor* _tmp113_ = NULL;
	ClutterActor* _tmp114_ = NULL;
	ClutterActor* _tmp115_ = NULL;
	ClutterStage* _tmp116_ = NULL;
	ClutterActor* _tmp117_ = NULL;
	GtkApplicationWindow* _tmp118_ = NULL;
	BoxesTopbar* _tmp119_ = NULL;
	GtkWidget* _tmp120_ = NULL;
	GtkWidget* _tmp121_ = NULL;
	BoxesRevealer* _tmp122_ = NULL;
	BoxesRevealer* _tmp123_ = NULL;
	BoxesRevealer* _tmp124_ = NULL;
	BoxesRevealer* _tmp125_ = NULL;
	BoxesRevealer* _tmp126_ = NULL;
	ClutterActor* _tmp127_ = NULL;
	BoxesRevealer* _tmp128_ = NULL;
	BoxesRevealer* _tmp129_ = NULL;
	BoxesSearchbar* _tmp130_ = NULL;
	ClutterActor* _tmp131_ = NULL;
	ClutterActor* _tmp132_ = NULL;
	ClutterActor* below_bin_actor = NULL;
	ClutterActor* _tmp133_ = NULL;
	ClutterActor* _tmp134_ = NULL;
	ClutterBinLayout* below_bin = NULL;
	ClutterBinLayout* _tmp135_ = NULL;
	ClutterActor* _tmp136_ = NULL;
	ClutterBinLayout* _tmp137_ = NULL;
	ClutterActor* _tmp138_ = NULL;
	ClutterActor* _tmp139_ = NULL;
	ClutterActor* _tmp140_ = NULL;
	ClutterActor* _tmp141_ = NULL;
	ClutterActor* _tmp142_ = NULL;
	BoxesCollectionView* _tmp143_ = NULL;
	ClutterActor* _tmp144_ = NULL;
	ClutterActor* _tmp145_ = NULL;
	ClutterActor* hbox_actor = NULL;
	ClutterActor* _tmp146_ = NULL;
	ClutterActor* _tmp147_ = NULL;
	ClutterBoxLayout* hbox = NULL;
	ClutterBoxLayout* _tmp148_ = NULL;
	ClutterActor* _tmp149_ = NULL;
	ClutterBoxLayout* _tmp150_ = NULL;
	ClutterActor* _tmp151_ = NULL;
	ClutterActor* _tmp152_ = NULL;
	ClutterActor* _tmp153_ = NULL;
	ClutterActor* _tmp154_ = NULL;
	ClutterActor* _tmp155_ = NULL;
	ClutterActor* _tmp156_ = NULL;
	ClutterActor* _tmp157_ = NULL;
	ClutterActor* _tmp158_ = NULL;
	ClutterBinLayout* _tmp159_ = NULL;
	ClutterActor* _tmp160_ = NULL;
	ClutterBinLayout* _tmp161_ = NULL;
	ClutterActor* _tmp162_ = NULL;
	ClutterActor* _tmp163_ = NULL;
	ClutterActor* _tmp164_ = NULL;
	ClutterActor* _tmp165_ = NULL;
	ClutterActor* _tmp166_ = NULL;
	ClutterActor* _tmp167_ = NULL;
	BoxesRevealer* _tmp168_ = NULL;
	BoxesRevealer* _tmp169_ = NULL;
	BoxesRevealer* _tmp170_ = NULL;
	ClutterActor* _tmp171_ = NULL;
	BoxesRevealer* _tmp172_ = NULL;
	BoxesRevealer* _tmp173_ = NULL;
	BoxesRevealer* _tmp174_ = NULL;
	BoxesSidebar* _tmp175_ = NULL;
	ClutterActor* _tmp176_ = NULL;
	ClutterActor* _tmp177_ = NULL;
	ClutterActor* content_bin_actor = NULL;
	ClutterActor* _tmp178_ = NULL;
	ClutterActor* _tmp179_ = NULL;
	ClutterActor* _tmp180_ = NULL;
	ClutterActor* _tmp181_ = NULL;
	ClutterActor* _tmp182_ = NULL;
	ClutterActor* _tmp183_ = NULL;
	ClutterBinLayout* content_bin = NULL;
	ClutterBinLayout* _tmp184_ = NULL;
	ClutterActor* _tmp185_ = NULL;
	ClutterBinLayout* _tmp186_ = NULL;
	ClutterActor* _tmp187_ = NULL;
	ClutterActor* _tmp188_ = NULL;
	ClutterActor* _tmp189_ = NULL;
	BoxesNotificationbar* _tmp190_ = NULL;
	ClutterActor* _tmp191_ = NULL;
	ClutterActor* _tmp192_ = NULL;
	ClutterActor* _tmp193_ = NULL;
	BoxesWizard* _tmp194_ = NULL;
	ClutterActor* _tmp195_ = NULL;
	ClutterActor* _tmp196_ = NULL;
	ClutterActor* _tmp197_ = NULL;
	BoxesProperties* _tmp198_ = NULL;
	ClutterActor* _tmp199_ = NULL;
	ClutterActor* _tmp200_ = NULL;
	ClutterActor* _tmp201_ = NULL;
	BoxesEmptyBoxes* _tmp202_ = NULL;
	ClutterActor* _tmp203_ = NULL;
	ClutterActor* _tmp204_ = NULL;
	BoxesProperties* _tmp205_ = NULL;
	ClutterActor* _tmp206_ = NULL;
	ClutterActor* _tmp207_ = NULL;
	BoxesEmptyBoxes* _tmp208_ = NULL;
	ClutterActor* _tmp209_ = NULL;
	ClutterActor* _tmp210_ = NULL;
	GtkBox* _tmp211_ = NULL;
	GError * _inner_error_ = NULL;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->ui_is_setup;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_) {
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 4622 "app.c"
	}
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->ui_is_setup = TRUE;
#line 462 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_set_default_icon_name ("gnome-boxes");
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = gtk_settings_get_default ();
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_set (_tmp1_, "gtk-application-prefer-dark-theme", TRUE, NULL);
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = gtk_css_provider_new ();
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	provider = _tmp2_;
#line 4636 "app.c"
	{
		gchar* sheet = NULL;
		gchar* _tmp3_ = NULL;
		GtkCssProvider* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GdkScreen* _tmp6_ = NULL;
		GtkCssProvider* _tmp7_ = NULL;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = boxes_get_style ("gtk-style.css");
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		sheet = _tmp3_;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = provider;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = sheet;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_css_provider_load_from_path (_tmp4_, _tmp5_, &_inner_error_);
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (sheet);
#line 4658 "app.c"
			goto __catch4_g_error;
		}
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = gdk_screen_get_default ();
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = provider;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_style_context_add_provider_for_screen (_tmp6_, (GtkStyleProvider*) _tmp7_, (guint) 600);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (sheet);
#line 4669 "app.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_error_ = _inner_error_;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _error_;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = _tmp8_->message;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:473: %s", _tmp9_);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_error_);
#line 4689 "app.c"
	}
	__finally4:
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (provider);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 4702 "app.c"
	}
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = self->priv->application;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = (GtkApplicationWindow*) gtk_application_window_new ((GtkApplication*) _tmp10_);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp11_);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->window);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->window = _tmp11_;
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = self->window;
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_application_window_set_show_menubar (_tmp12_, FALSE);
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = self->settings;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = g_settings_get_value (_tmp13_, "window-size");
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	size = _tmp14_;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = size;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = g_variant_n_children (_tmp15_);
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp16_ == ((gsize) 2)) {
#line 4730 "app.c"
		gint width = 0;
		GVariant* _tmp17_ = NULL;
		GVariant* _tmp18_ = NULL;
		GVariant* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		gint height = 0;
		GVariant* _tmp22_ = NULL;
		GVariant* _tmp23_ = NULL;
		GVariant* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		GtkApplicationWindow* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = size;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = g_variant_get_child_value (_tmp17_, (gsize) 0);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = _tmp18_;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = _variant_get3 (_tmp19_);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp21_ = _tmp20_;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (_tmp19_);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		width = _tmp21_;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp22_ = size;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = g_variant_get_child_value (_tmp22_, (gsize) 1);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp24_ = _tmp23_;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp25_ = _variant_get4 (_tmp24_);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp26_ = _tmp25_;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (_tmp24_);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		height = _tmp26_;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp27_ = self->window;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp28_ = width;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp29_ = height;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_set_default_size ((GtkWindow*) _tmp27_, _tmp28_, _tmp29_);
#line 4782 "app.c"
	}
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp30_ = self->settings;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31_ = g_settings_get_boolean (_tmp30_, "window-maximized");
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp31_) {
#line 4790 "app.c"
		GtkApplicationWindow* _tmp32_ = NULL;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp32_ = self->window;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_maximize ((GtkWindow*) _tmp32_);
#line 4796 "app.c"
	}
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp33_ = self->settings;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = g_settings_get_value (_tmp33_, "window-position");
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	position = _tmp34_;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp35_ = position;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp36_ = g_variant_n_children (_tmp35_);
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp36_ == ((gsize) 2)) {
#line 4810 "app.c"
		gint x = 0;
		GVariant* _tmp37_ = NULL;
		GVariant* _tmp38_ = NULL;
		GVariant* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
		gint y = 0;
		GVariant* _tmp42_ = NULL;
		GVariant* _tmp43_ = NULL;
		GVariant* _tmp44_ = NULL;
		gint _tmp45_ = 0;
		gint _tmp46_ = 0;
		GtkApplicationWindow* _tmp47_ = NULL;
		gint _tmp48_ = 0;
		gint _tmp49_ = 0;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp37_ = position;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp38_ = g_variant_get_child_value (_tmp37_, (gsize) 0);
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp39_ = _tmp38_;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp40_ = _variant_get5 (_tmp39_);
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp41_ = _tmp40_;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (_tmp39_);
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		x = _tmp41_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp42_ = position;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp43_ = g_variant_get_child_value (_tmp42_, (gsize) 1);
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp44_ = _tmp43_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp45_ = _variant_get6 (_tmp44_);
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp46_ = _tmp45_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (_tmp44_);
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		y = _tmp46_;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp47_ = self->window;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp48_ = x;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp49_ = y;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_move ((GtkWindow*) _tmp47_, _tmp48_, _tmp49_);
#line 4862 "app.c"
	}
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp50_ = self->window;
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object ((GtkWidget*) _tmp50_, "configure-event", (GCallback) ___lambda212__gtk_widget_configure_event, self, 0);
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp51_ = self->window;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object ((GtkWidget*) _tmp51_, "window-state-event", (GCallback) ___lambda214__gtk_widget_window_state_event, self, 0);
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp52_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp52_);
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	main_vbox = _tmp52_;
#line 526 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp53_ = self->window;
#line 526 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp54_ = main_vbox;
#line 526 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_container_add ((GtkContainer*) _tmp53_, (GtkWidget*) _tmp54_);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp55_ = (GtkNotebook*) gtk_notebook_new ();
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp55_);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->notebook);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->notebook = _tmp55_;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp56_ = self->notebook;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_notebook_set_show_border (_tmp56_, FALSE);
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp57_ = self->notebook;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_notebook_set_show_tabs (_tmp57_, FALSE);
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp58_ = main_vbox;
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp59_ = self->notebook;
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_container_add ((GtkContainer*) _tmp58_, (GtkWidget*) _tmp59_);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp60_ = boxes_clutter_widget_new ();
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp60_);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->embed);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->embed = _tmp60_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp61_ = self->notebook;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp62_ = self->embed;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_notebook_append_page (_tmp61_, (GtkWidget*) _tmp62_, NULL);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp63_ = boxes_display_page_new ();
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->display_page);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->display_page = _tmp63_;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp64_ = self->notebook;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp65_ = self->display_page;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp66_ = boxes_display_page_get_widget (_tmp65_);
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp67_ = _tmp66_;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_notebook_append_page (_tmp64_, _tmp67_, NULL);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp68_ = boxes_selectionbar_new ();
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp68_);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->selectionbar);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->selectionbar = _tmp68_;
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp69_ = main_vbox;
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp70_ = self->selectionbar;
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_container_add ((GtkContainer*) _tmp69_, (GtkWidget*) _tmp70_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp71_ = self->embed;
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp72_ = gtk_clutter_embed_get_stage ((GtkClutterEmbed*) _tmp71_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp73_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, clutter_stage_get_type ()) ? ((ClutterStage*) _tmp72_) : NULL);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->stage);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->stage = _tmp73_;
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp74_ = self->stage;
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_get_boxes_bg_color (&_tmp75_);
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_gdk_rgba_to_clutter_color (&_tmp75_, &_tmp76_);
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_background_color ((ClutterActor*) _tmp74_, &_tmp76_);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp77_ = self->window;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object ((GtkWidget*) _tmp77_, "delete-event", (GCallback) ___lambda215__gtk_widget_delete_event, self, 0);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp78_ = self->window;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object ((GtkWidget*) _tmp78_, "key-press-event", (GCallback) _boxes_app_on_key_pressed_gtk_widget_key_press_event, self, G_CONNECT_AFTER);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp79_ = (ClutterBinLayout*) clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_START, CLUTTER_BIN_ALIGNMENT_START);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp79_);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->stage_bin);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->stage_bin = _tmp79_;
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp80_ = self->stage;
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp81_ = self->stage_bin;
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager ((ClutterActor*) _tmp80_, (ClutterLayoutManager*) _tmp81_);
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp82_ = self->stage;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp82_, "boxes-stage");
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp83_ = (GtkClutterTexture*) gtk_clutter_texture_new ();
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp83_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	background = _tmp83_;
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp84_ = background;
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp84_, "background");
#line 5004 "app.c"
	{
		GdkPixbuf* pixbuf = NULL;
		gchar* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		GdkPixbuf* _tmp87_ = NULL;
		GdkPixbuf* _tmp88_ = NULL;
		GtkClutterTexture* _tmp89_ = NULL;
		GdkPixbuf* _tmp90_ = NULL;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp85_ = boxes_get_style ("assets/boxes-dark.png");
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp86_ = _tmp85_;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp87_ = gdk_pixbuf_new_from_file (_tmp86_, &_inner_error_);
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp88_ = _tmp87_;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp86_);
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		pixbuf = _tmp88_;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 5027 "app.c"
			goto __catch5_g_error;
		}
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp89_ = background;
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp90_ = pixbuf;
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_clutter_texture_set_from_pixbuf (_tmp89_, _tmp90_, &_inner_error_);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (pixbuf);
#line 5040 "app.c"
			goto __catch5_g_error;
		}
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (pixbuf);
#line 5045 "app.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		e = _inner_error_;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (e);
#line 5057 "app.c"
	}
	__finally5:
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (background);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (main_vbox);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (position);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_variant_unref0 (size);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (provider);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 5078 "app.c"
	}
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp91_ = background;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_texture_set_repeat ((ClutterTexture*) _tmp91_, TRUE, TRUE);
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp92_ = background;
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp92_, CLUTTER_ACTOR_ALIGN_FILL);
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp93_ = background;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp93_, CLUTTER_ACTOR_ALIGN_FILL);
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp94_ = background;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp94_, TRUE);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp95_ = background;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp95_, TRUE);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp96_ = self->stage;
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp97_ = background;
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child ((ClutterActor*) _tmp96_, (ClutterActor*) _tmp97_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp98_ = boxes_sidebar_new ();
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->sidebar);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->sidebar = _tmp98_;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp99_ = boxes_collection_view_new ();
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->view);
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->view = _tmp99_;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp100_ = boxes_searchbar_new ();
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->searchbar);
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->searchbar = _tmp100_;
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp101_ = boxes_topbar_new ();
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->topbar);
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->topbar = _tmp101_;
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp102_ = boxes_notificationbar_new ();
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->notificationbar);
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->notificationbar = _tmp102_;
#line 572 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp103_ = boxes_wizard_new ();
#line 572 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->wizard);
#line 572 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->wizard = _tmp103_;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp104_ = boxes_properties_new ();
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->properties);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->properties = _tmp104_;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp105_ = boxes_empty_boxes_new ();
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->empty_boxes);
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->empty_boxes = _tmp105_;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp106_ = clutter_actor_new ();
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp106_);
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	vbox_actor = _tmp106_;
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp107_ = vbox_actor;
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name (_tmp107_, "top-vbox");
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp108_ = (ClutterBoxLayout*) clutter_box_layout_new ();
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp108_);
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	vbox = _tmp108_;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp109_ = vbox_actor;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp110_ = vbox;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager (_tmp109_, (ClutterLayoutManager*) _tmp110_);
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp111_ = vbox;
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_box_layout_set_orientation (_tmp111_, CLUTTER_ORIENTATION_VERTICAL);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp112_ = vbox_actor;
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_align (_tmp112_, CLUTTER_ACTOR_ALIGN_FILL);
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp113_ = vbox_actor;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_align (_tmp113_, CLUTTER_ACTOR_ALIGN_FILL);
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp114_ = vbox_actor;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand (_tmp114_, TRUE);
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp115_ = vbox_actor;
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand (_tmp115_, TRUE);
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp116_ = self->stage;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp117_ = vbox_actor;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child ((ClutterActor*) _tmp116_, _tmp117_);
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp118_ = self->window;
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp119_ = self->topbar;
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp120_ = boxes_topbar_get_widget (_tmp119_);
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp121_ = _tmp120_;
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_set_titlebar ((GtkWindow*) _tmp118_, _tmp121_);
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp122_ = boxes_revealer_new (TRUE);
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp122_);
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->searchbar_revealer);
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->searchbar_revealer = _tmp122_;
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp123_ = self->searchbar_revealer;
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp123_->resize = TRUE;
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp124_ = self->searchbar_revealer;
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_revealer_unreveal (_tmp124_);
#line 593 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp125_ = self->searchbar_revealer;
#line 593 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp125_, "searchbar-revealer");
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp126_ = self->searchbar_revealer;
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp126_, TRUE);
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp127_ = vbox_actor;
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp128_ = self->searchbar_revealer;
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp127_, (ClutterActor*) _tmp128_);
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp129_ = self->searchbar_revealer;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp130_ = self->searchbar;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp131_ = boxes_ui_get_actor ((BoxesUI*) _tmp130_);
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp132_ = _tmp131_;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_container_add ((ClutterContainer*) _tmp129_, _tmp132_, NULL);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp133_ = clutter_actor_new ();
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp133_);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	below_bin_actor = _tmp133_;
#line 599 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp134_ = below_bin_actor;
#line 599 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name (_tmp134_, "below-bin");
#line 600 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp135_ = (ClutterBinLayout*) clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_START, CLUTTER_BIN_ALIGNMENT_START);
#line 600 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp135_);
#line 600 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	below_bin = _tmp135_;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp136_ = below_bin_actor;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp137_ = below_bin;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager (_tmp136_, (ClutterLayoutManager*) _tmp137_);
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp138_ = below_bin_actor;
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand (_tmp138_, TRUE);
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp139_ = below_bin_actor;
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand (_tmp139_, TRUE);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp140_ = vbox_actor;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp141_ = below_bin_actor;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp140_, _tmp141_);
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp142_ = below_bin_actor;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp143_ = self->view;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp144_ = boxes_ui_get_actor ((BoxesUI*) _tmp143_);
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp145_ = _tmp144_;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp142_, _tmp145_);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp146_ = clutter_actor_new ();
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp146_);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	hbox_actor = _tmp146_;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp147_ = hbox_actor;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name (_tmp147_, "top-hbox");
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp148_ = (ClutterBoxLayout*) clutter_box_layout_new ();
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp148_);
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	hbox = _tmp148_;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp149_ = hbox_actor;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp150_ = hbox;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager (_tmp149_, (ClutterLayoutManager*) _tmp150_);
#line 614 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp151_ = hbox_actor;
#line 614 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_align (_tmp151_, CLUTTER_ACTOR_ALIGN_FILL);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp152_ = hbox_actor;
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_align (_tmp152_, CLUTTER_ACTOR_ALIGN_FILL);
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp153_ = hbox_actor;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand (_tmp153_, TRUE);
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp154_ = hbox_actor;
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand (_tmp154_, TRUE);
#line 619 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp155_ = below_bin_actor;
#line 619 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp156_ = hbox_actor;
#line 619 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp155_, _tmp156_);
#line 621 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp157_ = clutter_actor_new ();
#line 621 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp157_);
#line 621 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->overlay_bin_actor);
#line 621 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->overlay_bin_actor = _tmp157_;
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp158_ = self->overlay_bin_actor;
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name (_tmp158_, "overlay-bin");
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp159_ = (ClutterBinLayout*) clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_START, CLUTTER_BIN_ALIGNMENT_START);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp159_);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->overlay_bin);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->overlay_bin = _tmp159_;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp160_ = self->overlay_bin_actor;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp161_ = self->overlay_bin;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager (_tmp160_, (ClutterLayoutManager*) _tmp161_);
#line 626 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp162_ = self->overlay_bin_actor;
#line 626 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_align (_tmp162_, CLUTTER_ACTOR_ALIGN_FILL);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp163_ = self->overlay_bin_actor;
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_align (_tmp163_, CLUTTER_ACTOR_ALIGN_FILL);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp164_ = self->overlay_bin_actor;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand (_tmp164_, TRUE);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp165_ = self->overlay_bin_actor;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand (_tmp165_, TRUE);
#line 630 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp166_ = below_bin_actor;
#line 630 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp167_ = self->overlay_bin_actor;
#line 630 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp166_, _tmp167_);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp168_ = boxes_revealer_new (FALSE);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp168_);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->sidebar_revealer);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->sidebar_revealer = _tmp168_;
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp169_ = self->sidebar_revealer;
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp169_, "sidebar-revealer");
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp170_ = self->sidebar_revealer;
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp170_, TRUE);
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp171_ = hbox_actor;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp172_ = self->sidebar_revealer;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp171_, (ClutterActor*) _tmp172_);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp173_ = self->sidebar_revealer;
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_revealer_unreveal (_tmp173_);
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp174_ = self->sidebar_revealer;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp175_ = self->sidebar;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp176_ = boxes_ui_get_actor ((BoxesUI*) _tmp175_);
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp177_ = _tmp176_;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_container_add ((ClutterContainer*) _tmp174_, _tmp177_, NULL);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp178_ = clutter_actor_new ();
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp178_);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	content_bin_actor = _tmp178_;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp179_ = content_bin_actor;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_name (_tmp179_, "content-bin");
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp180_ = content_bin_actor;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_align (_tmp180_, CLUTTER_ACTOR_ALIGN_FILL);
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp181_ = content_bin_actor;
#line 642 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_align (_tmp181_, CLUTTER_ACTOR_ALIGN_FILL);
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp182_ = content_bin_actor;
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_x_expand (_tmp182_, TRUE);
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp183_ = content_bin_actor;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_y_expand (_tmp183_, TRUE);
#line 645 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp184_ = (ClutterBinLayout*) clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_START, CLUTTER_BIN_ALIGNMENT_START);
#line 645 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp184_);
#line 645 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	content_bin = _tmp184_;
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp185_ = content_bin_actor;
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp186_ = content_bin;
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_layout_manager (_tmp185_, (ClutterLayoutManager*) _tmp186_);
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp187_ = hbox_actor;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp188_ = content_bin_actor;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp187_, _tmp188_);
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp189_ = below_bin_actor;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp190_ = self->notificationbar;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp191_ = boxes_notificationbar_get_actor (_tmp190_);
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp192_ = _tmp191_;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_child (_tmp189_, _tmp192_);
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp193_ = content_bin_actor;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp194_ = self->wizard;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp195_ = boxes_ui_get_actor ((BoxesUI*) _tmp194_);
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp196_ = _tmp195_;
#line 652 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_container_add ((ClutterContainer*) _tmp193_, _tmp196_, NULL);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp197_ = content_bin_actor;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp198_ = self->properties;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp199_ = boxes_ui_get_actor ((BoxesUI*) _tmp198_);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp200_ = _tmp199_;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_container_add ((ClutterContainer*) _tmp197_, _tmp200_, NULL);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp201_ = below_bin_actor;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp202_ = self->empty_boxes;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp203_ = boxes_ui_get_actor ((BoxesUI*) _tmp202_);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp204_ = _tmp203_;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_insert_child_below (_tmp201_, _tmp204_, NULL);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp205_ = self->properties;
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp206_ = boxes_ui_get_actor ((BoxesUI*) _tmp205_);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp207_ = _tmp206_;
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_hide (_tmp207_);
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp208_ = self->empty_boxes;
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp209_ = boxes_ui_get_actor ((BoxesUI*) _tmp208_);
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp210_ = _tmp209_;
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_hide (_tmp210_);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp211_ = main_vbox;
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp211_);
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (content_bin);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (content_bin_actor);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (hbox);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (hbox_actor);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (below_bin);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (below_bin_actor);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (vbox);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (vbox_actor);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (background);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (main_vbox);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_variant_unref0 (position);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_variant_unref0 (size);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (provider);
#line 5558 "app.c"
}


static void boxes_app_set_main_ui_state (BoxesApp* self) {
	GtkNotebook* _tmp0_ = NULL;
#line 664 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->notebook;
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_set (_tmp0_, "page", (gint) BOXES_APP_PAGE_MAIN, NULL);
#line 5570 "app.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data6_;
#line 5579 "app.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 5588 "app.c"
		BoxesApp * self;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data6_->self;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data6_->actor);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block6Data, _data6_);
#line 5598 "app.c"
	}
}


static gboolean __lambda227_ (BoxesApp* self) {
	gboolean result = FALSE;
	BoxesCollectionItem* _tmp0_ = NULL;
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->current_item;
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_position_item_actor_at_icon (self, _tmp0_);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5614 "app.c"
}


static gboolean ___lambda227__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda227_ (self);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5623 "app.c"
}


static void __lambda226_ (BoxesApp* self, GtkAllocation* allocation) {
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (allocation != NULL);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda227__gsource_func, g_object_ref (self), g_object_unref);
#line 5632 "app.c"
}


static void ___lambda226__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda226_ (self, allocation);
#line 5639 "app.c"
}


static void __lambda228_ (Block6Data* _data6_) {
	BoxesApp * self;
	ClutterActor* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	GdMainView* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	BoxesApp* _tmp4_ = NULL;
	BoxesUIState _tmp5_ = 0;
	BoxesUIState _tmp6_ = 0;
	gboolean _tmp12_ = FALSE;
#line 688 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data6_->self;
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data6_->actor;
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_remove_transition (_tmp0_, "animate-position");
#line 690 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->view;
#line 690 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->main_view;
#line 690 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_handler_disconnect ((GObject*) _tmp2_, _data6_->id);
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = boxes_app_app;
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp4_);
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ == BOXES_UI_STATE_COLLECTION) {
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = TRUE;
#line 5675 "app.c"
	} else {
		BoxesApp* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
		ClutterActor* _tmp9_ = NULL;
		ClutterActor* _tmp10_ = NULL;
		ClutterActor* _tmp11_ = NULL;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = boxes_app_app;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _tmp7_->current_item;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = boxes_ui_get_actor ((BoxesUI*) _tmp8_);
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = _tmp9_;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = _data6_->actor;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = _tmp10_ != _tmp11_;
#line 5694 "app.c"
	}
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = _tmp3_;
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp12_) {
#line 5700 "app.c"
		ClutterActor* _tmp13_ = NULL;
#line 693 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _data6_->actor;
#line 693 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_actor_remove (_tmp13_);
#line 5706 "app.c"
	}
}


static void ___lambda228__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self) {
#line 688 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda228_ (self);
#line 5714 "app.c"
}


static void boxes_app_position_item_actor_at_icon (BoxesApp* self, BoxesCollectionItem* item) {
	Block6Data* _data6_;
	gfloat item_x = 0.0F;
	gfloat item_y = 0.0F;
	BoxesCollectionView* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	gfloat _tmp2_ = 0.0F;
	gfloat _tmp3_ = 0.0F;
	BoxesCollectionItem* _tmp4_ = NULL;
	ClutterActor* _tmp5_ = NULL;
	ClutterActor* _tmp6_ = NULL;
	ClutterActor* _tmp7_ = NULL;
	ClutterTransition* transition = NULL;
	ClutterActor* _tmp8_ = NULL;
	ClutterTransition* _tmp9_ = NULL;
	ClutterTransition* _tmp10_ = NULL;
	ClutterTransition* _tmp11_ = NULL;
	gfloat _tmp13_ = 0.0F;
	gfloat _tmp14_ = 0.0F;
	ClutterTransition* _tmp15_ = NULL;
	BoxesCollectionView* _tmp16_ = NULL;
	GdMainView* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	ClutterTransition* _tmp19_ = NULL;
	ClutterActor* _tmp20_ = NULL;
	ClutterTransition* _tmp21_ = NULL;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->_ref_count_ = 1;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->self = g_object_ref (self);
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = item;
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_get_item_pos (_tmp0_, _tmp1_, &_tmp2_, &_tmp3_);
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	item_x = _tmp2_;
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	item_y = _tmp3_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = item;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_ui_get_actor ((BoxesUI*) _tmp4_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->actor = _tmp7_;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = _data6_->actor;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = clutter_actor_get_transition (_tmp8_, "animate-position");
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	transition = _tmp10_;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = transition;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp11_ != NULL) {
#line 5786 "app.c"
		ClutterActor* _tmp12_ = NULL;
#line 675 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _data6_->actor;
#line 675 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		clutter_actor_remove_transition (_tmp12_, "animate-position");
#line 5792 "app.c"
	}
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = item_x;
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = item_y;
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = boxes_animate_actor_geometry (_tmp13_, _tmp14_, (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, (gfloat) BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (transition);
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	transition = _tmp15_;
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = self->view;
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = _tmp16_->main_view;
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_signal_connect_object ((GtkWidget*) _tmp17_, "size-allocate", (GCallback) ___lambda226__gtk_widget_size_allocate, self, 0);
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->id = _tmp18_;
#line 688 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = transition;
#line 688 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_data ((ClutterTimeline*) _tmp19_, "completed", (GCallback) ___lambda228__clutter_timeline_completed, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = _data6_->actor;
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = transition;
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_add_transition (_tmp20_, "animate-position", _tmp21_);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (transition);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block6_data_unref (_data6_);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_ = NULL;
#line 5828 "app.c"
}


static void boxes_app_real_ui_state_changed (BoxesUI* base) {
	BoxesApp * self;
	BoxesSidebar* _tmp0_ = NULL;
	BoxesUI* _tmp1_ = NULL;
	BoxesSearchbar* _tmp2_ = NULL;
	BoxesUI* _tmp3_ = NULL;
	BoxesTopbar* _tmp4_ = NULL;
	BoxesUI* _tmp5_ = NULL;
	BoxesCollectionView* _tmp6_ = NULL;
	BoxesUI* _tmp7_ = NULL;
	BoxesProperties* _tmp8_ = NULL;
	BoxesUI* _tmp9_ = NULL;
	BoxesWizard* _tmp10_ = NULL;
	BoxesUI* _tmp11_ = NULL;
	BoxesEmptyBoxes* _tmp12_ = NULL;
	BoxesUI* _tmp13_ = NULL;
	BoxesUI** _tmp14_ = NULL;
	BoxesUIState _tmp19_ = 0;
	BoxesUIState _tmp20_ = 0;
	BoxesUIState _tmp21_ = 0;
	BoxesUIState _tmp22_ = 0;
	BoxesUIState _tmp24_ = 0;
	BoxesUIState _tmp25_ = 0;
	BoxesCollectionItem* _tmp60_ = NULL;
#line 698 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->sidebar;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 ((BoxesUI*) _tmp0_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->searchbar;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _g_object_ref0 ((BoxesUI*) _tmp2_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = self->topbar;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _g_object_ref0 ((BoxesUI*) _tmp4_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = self->view;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _g_object_ref0 ((BoxesUI*) _tmp6_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = self->properties;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _g_object_ref0 ((BoxesUI*) _tmp8_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = self->wizard;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = _g_object_ref0 ((BoxesUI*) _tmp10_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = self->empty_boxes;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = _g_object_ref0 ((BoxesUI*) _tmp12_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = g_new0 (BoxesUI*, 7 + 1);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[0] = _tmp1_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[1] = _tmp3_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[2] = _tmp5_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[3] = _tmp7_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[4] = _tmp9_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[5] = _tmp11_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_[6] = _tmp13_;
#line 5902 "app.c"
	{
		BoxesUI** ui_collection = NULL;
		gint ui_collection_length1 = 0;
		gint _ui_collection_size_ = 0;
		gint ui_it = 0;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		ui_collection = _tmp14_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		ui_collection_length1 = 7;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (ui_it = 0; ui_it < 7; ui_it = ui_it + 1) {
#line 5914 "app.c"
			BoxesUI* _tmp15_ = NULL;
			BoxesUI* ui = NULL;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = _g_object_ref0 (ui_collection[ui_it]);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			ui = _tmp15_;
#line 5921 "app.c"
			{
				BoxesUI* _tmp16_ = NULL;
				BoxesUIState _tmp17_ = 0;
				BoxesUIState _tmp18_ = 0;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp16_ = ui;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp17_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp18_ = _tmp17_;
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_ui_set_ui_state (_tmp16_, _tmp18_);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (ui);
#line 5936 "app.c"
			}
		}
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		ui_collection = (_vala_array_free (ui_collection, ui_collection_length1, (GDestroyNotify) g_object_unref), NULL);
#line 5941 "app.c"
	}
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = _tmp19_;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp20_ != BOXES_UI_STATE_DISPLAY) {
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_main_ui_state (self);
#line 5951 "app.c"
	}
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = _tmp21_;
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp22_ != BOXES_UI_STATE_COLLECTION) {
#line 5959 "app.c"
		BoxesRevealer* _tmp23_ = NULL;
#line 709 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = self->searchbar_revealer;
#line 709 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_revealer_set_revealed (_tmp23_, FALSE);
#line 5965 "app.c"
	}
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = _tmp24_;
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_tmp25_) {
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 5975 "app.c"
		{
			BoxesTopbar* _tmp26_ = NULL;
			BoxesCollectionItem* _tmp27_ = NULL;
			BoxesCollectionView* _tmp36_ = NULL;
			BoxesRevealer* _tmp37_ = NULL;
			BoxesSearchbar* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			gboolean _tmp40_ = FALSE;
			BoxesCollectionItem* _tmp41_ = NULL;
#line 713 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp26_ = self->topbar;
#line 713 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_topbar_set_status (_tmp26_, NULL);
#line 714 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (self->priv->status_bind);
#line 714 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			self->priv->status_bind = NULL;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = self->current_item;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, BOXES_TYPE_MACHINE)) {
#line 5997 "app.c"
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp28_ = NULL;
				BoxesMachine* _tmp29_ = NULL;
				gulong _tmp30_ = 0UL;
				BoxesMachine* _tmp33_ = NULL;
				GCancellable* _tmp34_ = NULL;
				GCancellable* _tmp35_ = NULL;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp28_ = self->current_item;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp29_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp28_) : NULL);
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp29_;
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp30_ = self->priv->got_error_id;
#line 717 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp30_ != ((gulong) 0)) {
#line 6015 "app.c"
					BoxesMachine* _tmp31_ = NULL;
					gulong _tmp32_ = 0UL;
#line 718 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp31_ = machine;
#line 718 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp32_ = self->priv->got_error_id;
#line 718 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					g_signal_handler_disconnect ((GObject*) _tmp31_, _tmp32_);
#line 719 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					self->priv->got_error_id = (gulong) 0;
#line 6026 "app.c"
				}
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp33_ = machine;
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp34_ = boxes_machine_get_connecting_cancellable (_tmp33_);
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp35_ = _tmp34_;
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				g_cancellable_cancel (_tmp35_);
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 6038 "app.c"
			}
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_set_fullscreen (self, FALSE);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp36_ = self->view;
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_collection_view_set_visible (_tmp36_, TRUE);
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp37_ = self->searchbar_revealer;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp38_ = self->searchbar;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp39_ = boxes_searchbar_get_visible (_tmp38_);
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp40_ = _tmp39_;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_revealer_set_revealed (_tmp37_, _tmp40_);
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp41_ = self->current_item;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp41_ != NULL) {
#line 6060 "app.c"
				ClutterActor* actor = NULL;
				BoxesCollectionItem* _tmp42_ = NULL;
				ClutterActor* _tmp43_ = NULL;
				ClutterActor* _tmp44_ = NULL;
				ClutterActor* _tmp45_ = NULL;
				ClutterActor* _tmp46_ = NULL;
				BoxesCollectionItem* _tmp47_ = NULL;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp42_ = self->current_item;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp43_ = boxes_ui_get_actor ((BoxesUI*) _tmp42_);
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp44_ = _tmp43_;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp45_ = _g_object_ref0 (_tmp44_);
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				actor = _tmp45_;
#line 732 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp46_ = actor;
#line 732 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				clutter_actor_show (_tmp46_);
#line 733 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp47_ = self->current_item;
#line 733 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_position_item_actor_at_icon (self, _tmp47_);
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (actor);
#line 6088 "app.c"
			}
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6092 "app.c"
		}
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_UI_STATE_CREDS:
#line 6096 "app.c"
		{
#line 739 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6100 "app.c"
		}
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_UI_STATE_WIZARD:
#line 6104 "app.c"
		{
			BoxesCollectionItem* _tmp48_ = NULL;
#line 742 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp48_ = self->current_item;
#line 742 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp48_ != NULL) {
#line 6111 "app.c"
				BoxesCollectionItem* _tmp49_ = NULL;
				ClutterActor* _tmp50_ = NULL;
				ClutterActor* _tmp51_ = NULL;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp49_ = self->current_item;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp50_ = boxes_ui_get_actor ((BoxesUI*) _tmp49_);
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp51_ = _tmp50_;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_actor_remove (_tmp51_);
#line 6123 "app.c"
			}
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6127 "app.c"
		}
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 6131 "app.c"
		{
			BoxesCollectionItem* _tmp52_ = NULL;
			ClutterActor* _tmp53_ = NULL;
			ClutterActor* _tmp54_ = NULL;
#line 747 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp52_ = self->current_item;
#line 747 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp53_ = boxes_ui_get_actor ((BoxesUI*) _tmp52_);
#line 747 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp54_ = _tmp53_;
#line 747 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			clutter_actor_hide (_tmp54_);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6146 "app.c"
		}
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 6150 "app.c"
		{
#line 751 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6154 "app.c"
		}
		default:
		{
			BoxesUIState _tmp55_ = 0;
			BoxesUIState _tmp56_ = 0;
			GEnumValue* _tmp57_;
			gchar* _tmp58_ = NULL;
			gchar* _tmp59_ = NULL;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp55_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp56_ = _tmp55_;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp57_ = g_enum_get_value (g_type_class_ref (BOXES_TYPE_UI_STATE), _tmp56_);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp58_ = g_strdup_printf ("Unhandled UI state %s", (_tmp57_ != NULL) ? _tmp57_->value_name : NULL);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp59_ = _tmp58_;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_warning ("app.vala:754: %s", _tmp59_);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp59_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6179 "app.c"
		}
	}
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp60_ = self->current_item;
#line 758 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp60_ != NULL) {
#line 6186 "app.c"
		BoxesCollectionItem* _tmp61_ = NULL;
		BoxesUIState _tmp62_ = 0;
		BoxesUIState _tmp63_ = 0;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp61_ = self->current_item;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp62_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp63_ = _tmp62_;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_ui_state ((BoxesUI*) _tmp61_, _tmp63_);
#line 6198 "app.c"
	}
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data7_;
#line 6208 "app.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 6217 "app.c"
		BoxesApp * self;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data7_->self;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block7Data, _data7_);
#line 6225 "app.c"
	}
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data8_;
#line 6235 "app.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 6244 "app.c"
		BoxesApp * self;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data8_->_data7_->self;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data8_->machine);
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block7_data_unref (_data8_->_data7_);
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data8_->_data7_ = NULL;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block8Data, _data8_);
#line 6256 "app.c"
	}
}


static void ______lambda229_ (Block8Data* _data8_) {
	Block7Data* _data7_;
	BoxesApp * self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_ = _data8_->_data7_;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data7_->self;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data8_->machine;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:784: %s suspended", _tmp2_);
#line 785 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _data7_->waiting_counter;
#line 785 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_->waiting_counter = _tmp3_ - 1;
#line 6284 "app.c"
}


static void _______lambda229__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	______lambda229_ (self);
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block8_data_unref (self);
#line 6293 "app.c"
}


void boxes_app_suspend_machines (BoxesApp* self) {
	Block7Data* _data7_;
	BoxesCollection* _tmp0_ = NULL;
	GMainContext* context = NULL;
	GMainContext* _tmp1_ = NULL;
	GMainContext* _tmp2_ = NULL;
	BoxesCollection* _tmp3_ = NULL;
	GPtrArray* _tmp4_ = NULL;
	gpointer* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GMainContext* _tmp14_ = NULL;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_->_ref_count_ = 1;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_->self = g_object_ref (self);
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_ == NULL) {
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block7_data_unref (_data7_);
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data7_ = NULL;
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 6326 "app.c"
	}
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:768: Suspending running boxes");
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_->waiting_counter = 0;
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_main_context_new ();
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	context = _tmp1_;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = context;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_push_thread_default (_tmp2_);
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = self->collection;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->items;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_->pdata;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5__length1 = (gint) _tmp4_->len;
#line 6348 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp5_;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp5__length1;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp5__length1; item_it = item_it + 1) {
#line 6360 "app.c"
			BoxesCollectionItem* _tmp6_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp6_ = _g_object_ref0 (item_collection[item_it]);
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp6_;
#line 6367 "app.c"
			{
				BoxesCollectionItem* _tmp7_ = NULL;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = item;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 6374 "app.c"
					Block8Data* _data8_;
					BoxesCollectionItem* _tmp8_ = NULL;
					BoxesLibvirtMachine* _tmp9_ = NULL;
					BoxesLibvirtMachine* _tmp10_ = NULL;
					gboolean _tmp11_ = FALSE;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data8_ = g_slice_new0 (Block8Data);
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data8_->_ref_count_ = 1;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data8_->_data7_ = block7_data_ref (_data7_);
#line 779 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp8_ = item;
#line 779 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp8_) : NULL);
#line 779 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data8_->machine = _tmp9_;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp10_ = _data8_->machine;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp11_ = ((BoxesMachine*) _tmp10_)->suspend_at_exit;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					if (_tmp11_) {
#line 6398 "app.c"
						gint _tmp12_ = 0;
						BoxesLibvirtMachine* _tmp13_ = NULL;
#line 782 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp12_ = _data7_->waiting_counter;
#line 782 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						_data7_->waiting_counter = _tmp12_ + 1;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp13_ = _data8_->machine;
#line 783 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
						boxes_libvirt_machine_suspend (_tmp13_, _______lambda229__gasync_ready_callback, block8_data_ref (_data8_));
#line 6409 "app.c"
					}
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					block8_data_unref (_data8_);
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_data8_ = NULL;
#line 6415 "app.c"
				}
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 6419 "app.c"
			}
		}
	}
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = context;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_pop_thread_default (_tmp14_);
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	while (TRUE) {
#line 6429 "app.c"
		gint _tmp15_ = 0;
		GMainContext* _tmp16_ = NULL;
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = _data7_->waiting_counter;
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (!(_tmp15_ > 0)) {
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 6438 "app.c"
		}
#line 794 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = context;
#line 794 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_main_context_iteration (_tmp16_, TRUE);
#line 6444 "app.c"
	}
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:796: Running boxes suspended");
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_main_context_unref0 (context);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block7_data_unref (_data7_);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_ = NULL;
#line 6454 "app.c"
}


gboolean boxes_app_quit (BoxesApp* self) {
	gboolean result = FALSE;
	BoxesNotificationbar* _tmp0_ = NULL;
	BoxesWizard* _tmp1_ = NULL;
	GtkApplicationWindow* _tmp2_ = NULL;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 800 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->notificationbar;
#line 800 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_notificationbar_cancel (_tmp0_);
#line 801 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_save_window_geometry (self);
#line 802 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->wizard;
#line 802 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_wizard_cleanup (_tmp1_);
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->window;
#line 803 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp2_);
#line 805 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 805 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6483 "app.c"
}


void boxes_app_show_properties (BoxesApp* self) {
	GList* selected_items = NULL;
	BoxesCollectionView* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 821 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_view_get_selected_items (_tmp0_);
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = _tmp1_;
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_set_selection_mode (self, FALSE);
#line 6501 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 827 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = selected_items;
#line 827 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 6509 "app.c"
			BoxesCollectionItem* _tmp2_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 827 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp2_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 827 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp2_;
#line 6516 "app.c"
			{
				BoxesCollectionItem* _tmp3_ = NULL;
				BoxesCollectionItem* _tmp4_ = NULL;
#line 828 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = item;
#line 828 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = _g_object_ref0 (_tmp3_);
#line 828 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (self->current_item);
#line 828 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				self->current_item = _tmp4_;
#line 829 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 830 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 830 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 6534 "app.c"
			}
		}
	}
#line 821 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 6540 "app.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data9_;
#line 6549 "app.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 6558 "app.c"
		BoxesApp * self;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data9_->self;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data9_->selected_items);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block9Data, _data9_);
#line 6568 "app.c"
	}
}


static void __lambda175_ (Block9Data* _data9_) {
	BoxesApp * self;
	GList* _tmp0_ = NULL;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data9_->self;
#line 850 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:850: Box deletion cancelled by user, re-adding to view");
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data9_->selected_items;
#line 6582 "app.c"
	{
		GList* selected_collection = NULL;
		GList* selected_it = NULL;
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		selected_collection = _tmp0_;
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (selected_it = selected_collection; selected_it != NULL; selected_it = selected_it->next) {
#line 6590 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* selected = NULL;
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) selected_it->data);
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			selected = _tmp1_;
#line 6597 "app.c"
			{
				BoxesCollection* _tmp2_ = NULL;
				BoxesCollectionItem* _tmp3_ = NULL;
#line 852 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = self->collection;
#line 852 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = selected;
#line 852 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_add_item (_tmp2_, _tmp3_);
#line 851 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (selected);
#line 6609 "app.c"
			}
		}
	}
}


static void ___lambda175__boxes_notificationbar_ok_func (gpointer self) {
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda175_ (self);
#line 6619 "app.c"
}


static void __lambda176_ (Block9Data* _data9_) {
	BoxesApp * self;
	GList* _tmp0_ = NULL;
#line 856 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data9_->self;
#line 857 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:857: Box deletion, deleting now");
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data9_->selected_items;
#line 6632 "app.c"
	{
		GList* selected_collection = NULL;
		GList* selected_it = NULL;
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		selected_collection = _tmp0_;
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (selected_it = selected_collection; selected_it != NULL; selected_it = selected_it->next) {
#line 6640 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* selected = NULL;
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) selected_it->data);
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			selected = _tmp1_;
#line 6647 "app.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp2_ = NULL;
				BoxesMachine* _tmp3_ = NULL;
				BoxesMachine* _tmp4_ = NULL;
#line 859 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = selected;
#line 859 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 859 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp3_;
#line 861 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = machine;
#line 861 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp4_ != NULL) {
#line 6663 "app.c"
					BoxesMachine* _tmp5_ = NULL;
#line 862 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp5_ = machine;
#line 862 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_machine_delete (_tmp5_, TRUE);
#line 6669 "app.c"
				}
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 858 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (selected);
#line 6675 "app.c"
			}
		}
	}
}


static void ___lambda176__boxes_notificationbar_cancel_func (gpointer self) {
#line 856 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda176_ (self);
#line 6685 "app.c"
}


void boxes_app_remove_selected_items (BoxesApp* self) {
	Block9Data* _data9_;
	BoxesCollectionView* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	guint num_selected = 0U;
	GList* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	gchar* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	gchar* message = NULL;
	const gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	GList* _tmp19_ = NULL;
	BoxesNotificationbarOKFunc undo = NULL;
	void* undo_target = NULL;
	GDestroyNotify undo_target_destroy_notify = NULL;
	BoxesNotificationbarCancelFunc really_remove = NULL;
	void* really_remove_target = NULL;
	GDestroyNotify really_remove_target_destroy_notify = NULL;
	BoxesNotificationbar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	BoxesNotificationbarOKFunc _tmp25_ = NULL;
	void* _tmp25__target = NULL;
	GDestroyNotify _tmp25__target_destroy_notify = NULL;
	BoxesNotificationbarCancelFunc _tmp26_ = NULL;
	void* _tmp26__target = NULL;
	GDestroyNotify _tmp26__target_destroy_notify = NULL;
	GdNotification* _tmp27_ = NULL;
	GdNotification* _tmp28_ = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data9_->_ref_count_ = 1;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data9_->self = g_object_ref (self);
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_view_get_selected_items (_tmp0_);
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data9_->selected_items = _tmp1_;
#line 836 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data9_->selected_items;
#line 836 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_list_length (_tmp2_);
#line 836 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	num_selected = _tmp3_;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = num_selected;
#line 837 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp4_ == ((guint) 0)) {
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		block9_data_unref (_data9_);
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_data9_ = NULL;
#line 838 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 6749 "app.c"
	}
#line 840 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_set_selection_mode (self, FALSE);
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = num_selected;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ == ((guint) 1)) {
#line 6757 "app.c"
		const gchar* _tmp7_ = NULL;
		GList* _tmp8_ = NULL;
		gconstpointer _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _ ("Box '%s' has been deleted");
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _data9_->selected_items;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = _tmp8_->data;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp9_);
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = _tmp10_;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = g_strdup_printf (_tmp7_, _tmp11_);
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp5_);
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = _tmp12_;
#line 6780 "app.c"
	} else {
		guint _tmp13_ = 0U;
		const gchar* _tmp14_ = NULL;
		guint _tmp15_ = 0U;
		gchar* _tmp16_ = NULL;
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = num_selected;
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = ngettext ("%u box has been deleted", "%u boxes have been deleted", (gulong) _tmp13_);
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = num_selected;
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = g_strdup_printf (_tmp14_, _tmp15_);
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp5_);
#line 843 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = _tmp16_;
#line 6798 "app.c"
	}
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = _tmp5_;
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_strdup (_tmp17_);
#line 842 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	message = _tmp18_;
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = _data9_->selected_items;
#line 6808 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp19_;
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 6816 "app.c"
			BoxesCollectionItem* _tmp20_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp20_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp20_;
#line 6823 "app.c"
			{
				BoxesCollection* _tmp21_ = NULL;
				BoxesCollectionItem* _tmp22_ = NULL;
#line 847 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp21_ = self->collection;
#line 847 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp22_ = item;
#line 847 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_remove_item (_tmp21_, _tmp22_);
#line 846 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 6835 "app.c"
			}
		}
	}
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo = ___lambda175__boxes_notificationbar_ok_func;
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = block9_data_ref (_data9_);
#line 849 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = block9_data_unref;
#line 856 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = ___lambda176__boxes_notificationbar_cancel_func;
#line 856 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = block9_data_ref (_data9_);
#line 856 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = block9_data_unref;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = self->notificationbar;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = message;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = undo;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25__target = undo_target;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25__target_destroy_notify = undo_target_destroy_notify;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = really_remove;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26__target = really_remove_target;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26__target_destroy_notify = really_remove_target_destroy_notify;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = boxes_notificationbar_display_for_action (_tmp23_, _tmp24_, "_Undo", _tmp25_, _tmp25__target, _tmp25__target_destroy_notify, _tmp26_, _tmp26__target, _tmp26__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp28_ = _tmp27_;
#line 866 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp28_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	(really_remove_target_destroy_notify == NULL) ? NULL : (really_remove_target_destroy_notify (really_remove_target), NULL);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	(undo_target_destroy_notify == NULL) ? NULL : (undo_target_destroy_notify (undo_target), NULL);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (message);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp5_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block9_data_unref (_data9_);
#line 834 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data9_ = NULL;
#line 6901 "app.c"
}


static gboolean boxes_app_on_key_pressed (BoxesApp* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkModifierType default_modifiers = 0;
	GdkModifierType _tmp0_ = 0;
	GdkEventKey _tmp1_ = {0};
	guint _tmp2_ = 0U;
#line 869 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 869 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 869 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = gtk_accelerator_get_default_mod_mask ();
#line 870 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	default_modifiers = _tmp0_;
#line 872 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = *event;
#line 872 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_.keyval;
#line 872 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ == ((guint) GDK_KEY_F11)) {
#line 6927 "app.c"
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = boxes_app_get_fullscreen (self);
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_;
#line 873 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_fullscreen (self, !_tmp4_);
#line 874 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		result = TRUE;
#line 874 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 6940 "app.c"
	} else {
		GdkEventKey _tmp5_ = {0};
		guint _tmp6_ = 0U;
#line 875 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = *event;
#line 875 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = _tmp5_.keyval;
#line 875 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp6_ == ((guint) GDK_KEY_Escape)) {
#line 6950 "app.c"
			gboolean _tmp7_ = FALSE;
			gboolean _tmp8_ = FALSE;
			gboolean _tmp9_ = FALSE;
			gboolean _tmp12_ = FALSE;
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = boxes_app_get_selection_mode (self);
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = _tmp8_;
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp9_) {
#line 6961 "app.c"
				BoxesUIState _tmp10_ = 0;
				BoxesUIState _tmp11_ = 0;
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp10_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp11_ = _tmp10_;
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = _tmp11_ == BOXES_UI_STATE_COLLECTION;
#line 6970 "app.c"
			} else {
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = FALSE;
#line 6974 "app.c"
			}
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = _tmp7_;
#line 876 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp12_) {
#line 877 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_set_selection_mode (self, FALSE);
#line 6982 "app.c"
			}
		} else {
			gboolean _tmp13_ = FALSE;
			GdkEventKey _tmp14_ = {0};
			guint _tmp15_ = 0U;
			gboolean _tmp19_ = FALSE;
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = *event;
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = _tmp14_.keyval;
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp15_ == ((guint) GDK_KEY_q)) {
#line 6995 "app.c"
				GdkEventKey _tmp16_ = {0};
				GdkModifierType _tmp17_ = 0;
				GdkModifierType _tmp18_ = 0;
#line 879 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp16_ = *event;
#line 879 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp17_ = _tmp16_.state;
#line 879 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp18_ = default_modifiers;
#line 879 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp13_ = (_tmp17_ & _tmp18_) == GDK_CONTROL_MASK;
#line 7007 "app.c"
			} else {
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp13_ = FALSE;
#line 7011 "app.c"
			}
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = _tmp13_;
#line 878 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp19_) {
#line 880 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_quit (self);
#line 881 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				result = TRUE;
#line 881 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				return result;
#line 7023 "app.c"
			} else {
				gboolean _tmp20_ = FALSE;
				GdkEventKey _tmp21_ = {0};
				guint _tmp22_ = 0U;
				gboolean _tmp26_ = FALSE;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp21_ = *event;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp22_ = _tmp21_.keyval;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp22_ == ((guint) GDK_KEY_a)) {
#line 7035 "app.c"
					GdkEventKey _tmp23_ = {0};
					GdkModifierType _tmp24_ = 0;
					GdkModifierType _tmp25_ = 0;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp23_ = *event;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp24_ = _tmp23_.state;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp25_ = default_modifiers;
#line 883 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp20_ = (_tmp24_ & _tmp25_) == GDK_MOD1_MASK;
#line 7047 "app.c"
				} else {
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp20_ = FALSE;
#line 7051 "app.c"
				}
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp26_ = _tmp20_;
#line 882 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp26_) {
#line 884 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_app_quit (self);
#line 885 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					result = TRUE;
#line 885 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
					return result;
#line 7063 "app.c"
				}
			}
		}
	}
#line 888 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 888 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7072 "app.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return _data10_;
#line 7081 "app.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 7090 "app.c"
		BoxesApp * self;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data10_->self;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data10_->machine);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block10Data, _data10_);
#line 7100 "app.c"
	}
}


static void __lambda85_ (BoxesApp* self, const gchar* message) {
	BoxesApp* _tmp0_ = NULL;
	BoxesNotificationbar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GdNotification* _tmp4_ = NULL;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (message != NULL);
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_app;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->notificationbar;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = message;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_notificationbar_display_error (_tmp1_, _tmp2_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 912 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp4_);
#line 7125 "app.c"
}


static void ___lambda85__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self) {
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda85_ (self, message);
#line 7132 "app.c"
}


static void ____lambda87_ (Block10Data* _data10_) {
	BoxesApp * self;
	BoxesMachine* _tmp0_ = NULL;
	gfloat _tmp1_ = 0.0F;
	gfloat _tmp2_ = 0.0F;
	BoxesMachineConnectFlags _tmp3_ = 0;
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data10_->self;
#line 935 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data10_->machine;
#line 935 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data10_->x;
#line 935 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data10_->y;
#line 935 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _data10_->flags;
#line 935 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_connect_to (self, _tmp0_, _tmp1_, _tmp2_, _tmp3_ | BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE);
#line 7154 "app.c"
}


static void _____lambda87__boxes_notificationbar_ok_func (gpointer self) {
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	____lambda87_ (self);
#line 7161 "app.c"
}


static void __lambda86_ (Block10Data* _data10_, GObject* obj, GAsyncResult* res) {
	BoxesApp * self;
	GError * _inner_error_ = NULL;
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data10_->self;
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (res != NULL);
#line 7172 "app.c"
	{
		BoxesMachine* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		gboolean _tmp3_ = FALSE;
#line 921 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = _data10_->machine;
#line 921 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp1_ = res;
#line 921 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_machine_connect_display_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 921 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_inner_error_ != NULL) {
#line 7186 "app.c"
			goto __catch6_g_error;
		}
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = boxes_app_get_maximized (self);
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = _tmp2_;
#line 923 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp3_) {
#line 924 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_set_fullscreen (self, TRUE);
#line 7197 "app.c"
		}
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesNotificationbar* bar = NULL;
		BoxesApp* _tmp6_ = NULL;
		BoxesNotificationbar* _tmp7_ = NULL;
		BoxesNotificationbar* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		GError* _tmp10_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		e = _inner_error_;
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 926 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 927 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = e;
#line 927 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = _tmp4_->message;
#line 927 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_debug ("app.vala:927: connect display failed: %s", _tmp5_);
#line 928 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = boxes_app_app;
#line 928 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _tmp6_->notificationbar;
#line 928 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 928 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		bar = _tmp8_;
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = e;
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (g_error_matches (_tmp10_, BOXES_ERROR, BOXES_ERROR_RESTORE_FAILED)) {
#line 7237 "app.c"
			BoxesMachineConnectFlags _tmp11_ = 0;
#line 931 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = _data10_->flags;
#line 931 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = !((_tmp11_ & BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) == BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE);
#line 7243 "app.c"
		} else {
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = FALSE;
#line 7247 "app.c"
		}
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _tmp9_;
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp12_) {
#line 7253 "app.c"
			gchar* message = NULL;
			const gchar* _tmp13_ = NULL;
			BoxesMachine* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			BoxesNotificationbar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			GdNotification* _tmp21_ = NULL;
			GdNotification* _tmp22_ = NULL;
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = _ ("'%s' could not be restored from disk\nTry without saved state?");
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = _data10_->machine;
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp14_);
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = _tmp15_;
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp17_ = g_strdup_printf (_tmp13_, _tmp16_);
#line 932 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			message = _tmp17_;
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp18_ = bar;
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = message;
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp20_ = _ ("Restart");
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp21_ = boxes_notificationbar_display_for_action (_tmp18_, _tmp19_, _tmp20_, _____lambda87__boxes_notificationbar_ok_func, block10_data_ref (_data10_), block10_data_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp22_ = _tmp21_;
#line 934 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_tmp22_);
#line 930 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (message);
#line 7291 "app.c"
		} else {
			BoxesNotificationbar* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			BoxesMachine* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			GdNotification* _tmp30_ = NULL;
			GdNotification* _tmp31_ = NULL;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp23_ = bar;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp24_ = _ ("Connection to '%s' failed");
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = _data10_->machine;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp26_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp25_);
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = _tmp26_;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp28_ = g_strdup_printf (_tmp24_, _tmp27_);
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp29_ = _tmp28_;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp30_ = boxes_notificationbar_display_error (_tmp23_, _tmp29_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp31_ = _tmp30_;
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_tmp31_);
#line 939 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp29_);
#line 7324 "app.c"
		}
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (bar);
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (e);
#line 7330 "app.c"
	}
	__finally6:
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_inner_error_ != NULL) {
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 920 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 7341 "app.c"
	}
}


static void ___lambda86__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda86_ (self, source_object, res);
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block10_data_unref (self);
#line 7351 "app.c"
}


void boxes_app_connect_to (BoxesApp* self, BoxesMachine* machine, gfloat x, gfloat y, BoxesMachineConnectFlags flags) {
	Block10Data* _data10_;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	gfloat _tmp2_ = 0.0F;
	gfloat _tmp3_ = 0.0F;
	BoxesMachineConnectFlags _tmp4_ = 0;
	BoxesMachine* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp6_ = NULL;
	ClutterActor* actor = NULL;
	BoxesMachine* _tmp7_ = NULL;
	ClutterActor* _tmp8_ = NULL;
	ClutterActor* _tmp9_ = NULL;
	ClutterActor* _tmp10_ = NULL;
	ClutterActor* _tmp11_ = NULL;
	ClutterActor* _tmp12_ = NULL;
	ClutterActor* _tmp19_ = NULL;
	ClutterActor* _tmp20_ = NULL;
	ClutterActor* _tmp21_ = NULL;
	ClutterActor* _tmp22_ = NULL;
	ClutterActor* _tmp23_ = NULL;
	ClutterActor* _tmp24_ = NULL;
	BoxesApp* _tmp25_ = NULL;
	guint _tmp26_ = 0U;
	BoxesMachine* _tmp27_ = NULL;
	BoxesTopbar* _tmp28_ = NULL;
	GBinding* _tmp29_ = NULL;
	GBinding* _tmp30_ = NULL;
	BoxesMachine* _tmp31_ = NULL;
	gulong _tmp32_ = 0UL;
	BoxesMachine* _tmp33_ = NULL;
	BoxesMachineConnectFlags _tmp34_ = 0;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->_ref_count_ = 1;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->self = g_object_ref (self);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data10_->machine);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->machine = _tmp1_;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = x;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->x = _tmp2_;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = y;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->y = _tmp3_;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = flags;
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->flags = _tmp4_;
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _data10_->machine;
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _g_object_ref0 ((BoxesCollectionItem*) _tmp5_);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->current_item);
#line 892 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->current_item = _tmp6_;
#line 895 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _data10_->machine;
#line 895 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = boxes_ui_get_actor ((BoxesUI*) _tmp7_);
#line 895 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _tmp8_;
#line 895 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 895 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	actor = _tmp10_;
#line 896 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = actor;
#line 896 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = clutter_actor_get_parent (_tmp11_);
#line 896 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp12_ == NULL) {
#line 7441 "app.c"
		BoxesApp* _tmp13_ = NULL;
		ClutterActor* _tmp14_ = NULL;
		ClutterActor* _tmp15_ = NULL;
		ClutterActor* _tmp16_ = NULL;
		gfloat _tmp17_ = 0.0F;
		gfloat _tmp18_ = 0.0F;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = boxes_app_app;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = _tmp13_->overlay_bin_actor;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = actor;
#line 897 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		clutter_actor_add_child (_tmp14_, _tmp15_);
#line 898 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = actor;
#line 898 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = _data10_->x;
#line 898 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = _data10_->y;
#line 898 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_allocate_actor_no_animation (_tmp16_, _tmp17_, _tmp18_, (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, (gfloat) (BOXES_MACHINE_SCREENSHOT_HEIGHT * 2));
#line 7464 "app.c"
	}
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = actor;
#line 902 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_show (_tmp19_);
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = actor;
#line 903 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_easing_mode (_tmp20_, CLUTTER_LINEAR);
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = actor;
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = actor;
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_set (_tmp22_, "natural-width", (gfloat) (BOXES_MACHINE_SCREENSHOT_WIDTH * 2), NULL);
#line 904 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_set (_tmp21_, "min-width", (gfloat) (BOXES_MACHINE_SCREENSHOT_WIDTH * 2), NULL);
#line 905 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = actor;
#line 905 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_fixed_position_set (_tmp23_, FALSE);
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = actor;
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = boxes_app_app;
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = _tmp25_->duration;
#line 906 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	clutter_actor_set_easing_duration (_tmp24_, _tmp26_);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = _data10_->machine;
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp28_ = self->topbar;
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp29_ = g_object_bind_property_with_closures ((GObject*) _tmp27_, "status", (GObject*) _tmp28_, "status", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp30_ = _g_object_ref0 (_tmp29_);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 909 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->status_bind = _tmp30_;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31_ = _data10_->machine;
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp32_ = g_signal_connect_object (_tmp31_, "got-error", (GCallback) ___lambda85__boxes_machine_got_error, self, 0);
#line 911 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->got_error_id = _tmp32_;
#line 916 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_CREDS);
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp33_ = _data10_->machine;
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = _data10_->flags;
#line 919 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_machine_connect_display (_tmp33_, _tmp34_, ___lambda86__gasync_ready_callback, block10_data_ref (_data10_));
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (actor);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	block10_data_unref (_data10_);
#line 891 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_ = NULL;
#line 7526 "app.c"
}


void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item) {
	gboolean _tmp0_ = FALSE;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	gboolean _tmp5_ = FALSE;
#line 944 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 944 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 7545 "app.c"
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = boxes_app_get_selection_mode (self);
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_;
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = !_tmp4_;
#line 7554 "app.c"
	} else {
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = FALSE;
#line 7558 "app.c"
	}
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp0_;
#line 945 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp5_) {
#line 7564 "app.c"
		BoxesCollectionItem* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
		BoxesCollectionItem* _tmp18_ = NULL;
#line 946 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = item;
#line 946 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 946 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self->current_item);
#line 946 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		self->current_item = _tmp7_;
#line 948 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = self->current_item;
#line 948 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE)) {
#line 7581 "app.c"
			BoxesMachine* machine = NULL;
			BoxesCollectionItem* _tmp9_ = NULL;
			BoxesMachine* _tmp10_ = NULL;
			gfloat item_x = 0.0F;
			gfloat item_y = 0.0F;
			BoxesCollectionView* _tmp11_ = NULL;
			BoxesCollectionItem* _tmp12_ = NULL;
			gfloat _tmp13_ = 0.0F;
			gfloat _tmp14_ = 0.0F;
			BoxesMachine* _tmp15_ = NULL;
			gfloat _tmp16_ = 0.0F;
			gfloat _tmp17_ = 0.0F;
#line 949 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = self->current_item;
#line 949 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp9_) : NULL);
#line 949 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			machine = _tmp10_;
#line 952 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = self->view;
#line 952 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = item;
#line 952 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_collection_view_get_item_pos (_tmp11_, _tmp12_, &_tmp13_, &_tmp14_);
#line 952 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item_x = _tmp13_;
#line 952 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			item_y = _tmp14_;
#line 954 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = machine;
#line 954 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = item_x;
#line 954 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp17_ = item_y;
#line 954 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_connect_to (self, _tmp15_, _tmp16_, _tmp17_, BOXES_MACHINE_CONNECT_FLAGS_NONE);
#line 948 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (machine);
#line 7620 "app.c"
		} else {
#line 956 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			g_warning ("app.vala:956: unknown item, fix your code");
#line 7624 "app.c"
		}
#line 958 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = item;
#line 958 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_signal_emit_by_name (self, "item-selected", _tmp18_);
#line 7630 "app.c"
	} else {
		BoxesUIState _tmp19_ = 0;
		BoxesUIState _tmp20_ = 0;
#line 959 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 959 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = _tmp19_;
#line 959 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp20_ == BOXES_UI_STATE_WIZARD) {
#line 7640 "app.c"
			BoxesCollectionItem* _tmp21_ = NULL;
			BoxesCollectionItem* _tmp22_ = NULL;
#line 960 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp21_ = item;
#line 960 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp22_ = _g_object_ref0 (_tmp21_);
#line 960 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (self->current_item);
#line 960 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			self->current_item = _tmp22_;
#line 962 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_ui_set_ui_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 7653 "app.c"
		}
	}
}


static ClutterActor* boxes_app_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesApp* self;
	ClutterStage* _tmp0_ = NULL;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->stage;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = (ClutterActor*) _tmp0_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7671 "app.c"
}


gboolean boxes_app_get_fullscreen (BoxesApp* self) {
	gboolean result;
	GtkApplicationWindow* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GdkWindowState _tmp2_ = 0;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->window;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = gdk_window_get_state (_tmp1_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = (_tmp2_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7692 "app.c"
}


void boxes_app_set_fullscreen (BoxesApp* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_) {
#line 7704 "app.c"
		GtkApplicationWindow* _tmp1_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp1_ = self->window;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_fullscreen ((GtkWindow*) _tmp1_);
#line 7710 "app.c"
	} else {
		GtkApplicationWindow* _tmp2_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = self->window;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_unfullscreen ((GtkWindow*) _tmp2_);
#line 7717 "app.c"
	}
}


static gboolean boxes_app_get_maximized (BoxesApp* self) {
	gboolean result;
	GtkApplicationWindow* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GdkWindowState _tmp2_ = 0;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->window;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = gdk_window_get_state (_tmp1_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = (_tmp2_ & GDK_WINDOW_STATE_MAXIMIZED) == GDK_WINDOW_STATE_MAXIMIZED;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7739 "app.c"
}


const gchar* boxes_app_get_uri (BoxesApp* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_uri;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7754 "app.c"
}


void boxes_app_set_uri (BoxesApp* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_uri = _tmp1_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "uri");
#line 7773 "app.c"
}


GVirConnection* boxes_app_get_default_connection (BoxesApp* self) {
	GVirConnection* result;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_libvirt_broker_get_default ();
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_libvirt_broker_get_connection (_tmp1_, "QEMU Session");
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp1_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp3_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7799 "app.c"
}


BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self) {
	BoxesCollectionSource* result;
	GHashTable* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->sources;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_hash_table_lookup (_tmp0_, "QEMU Session");
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = (BoxesCollectionSource*) _tmp1_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7817 "app.c"
}


gboolean boxes_app_get_selection_mode (BoxesApp* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 809 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 809 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_selection_mode;
#line 809 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 809 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7832 "app.c"
}


void boxes_app_set_selection_mode (BoxesApp* self, gboolean value) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 811 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (_tmp1_ == BOXES_UI_STATE_COLLECTION);
#line 813 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = value;
#line 813 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_selection_mode = _tmp2_;
#line 810 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "selection-mode");
#line 7854 "app.c"
}


GList* boxes_app_get_selected_items (BoxesApp* self) {
	GList* result;
	BoxesCollectionView* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->view;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_view_get_selected_items (_tmp0_);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp1_;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 7872 "app.c"
}


static void boxes_app_class_init (BoxesAppClass * klass) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_parent_class = g_type_class_peek_parent (klass);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_type_class_add_private (klass, sizeof (BoxesAppPrivate));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_app_real_ui_state_changed;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_app_real_get_actor;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_app_get_property;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_app_set_property;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_app_finalize;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_FULLSCREEN, g_param_spec_boolean ("fullscreen", "fullscreen", "fullscreen", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_CONNECTION, g_param_spec_object ("default-connection", "default-connection", "default-connection", gvir_connection_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_SOURCE, g_param_spec_object ("default-source", "default-source", "default-source", BOXES_TYPE_COLLECTION_SOURCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_SELECTION_MODE, g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_SELECTED_ITEMS, g_param_spec_pointer ("selected-items", "selected-items", "selected-items", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_new ("ready", BOXES_TYPE_APP, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_new ("item_selected", BOXES_TYPE_APP, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 7909 "app.c"
}


static void boxes_app_instance_init (BoxesApp * self) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv = BOXES_APP_GET_PRIVATE (self);
#line 7916 "app.c"
}


static void boxes_app_finalize (GObject* obj) {
	BoxesApp * self;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_APP, BoxesApp);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->window);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->notebook);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->embed);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->stage);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->stage_bin);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->overlay_bin_actor);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->overlay_bin);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->current_item);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->searchbar);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->topbar);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->notificationbar);
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->sidebar_revealer);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->searchbar_revealer);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->sidebar);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->selectionbar);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->settings);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->wizard);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->properties);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->display_page);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->empty_boxes);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->filter);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->application);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->view);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (boxes_app_parent_class)->finalize (obj);
#line 7982 "app.c"
}


GType boxes_app_get_type (void) {
	static volatile gsize boxes_app_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAppClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_app_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesApp), 0, (GInstanceInitFunc) boxes_app_instance_init, NULL };
		GType boxes_app_type_id;
		boxes_app_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesApp", &g_define_type_info, 0);
		g_once_init_leave (&boxes_app_type_id__volatile, boxes_app_type_id);
	}
	return boxes_app_type_id__volatile;
}


static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_ACTOR:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_FULLSCREEN:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_boolean (value, boxes_app_get_fullscreen (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_string (value, boxes_app_get_uri (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_CONNECTION:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_take_object (value, boxes_app_get_default_connection (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_SOURCE:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_object (value, boxes_app_get_default_source (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTION_MODE:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_boolean (value, boxes_app_get_selection_mode (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTED_ITEMS:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_pointer (value, boxes_app_get_selected_items (self));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 8045 "app.c"
		default:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 8051 "app.c"
	}
}


static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_FULLSCREEN:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_fullscreen (self, g_value_get_boolean (value));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_uri (self, g_value_get_string (value));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTION_MODE:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_selection_mode (self, g_value_get_boolean (value));
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 8079 "app.c"
		default:
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 8085 "app.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



